@@ -15,15 +15,7 @@
  */
 
 #include "aligncommand.h"
-#include "sequence.hpp"
-
-#include "gotohoverlap.hpp"
-#include "needlemanoverlap.hpp"
-#include "blastalign.hpp"
-#include "noalign.hpp"
-
-#include "nast.hpp"
-#include "nastreport.hpp"
+#include "referencedb.h"
 
 //**********************************************************************************************************************
 vector<string> AlignCommand::setParameters(){	
@@ -39,6 +31,7 @@ vector<string> AlignCommand::setParameters(){
 		CommandParameter pgapextend("gapextend", "Number", "", "-1.0", "", "", "",false,false); parameters.push_back(pgapextend);
 		CommandParameter pprocessors("processors", "Number", "", "1", "", "", "",false,false); parameters.push_back(pprocessors);
 		CommandParameter pflip("flip", "Boolean", "", "F", "", "", "",false,false); parameters.push_back(pflip);
+		CommandParameter psave("save", "Boolean", "", "F", "", "", "",false,false); parameters.push_back(psave);
 		CommandParameter pthreshold("threshold", "Number", "", "0.50", "", "", "",false,false); parameters.push_back(pthreshold);
 		CommandParameter pinputdir("inputdir", "String", "", "", "", "", "",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "",false,false); parameters.push_back(poutputdir);
@@ -69,6 +62,7 @@ string AlignCommand::getHelpString(){
 		helpString += "The flip parameter is used to specify whether or not you want mothur to try the reverse complement if a sequence falls below the threshold.  The default is false.";
 		helpString += "The threshold is used to specify a cutoff at which an alignment is deemed 'bad' and the reverse complement may be tried. The default threshold is 0.50, meaning 50% of the bases are removed in the alignment.";
 		helpString += "If the flip parameter is set to true the reverse complement of the sequence is aligned and the better alignment is reported.";
+		helpString += "If the save parameter is set to true the reference sequences will be saved in memory, to clear them later you can use the clear.memory command. Default=f.";
 		helpString += "The default for the threshold parameter is 0.50, meaning at least 50% of the bases must remain or the sequence is reported as potentially reversed.";
 		helpString += "The align.seqs command should be in the following format:";
 		helpString += "align.seqs(reference=yourTemplateFile, fasta=yourCandidateFile, align=yourAlignmentMethod, search=yourSearchmethod, ksize=yourKmerSize, match=yourMatchBonus, mismatch=yourMismatchpenalty, gapopen=yourGapopenPenalty, gapextend=yourGapExtendPenalty)";
@@ -99,10 +93,12 @@ AlignCommand::AlignCommand(){
 //**********************************************************************************************************************
 AlignCommand::AlignCommand(string option)  {
 	try {
-		abort = false; calledHelp = false;   
-	
+		abort = false; calledHelp = false;  
+		ReferenceDB* rdb = ReferenceDB::getInstance();
+		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true;}
+		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
 		
 		else {
 			vector<string> myArray = setParameters();
@@ -145,15 +141,6 @@ AlignCommand::AlignCommand(string option)  {
 				}
 			}
 
-			//check for required parameters
-			templateFileName = validParameter.validFile(parameters, "reference", true);
-			
-			if (templateFileName == "not found") { 
-				m->mothurOut("reference is a required parameter for the align.seqs command."); 
-				m->mothurOutEndLine();
-				abort = true; 
-			}else if (templateFileName == "not open") { abort = true; }	
-			
 			candidateFileName = validParameter.validFile(parameters, "fasta", false);
 			if (candidateFileName == "not found") { 
 				//if there is a current fasta file, use it
@@ -167,50 +154,66 @@ AlignCommand::AlignCommand(string option)  {
 				for (int i = 0; i < candidateFileNames.size(); i++) {
 					//candidateFileNames[i] = m->getFullPathName(candidateFileNames[i]);
 					
-					if (inputDir != "") {
-						string path = m->hasPath(candidateFileNames[i]);
-						//if the user has not given a path then, add inputdir. else leave path alone.
-						if (path == "") {	candidateFileNames[i] = inputDir + candidateFileNames[i];		}
-					}
-	
-					int ableToOpen;
-					ifstream in;
-					ableToOpen = m->openInputFile(candidateFileNames[i], in, "noerror");
-					in.close();	
-					
-					//if you can't open it, try default location
-					if (ableToOpen == 1) {
-						if (m->getDefaultPath() != "") { //default path is set
-							string tryPath = m->getDefaultPath() + m->getSimpleName(candidateFileNames[i]);
-							m->mothurOut("Unable to open " + candidateFileNames[i] + ". Trying default " + tryPath); m->mothurOutEndLine();
-							ifstream in2;
-							ableToOpen = m->openInputFile(tryPath, in2, "noerror");
-							in2.close();
-							candidateFileNames[i] = tryPath;
+					bool ignore = false;
+					if (candidateFileNames[i] == "current") { 
+						candidateFileNames[i] = m->getFastaFile(); 
+						if (candidateFileNames[i] != "") {  m->mothurOut("Using " + candidateFileNames[i] + " as input file for the fasta parameter where you had given current."); m->mothurOutEndLine(); }
+						else { 	
+							m->mothurOut("You have no current fastafile, ignoring current."); m->mothurOutEndLine(); ignore=true; 
+							//erase from file list
+							candidateFileNames.erase(candidateFileNames.begin()+i);
+							i--;
 						}
 					}
 					
-					//if you can't open it, try output location
-					if (ableToOpen == 1) {
-						if (m->getOutputDir() != "") { //default path is set
-							string tryPath = m->getOutputDir() + m->getSimpleName(candidateFileNames[i]);
-							m->mothurOut("Unable to open " + candidateFileNames[i] + ". Trying output directory " + tryPath); m->mothurOutEndLine();
-							ifstream in2;
-							ableToOpen = m->openInputFile(tryPath, in2, "noerror");
-							in2.close();
-							candidateFileNames[i] = tryPath;
-						}
-					}
+					if (!ignore) {
 					
-									
+						if (inputDir != "") {
+							string path = m->hasPath(candidateFileNames[i]);
+							//if the user has not given a path then, add inputdir. else leave path alone.
+							if (path == "") {	candidateFileNames[i] = inputDir + candidateFileNames[i];		}
+						}
+		
+						int ableToOpen;
+						ifstream in;
+						ableToOpen = m->openInputFile(candidateFileNames[i], in, "noerror");
+						in.close();	
+						
+						//if you can't open it, try default location
+						if (ableToOpen == 1) {
+							if (m->getDefaultPath() != "") { //default path is set
+								string tryPath = m->getDefaultPath() + m->getSimpleName(candidateFileNames[i]);
+								m->mothurOut("Unable to open " + candidateFileNames[i] + ". Trying default " + tryPath); m->mothurOutEndLine();
+								ifstream in2;
+								ableToOpen = m->openInputFile(tryPath, in2, "noerror");
+								in2.close();
+								candidateFileNames[i] = tryPath;
+							}
+						}
+						
+						//if you can't open it, try output location
+						if (ableToOpen == 1) {
+							if (m->getOutputDir() != "") { //default path is set
+								string tryPath = m->getOutputDir() + m->getSimpleName(candidateFileNames[i]);
+								m->mothurOut("Unable to open " + candidateFileNames[i] + ". Trying output directory " + tryPath); m->mothurOutEndLine();
+								ifstream in2;
+								ableToOpen = m->openInputFile(tryPath, in2, "noerror");
+								in2.close();
+								candidateFileNames[i] = tryPath;
+							}
+						}
+						
+										
 
-					if (ableToOpen == 1) { 
-						m->mothurOut("Unable to open " + candidateFileNames[i] + ". It will be disregarded."); m->mothurOutEndLine(); 
-						//erase from file list
-						candidateFileNames.erase(candidateFileNames.begin()+i);
-						i--;
+						if (ableToOpen == 1) { 
+							m->mothurOut("Unable to open " + candidateFileNames[i] + ". It will be disregarded."); m->mothurOutEndLine(); 
+							//erase from file list
+							candidateFileNames.erase(candidateFileNames.begin()+i);
+							i--;
+						}else {
+							m->setFastaFile(candidateFileNames[i]);
+						}
 					}
-					
 				}
 				
 				//make sure there is at least one valid file left
@@ -242,6 +245,32 @@ AlignCommand::AlignCommand(string option)  {
 			temp = validParameter.validFile(parameters, "flip", false);			if (temp == "not found"){	temp = "f";				}
 			flip = m->isTrue(temp); 
 			
+			temp = validParameter.validFile(parameters, "save", false);			if (temp == "not found"){	temp = "f";				}
+			save = m->isTrue(temp); 
+			//this is so the threads can quickly load the reference data
+			#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+			#else
+				if (processors != 1) { save = true; }
+			#endif
+			rdb->save = save; 
+			if (save) { //clear out old references
+				rdb->clearMemory();
+			}
+			
+			//this has to go after save so that if the user sets save=t and provides no reference we abort
+			templateFileName = validParameter.validFile(parameters, "reference", true);
+			if (templateFileName == "not found") { 
+				//check for saved reference sequences
+				if (rdb->referenceSeqs.size() != 0) {
+					templateFileName = "saved";
+				}else {
+					m->mothurOut("[ERROR]: You don't have any saved reference sequences and the reference parameter is a required for the align.seqs command."); 
+					m->mothurOutEndLine();
+					abort = true; 
+				}
+			}else if (templateFileName == "not open") { abort = true; }	
+			else {	if (save) {	rdb->setSavedReference(templateFileName);	}	}
+			
 			temp = validParameter.validFile(parameters, "threshold", false);	if (temp == "not found"){	temp = "0.50";			}
 			convert(temp, threshold); 
 			
@@ -265,7 +294,6 @@ AlignCommand::~AlignCommand(){
 	if (abort == false) {
 		for (int i = 0; i < lines.size(); i++) {  delete lines[i];  }  lines.clear();
 		delete templateDB;
-		delete alignment;
 	}
 }
 //**********************************************************************************************************************
@@ -274,18 +302,7 @@ int AlignCommand::execute(){
 	try {
 		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
 
-		templateDB = new AlignmentDB(templateFileName, search, kmerSize, gapOpen, gapExtend, match, misMatch);
-		int longestBase = templateDB->getLongestBase();
-		
-		if(align == "gotoh")			{	alignment = new GotohOverlap(gapOpen, gapExtend, match, misMatch, longestBase);			}
-		else if(align == "needleman")	{	alignment = new NeedlemanOverlap(gapOpen, match, misMatch, longestBase);				}
-		else if(align == "blast")		{	alignment = new BlastAlignment(gapOpen, gapExtend, match, misMatch);		}
-		else if(align == "noalign")		{	alignment = new NoAlign();													}
-		else {
-			m->mothurOut(align + " is not a valid alignment option. I will run the command using needleman.");
-			m->mothurOutEndLine();
-			alignment = new NeedlemanOverlap(gapOpen, match, misMatch, longestBase);
-		}
+		templateDB = new AlignmentDB(templateFileName, search, kmerSize, gapOpen, gapExtend, match, misMatch, rand());
 		
 		for (int s = 0; s < candidateFileNames.size(); s++) {
 			if (m->control_pressed) { outputTypes.clear(); return 0; }
@@ -305,7 +322,7 @@ int AlignCommand::execute(){
 #ifdef USE_MPI	
 				int pid, numSeqsPerProcessor; 
 				int tag = 2001;
-				vector<unsigned long int> MPIPos;
+				vector<unsigned long long> MPIPos;
 				MPIWroteAccnos = false;
 			
 				MPI_Status status; 
@@ -403,30 +420,42 @@ int AlignCommand::execute(){
 						//MPI_Info info;
 						//MPI_File_delete(outAccnosFilename, info);
 						hasAccnos = false;	
-						remove(accnosFileName.c_str()); 
+						m->mothurRemove(accnosFileName); 
 					}
 				}
 				
 #else
 
-		vector<unsigned long int> positions = m->divideFile(candidateFileNames[s], processors);
-		for (int i = 0; i < (positions.size()-1); i++) {
-			lines.push_back(new linePair(positions[i], positions[(i+1)]));
-		}	
-	#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+			vector<unsigned long long> positions; 
+		#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+			positions = m->divideFile(candidateFileNames[s], processors);
+			for (int i = 0; i < (positions.size()-1); i++) {	lines.push_back(new linePair(positions[i], positions[(i+1)]));	}
+		#else
+			if (processors == 1) {
+				lines.push_back(new linePair(0, 1000));
+			}else {
+				positions = m->setFilePosFasta(candidateFileNames[s], numFastaSeqs); 
+				
+				//figure out how many sequences you have to process
+				int numSeqsPerProcessor = numFastaSeqs / processors;
+				for (int i = 0; i < processors; i++) {
+					int startIndex =  i * numSeqsPerProcessor;
+					if(i == (processors - 1)){	numSeqsPerProcessor = numFastaSeqs - i * numSeqsPerProcessor; 	}
+					lines.push_back(new linePair(positions[startIndex], numSeqsPerProcessor));
+				}
+			}
+		#endif
+			
 			if(processors == 1){
 				numFastaSeqs = driver(lines[0], alignFileName, reportFileName, accnosFileName, candidateFileNames[s]);
 			}else{
 				numFastaSeqs = createProcesses(alignFileName, reportFileName, accnosFileName, candidateFileNames[s]); 
 			}
-	#else
-			numFastaSeqs = driver(lines[0], alignFileName, reportFileName, accnosFileName, candidateFileNames[s]);
-	#endif
-			
-			if (m->control_pressed) { remove(accnosFileName.c_str()); remove(alignFileName.c_str()); remove(reportFileName.c_str()); outputTypes.clear();  return 0; }
+				
+			if (m->control_pressed) { m->mothurRemove(accnosFileName); m->mothurRemove(alignFileName); m->mothurRemove(reportFileName); outputTypes.clear();  return 0; }
 			
 			//delete accnos file if its blank else report to user
-			if (m->isBlank(accnosFileName)) {  remove(accnosFileName.c_str());  hasAccnos = false; }
+			if (m->isBlank(accnosFileName)) {  m->mothurRemove(accnosFileName);  hasAccnos = false; }
 			else { 
 				m->mothurOut("Some of you sequences generated alignments that eliminated too many bases, a list is provided in " + accnosFileName + ".");
 				if (!flip) {
@@ -478,7 +507,6 @@ int AlignCommand::execute(){
 }
 
 //**********************************************************************************************************************
-
 int AlignCommand::driver(linePair* filePos, string alignFName, string reportFName, string accnosFName, string filename){
 	try {
 		ofstream alignmentFile;
@@ -496,10 +524,23 @@ int AlignCommand::driver(linePair* filePos, string alignFName, string reportFNam
 
 		bool done = false;
 		int count = 0;
+		
+		//moved this into driver to avoid deep copies in windows paralellized version
+		Alignment* alignment;
+		int longestBase = templateDB->getLongestBase();
+		if(align == "gotoh")			{	alignment = new GotohOverlap(gapOpen, gapExtend, match, misMatch, longestBase);			}
+		else if(align == "needleman")	{	alignment = new NeedlemanOverlap(gapOpen, match, misMatch, longestBase);				}
+		else if(align == "blast")		{	alignment = new BlastAlignment(gapOpen, gapExtend, match, misMatch);		}
+		else if(align == "noalign")		{	alignment = new NoAlign();													}
+		else {
+			m->mothurOut(align + " is not a valid alignment option. I will run the command using needleman.");
+			m->mothurOutEndLine();
+			alignment = new NeedlemanOverlap(gapOpen, match, misMatch, longestBase);
+		}
 	
 		while (!done) {
 			
-			if (m->control_pressed) {  return 0; }
+			if (m->control_pressed) {  break; }
 			
 			Sequence* candidateSeq = new Sequence(inFASTA);  m->gobble(inFASTA);
 			report.setCandidate(candidateSeq);
@@ -515,7 +556,7 @@ int AlignCommand::driver(linePair* filePos, string alignFName, string reportFNam
 								
 				Sequence temp = templateDB->findClosestSequence(candidateSeq);
 				Sequence* templateSeq = &temp;
-			
+				
 				float searchScore = templateDB->getSearchScore();
 								
 				Nast* nast = new Nast(alignment, candidateSeq, templateSeq);
@@ -582,7 +623,7 @@ int AlignCommand::driver(linePair* filePos, string alignFName, string reportFNam
 			delete candidateSeq;
 			
 			#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
-				unsigned long int pos = inFASTA.tellg();
+				unsigned long long pos = inFASTA.tellg();
 				if ((pos == -1) || (pos >= filePos->end)) { break; }
 			#else
 				if (inFASTA.eof()) { break; }
@@ -595,6 +636,7 @@ int AlignCommand::driver(linePair* filePos, string alignFName, string reportFNam
 		//report progress
 		if((count) % 100 != 0){	m->mothurOut(toString(count)); m->mothurOutEndLine();		}
 		
+		delete alignment;
 		alignmentFile.close();
 		inFASTA.close();
 		accnosFile.close();
@@ -608,7 +650,7 @@ int AlignCommand::driver(linePair* filePos, string alignFName, string reportFNam
 }
 //**********************************************************************************************************************
 #ifdef USE_MPI
-int AlignCommand::driverMPI(int start, int num, MPI_File& inMPI, MPI_File& alignFile, MPI_File& reportFile, MPI_File& accnosFile, vector<unsigned long int>& MPIPos){
+int AlignCommand::driverMPI(int start, int num, MPI_File& inMPI, MPI_File& alignFile, MPI_File& reportFile, MPI_File& accnosFile, vector<unsigned long long>& MPIPos){
 	try {
 		string outputString = "";
 		MPI_Status statusReport; 
@@ -632,9 +674,22 @@ int AlignCommand::driverMPI(int start, int num, MPI_File& inMPI, MPI_File& align
             delete buf;
 		}
 		
+		Alignment* alignment;
+		int longestBase = templateDB->getLongestBase();
+		if(align == "gotoh")			{	alignment = new GotohOverlap(gapOpen, gapExtend, match, misMatch, longestBase);			}
+		else if(align == "needleman")	{	alignment = new NeedlemanOverlap(gapOpen, match, misMatch, longestBase);				}
+		else if(align == "blast")		{	alignment = new BlastAlignment(gapOpen, gapExtend, match, misMatch);		}
+		else if(align == "noalign")		{	alignment = new NoAlign();													}
+		else {
+			m->mothurOut(align + " is not a valid alignment option. I will run the command using needleman.");
+			m->mothurOutEndLine();
+			alignment = new NeedlemanOverlap(gapOpen, match, misMatch, longestBase);
+		}
+		
+		
 		for(int i=0;i<num;i++){
 		
-			if (m->control_pressed) {  return 0; }
+			if (m->control_pressed) { delete alignment; return 0; }
 
 			//read next sequence
 			int length = MPIPos[start+i+1] - MPIPos[start+i];
@@ -774,11 +829,10 @@ int AlignCommand::driverMPI(int start, int num, MPI_File& inMPI, MPI_File& align
 
 int AlignCommand::createProcesses(string alignFileName, string reportFileName, string accnosFName, string filename) {
 	try {
-#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
-		processIDS.resize(0);
-		int process = 1;
 		int num = 0;
-		//		processIDS.resize(0);
+		processIDS.resize(0);
+#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+		int process = 1;
 		
 		//loop through and create all the processes you want
 		while (process != processors) {
@@ -816,24 +870,24 @@ int AlignCommand::createProcesses(string alignFileName, string reportFileName, s
 		
 		vector<string> nonBlankAccnosFiles;
 		if (!(m->isBlank(accnosFName))) { nonBlankAccnosFiles.push_back(accnosFName); }
-		else { remove(accnosFName.c_str()); } //remove so other files can be renamed to it
+		else { m->mothurRemove(accnosFName); } //remove so other files can be renamed to it
 			
 		for (int i = 0; i < processIDS.size(); i++) {
 			ifstream in;
 			string tempFile =  alignFileName + toString(processIDS[i]) + ".num.temp";
 			m->openInputFile(tempFile, in);
 			if (!in.eof()) { int tempNum = 0; in >> tempNum; num += tempNum; }
-			in.close(); remove(tempFile.c_str());
+			in.close(); m->mothurRemove(tempFile);
 			
 			appendAlignFiles((alignFileName + toString(processIDS[i]) + ".temp"), alignFileName);
-			remove((alignFileName + toString(processIDS[i]) + ".temp").c_str());
+			m->mothurRemove((alignFileName + toString(processIDS[i]) + ".temp"));
 			
 			appendReportFiles((reportFileName + toString(processIDS[i]) + ".temp"), reportFileName);
-			remove((reportFileName + toString(processIDS[i]) + ".temp").c_str());
+			m->mothurRemove((reportFileName + toString(processIDS[i]) + ".temp"));
 			
 			if (!(m->isBlank(accnosFName + toString(processIDS[i]) + ".temp"))) {
 				nonBlankAccnosFiles.push_back(accnosFName + toString(processIDS[i]) + ".temp");
-			}else { remove((accnosFName + toString(processIDS[i]) + ".temp").c_str());  }
+			}else { m->mothurRemove((accnosFName + toString(processIDS[i]) + ".temp"));  }
 			
 		}
 		
@@ -843,16 +897,97 @@ int AlignCommand::createProcesses(string alignFileName, string reportFileName, s
 			
 			for (int h=1; h < nonBlankAccnosFiles.size(); h++) {
 				appendAlignFiles(nonBlankAccnosFiles[h], accnosFName);
-				remove(nonBlankAccnosFiles[h].c_str());
+				m->mothurRemove(nonBlankAccnosFiles[h]);
 			}
 		}else { //recreate the accnosfile if needed
 			ofstream out;
 			m->openOutputFile(accnosFName, out);
 			out.close();
 		}
+#else
+		//////////////////////////////////////////////////////////////////////////////////////////////////////
+		//Windows version shared memory, so be careful when passing variables through the alignData struct. 
+		//Above fork() will clone, so memory is separate, but that's not the case with windows, 
+		//////////////////////////////////////////////////////////////////////////////////////////////////////
+		
+		vector<alignData*> pDataArray; 
+		DWORD   dwThreadIdArray[processors-1];
+		HANDLE  hThreadArray[processors-1]; 
+		
+		//Create processor worker threads.
+		for( int i=0; i<processors-1; i++ ){
+			//copy templateDb
+			//AlignmentDB* tempDB = new AlignmentDB(*templateDB);
+			
+			// Allocate memory for thread data.
+			string extension = "";
+			if (i != 0) { extension = toString(i) + ".temp"; }
+			
+			alignData* tempalign = new alignData((alignFileName + extension), (reportFileName + extension), (accnosFName + extension), filename, align, search, kmerSize, m, lines[i]->start, lines[i]->end, flip, match, misMatch, gapOpen, gapExtend, threshold, i);
+			pDataArray.push_back(tempalign);
+			processIDS.push_back(i);
+				
+			//MySeqSumThreadFunction is in header. It must be global or static to work with the threads.
+			//default security attributes, thread function name, argument to thread function, use default creation flags, returns the thread identifier
+			hThreadArray[i] = CreateThread(NULL, 0, MyAlignThreadFunction, pDataArray[i], 0, &dwThreadIdArray[i]);   
+		}
+		
+		//need to check for line ending error
+		ifstream inFASTA;
+		m->openInputFile(filename, inFASTA);
+		inFASTA.seekg(lines[processors-1]->start-1);
+		char c = inFASTA.peek();
+		
+		if (c != '>') { //we need to move back
+			lines[processors-1]->start--; 
+		}
+		
+		//using the main process as a worker saves time and memory
+		//do my part - do last piece because windows is looking for eof
+		num = driver(lines[processors-1], (alignFileName + toString(processors-1) + ".temp"), (reportFileName + toString(processors-1) + ".temp"), (accnosFName + toString(processors-1) + ".temp"), filename);
+		
+		//Wait until all threads have terminated.
+		WaitForMultipleObjects(processors-1, hThreadArray, TRUE, INFINITE);
+		
+		//Close all thread handles and free memory allocations.
+		for(int i=0; i < pDataArray.size(); i++){
+			num += pDataArray[i]->count;
+			CloseHandle(hThreadArray[i]);
+			delete pDataArray[i];
+		}
+		
+		vector<string> nonBlankAccnosFiles;
+		if (!(m->isBlank(accnosFName))) { nonBlankAccnosFiles.push_back(accnosFName); }
+		else { m->mothurRemove(accnosFName); } //remove so other files can be renamed to it
+		
+		for (int i = 1; i < processors; i++) {
+			appendAlignFiles((alignFileName + toString(i) + ".temp"), alignFileName);
+			m->mothurRemove((alignFileName + toString(i) + ".temp"));
+			
+			appendReportFiles((reportFileName + toString(i) + ".temp"), reportFileName);
+			m->mothurRemove((reportFileName + toString(i) + ".temp"));
+			
+			if (!(m->isBlank(accnosFName + toString(i) + ".temp"))) {
+				nonBlankAccnosFiles.push_back(accnosFName + toString(i) + ".temp");
+			}else { m->mothurRemove((accnosFName + toString(i) + ".temp"));  }
+		}
+		
+		//append accnos files
+		if (nonBlankAccnosFiles.size() != 0) { 
+			rename(nonBlankAccnosFiles[0].c_str(), accnosFName.c_str());
+			
+			for (int h=1; h < nonBlankAccnosFiles.size(); h++) {
+				appendAlignFiles(nonBlankAccnosFiles[h], accnosFName);
+				m->mothurRemove(nonBlankAccnosFiles[h]);
+			}
+		}else { //recreate the accnosfile if needed
+			ofstream out;
+			m->openOutputFile(accnosFName, out);
+			out.close();
+		}	
+#endif	
 		
 		return num;
-#endif		
 	}
 	catch(exception& e) {
 		m->errorOut(e, "AlignCommand", "createProcesses");
