@@ -16,26 +16,32 @@
 class BlastDB : public Database {
 
 public:
-	BlastDB(float, float, float, float);
-	BlastDB();
+	BlastDB(string, float, float, float, float, string, int);
+	BlastDB(string, int);
+	BlastDB(const BlastDB& bdb) : dbFileName(bdb.dbFileName), queryFileName(bdb.queryFileName), blastFileName(bdb.blastFileName), path(bdb.path),
+									count(bdb.count), gapOpen(bdb.gapOpen), gapExtend(bdb.gapExtend), match(bdb.match), misMatch(bdb.misMatch), Database(bdb) {}
 	~BlastDB();
 	
 	void generateDB();
 	void addSequence(Sequence);
 	vector<int> findClosestSequences(Sequence*, int);
-	vector<int> findClosestMegaBlast(Sequence*, int);
+	vector<int> findClosestMegaBlast(Sequence*, int, int);
 	
 private:
+	
+	string scrubName(string);
+	
 	string dbFileName;
 	string queryFileName;
 	string blastFileName;
 	string path;
 	
-	int count;
+	int count, threadID;
 	float gapOpen;
 	float gapExtend;
 	float match;
 	float misMatch;
+	
 };
 
 #endif
