@@ -78,6 +78,7 @@ BootSharedCommand::BootSharedCommand(string option) {
 		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
+		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
 		
 		else {
 			vector<string> myArray = setParameters();
@@ -112,8 +113,13 @@ BootSharedCommand::BootSharedCommand(string option) {
 			}
 			
 			sharedfile = validParameter.validFile(parameters, "shared", true);
-			if (sharedfile == "not found") { m->mothurOut("shared is a required parameter.");  m->mothurOutEndLine(); sharedfile = ""; abort = true; }
+			if (sharedfile == "not found") { 
+				sharedfile = m->getSharedFile(); 
+				if (sharedfile != "") { m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
+				else { 	m->mothurOut("You have no current shared file and the shared parameter is required."); m->mothurOutEndLine(); abort = true; }
+			}	
 			else if (sharedfile == "not open") { sharedfile = ""; abort = true; }
+			else { m->setSharedFile(sharedfile); }
 		
 			//if the user changes the output directory command factory will send this info to us in the output parameter 
 			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	
@@ -134,7 +140,7 @@ BootSharedCommand::BootSharedCommand(string option) {
 			if (groups == "not found") { groups = ""; }
 			else { 
 				m->splitAtDash(groups, Groups);
-				m->Groups = Groups;
+				m->setGroups(Groups);
 			}
 				
 			calc = validParameter.validFile(parameters, "calc", false);			
@@ -143,6 +149,11 @@ BootSharedCommand::BootSharedCommand(string option) {
 				 if (calc == "default")  {  calc = "jclass-thetayc";  }
 			}
 			m->splitAtDash(calc, Estimators);
+			if (m->inUsersGroups("citation", Estimators)) { 
+				ValidCalculators validCalc; validCalc.printCitations(Estimators); 
+				//remove citation from list of calcs
+				for (int i = 0; i < Estimators.size(); i++) { if (Estimators[i] == "citation") {  Estimators.erase(Estimators.begin()+i); break; } }
+			}
 
 			string temp;
 			temp = validParameter.validFile(parameters, "iters", false);  if (temp == "not found") { temp = "1000"; }
@@ -245,13 +256,13 @@ int BootSharedCommand::execute(){
 		globaldata->gTreemap = tmap;
 			
 		while((order != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
-			if (m->control_pressed) {  for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str());  } globaldata->Groups.clear(); delete input;delete util; return 0;	} 
+			if (m->control_pressed) {  for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  } globaldata->Groups.clear(); delete input;delete util; return 0;	} 
 	
 			if(allLines == 1 || labels.count(order->getLabel()) == 1){			
 				
 				m->mothurOut(order->getLabel()); m->mothurOutEndLine();
 				int error = process(order);
-				if (error == 1) {  for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str());  } globaldata->Groups.clear(); delete input;delete util; return 0;	} 
+				if (error == 1) {  for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  } globaldata->Groups.clear(); delete input;delete util; return 0;	} 
 				
 				processedLabels.insert(order->getLabel());
 				userLabels.erase(order->getLabel());
@@ -265,7 +276,7 @@ int BootSharedCommand::execute(){
 				order = input->getSharedOrderVector(lastLabel);													
 				m->mothurOut(order->getLabel()); m->mothurOutEndLine();
 				int error = process(order);
-				if (error == 1) {  for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str());  } globaldata->Groups.clear(); delete input;delete util; return 0;	} 
+				if (error == 1) {  for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  } globaldata->Groups.clear(); delete input;delete util; return 0;	} 
 
 				processedLabels.insert(order->getLabel());
 				userLabels.erase(order->getLabel());
@@ -283,7 +294,7 @@ int BootSharedCommand::execute(){
 		}
 		
 		
-		if (m->control_pressed) {  for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str());  } globaldata->Groups.clear(); delete input; delete util;  return 0;	} 
+		if (m->control_pressed) {  for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  } globaldata->Groups.clear(); delete input; delete util;  return 0;	} 
 
 		//output error messages about any remaining user labels
 		set<string>::iterator it;
@@ -298,7 +309,7 @@ int BootSharedCommand::execute(){
 			}
 		}
 		
-		if (m->control_pressed) {  for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str());  } globaldata->Groups.clear(); delete input; delete util; return 0;	} 
+		if (m->control_pressed) {  for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  } globaldata->Groups.clear(); delete input; delete util; return 0;	} 
 
 		//run last line if you need to
 		if (needToRun == true)  {
@@ -306,13 +317,13 @@ int BootSharedCommand::execute(){
 				order = input->getSharedOrderVector(lastLabel);													
 				m->mothurOut(order->getLabel()); m->mothurOutEndLine();
 				int error = process(order);
-				if (error == 1) {  for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str());  } globaldata->Groups.clear(); delete input; delete util; return 0;	} 
+				if (error == 1) {  for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  } globaldata->Groups.clear(); delete input; delete util; return 0;	} 
 				
 				delete order;
 
 		}
 		
-		if (m->control_pressed) {  for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str());  } globaldata->Groups.clear();delete input; delete util; return 0;	} 
+		if (m->control_pressed) {  for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  } globaldata->Groups.clear();delete input; delete util; return 0;	} 
 
 		//reset groups parameter
 		globaldata->Groups.clear();  
