@@ -28,6 +28,8 @@ public:
 	string getCommandName()			{ return "chimera.check";		}
 	string getCommandCategory()		{ return "Sequence Processing"; }
 	string getHelpString();	
+	string getCitation() { return "CHIMERA_CHECK version 2.7 written by Niels Larsen (http://wdcm.nig.ac.jp/RDP/docs/chimera_doc.html) \nhttp://www.mothur.org/wiki/Chimera.check"; }
+	string getDescription()		{ return "detect chimeric sequences"; }
 	
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
@@ -36,9 +38,9 @@ public:
 private:
 
 	struct linePair {
-		unsigned long int start;
-		unsigned long int end;
-		linePair(unsigned long int i, unsigned long int j) : start(i), end(j) {}
+		unsigned long long start;
+		unsigned long long end;
+		linePair(unsigned long long i, unsigned long long j) : start(i), end(j) {}
 	};
 
 	vector<int> processIDS;   //processid
@@ -48,10 +50,10 @@ private:
 	int createProcesses(string, string);
 		
 	#ifdef USE_MPI
-	int driverMPI(int, int, MPI_File&, MPI_File&, vector<unsigned long int>&);
+	int driverMPI(int, int, MPI_File&, MPI_File&, vector<unsigned long long>&);
 	#endif
 
-	bool abort, svg;
+	bool abort, svg, save;
 	string fastafile, templatefile, namefile, outputDir;
 	int processors, increment, ksize, numSeqs, templateSeqsLength;
 	Chimera* chimera;
