@@ -26,6 +26,8 @@ public:
 	string getCommandName()			{ return "classify.otu";		}
 	string getCommandCategory()		{ return "Phylotype Analysis";	}
 	string getHelpString();	
+	string getCitation() { return "Schloss PD, Westcott SL (2011). Assessing and improving methods used in OTU-based approaches for 16S rRNA gene sequence analysis. Appl Environ Microbiol. \nhttp://www.mothur.org/wiki/Classify.otu"; }
+	string getDescription()		{ return "find the concensus taxonomy for each OTU"; }
 	
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
@@ -46,6 +48,7 @@ private:
 	int readTaxonomyFile();
 	void removeConfidences(string&);
 	int process(ListVector*);
+	string addUnclassifieds(string, int);
 	vector<string> findConsensusTaxonomy(int, ListVector*, int&, string&); 	// returns the name of the "representative" taxonomy of given bin
 	
 												
