@@ -8,11 +8,7 @@
  */
 
 #include "classifyseqscommand.h"
-#include "sequence.hpp"
-#include "bayesian.h"
-#include "phylotree.h"
-#include "phylosummary.h"
-#include "knn.h"
+
 
 
 //**********************************************************************************************************************
@@ -34,6 +30,7 @@ vector<string> ClassifySeqsCommand::setParameters(){
 		CommandParameter pcutoff("cutoff", "Number", "", "0", "", "", "",false,true); parameters.push_back(pcutoff);
 		CommandParameter pprobs("probs", "Boolean", "", "T", "", "", "",false,false); parameters.push_back(pprobs);
 		CommandParameter piters("iters", "Number", "", "100", "", "", "",false,true); parameters.push_back(piters);
+		CommandParameter psave("save", "Boolean", "", "F", "", "", "",false,false); parameters.push_back(psave);
 		CommandParameter pnumwanted("numwanted", "Number", "", "10", "", "", "",false,true); parameters.push_back(pnumwanted);
 		CommandParameter pinputdir("inputdir", "String", "", "", "", "", "",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "",false,false); parameters.push_back(poutputdir);
@@ -63,6 +60,7 @@ string ClassifySeqsCommand::getHelpString(){
 #ifdef USE_MPI
 		helpString += "When using MPI, the processors parameter is set to the number of MPI processes running. \n";
 #endif
+		helpString += "If the save parameter is set to true the reference sequences will be saved in memory, to clear them later you can use the clear.memory command. Default=f.";
 		helpString += "The match parameter allows you to specify the bonus for having the same base. The default is 1.0.\n";
 		helpString += "The mistmatch parameter allows you to specify the penalty for having different bases.  The default is -1.0.\n";
 		helpString += "The gapopen parameter allows you to specify the penalty for opening a gap in an alignment. The default is -2.0.\n";
@@ -103,9 +101,11 @@ ClassifySeqsCommand::ClassifySeqsCommand(){
 ClassifySeqsCommand::ClassifySeqsCommand(string option)  {
 	try {
 		abort = false; calledHelp = false;   
+		rdb = ReferenceDB::getInstance();
 		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
+		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
 		
 		else {
 			vector<string> myArray = setParameters();
@@ -160,16 +160,6 @@ ClassifySeqsCommand::ClassifySeqsCommand(string option)  {
 				}
 			}
 
-			//check for required parameters
-			templateFileName = validParameter.validFile(parameters, "reference", true);
-			if (templateFileName == "not found") { 
-				m->mothurOut("reference is a required parameter for the classify.seqs command."); 
-				m->mothurOutEndLine();
-				abort = true; 
-			}
-			else if (templateFileName == "not open") { abort = true; }	
-			
-						
 			fastaFileName = validParameter.validFile(parameters, "fasta", false);
 			if (fastaFileName == "not found") { 				
 				//if there is a current fasta file, use it
@@ -182,47 +172,65 @@ ClassifySeqsCommand::ClassifySeqsCommand(string option)  {
 				
 				//go through files and make sure they are good, if not, then disregard them
 				for (int i = 0; i < fastaFileNames.size(); i++) {
-					if (inputDir != "") {
-						string path = m->hasPath(fastaFileNames[i]);
-						//if the user has not given a path then, add inputdir. else leave path alone.
-						if (path == "") {	fastaFileNames[i] = inputDir + fastaFileNames[i];		}
-					}
 					
-					int ableToOpen;
-					
-					ifstream in;
-					ableToOpen = m->openInputFile(fastaFileNames[i], in, "noerror");
-				
-					//if you can't open it, try default location
-					if (ableToOpen == 1) {
-						if (m->getDefaultPath() != "") { //default path is set
-							string tryPath = m->getDefaultPath() + m->getSimpleName(fastaFileNames[i]);
-							m->mothurOut("Unable to open " + fastaFileNames[i] + ". Trying default " + tryPath); m->mothurOutEndLine();
-							ifstream in2;
-							ableToOpen = m->openInputFile(tryPath, in2, "noerror");
-							in2.close();
-							fastaFileNames[i] = tryPath;
+					bool ignore = false;
+					if (fastaFileNames[i] == "current") { 
+						fastaFileNames[i] = m->getFastaFile(); 
+						if (fastaFileNames[i] != "") {  m->mothurOut("Using " + fastaFileNames[i] + " as input file for the fasta parameter where you had given current."); m->mothurOutEndLine(); }
+						else { 	
+							m->mothurOut("You have no current fastafile, ignoring current."); m->mothurOutEndLine(); ignore=true; 
+							//erase from file list
+							fastaFileNames.erase(fastaFileNames.begin()+i);
+							i--;
 						}
 					}
 					
-					if (ableToOpen == 1) {
-						if (m->getOutputDir() != "") { //default path is set
-							string tryPath = m->getOutputDir() + m->getSimpleName(fastaFileNames[i]);
-							m->mothurOut("Unable to open " + fastaFileNames[i] + ". Trying output directory " + tryPath); m->mothurOutEndLine();
-							ifstream in2;
-							ableToOpen = m->openInputFile(tryPath, in2, "noerror");
-							in2.close();
-							fastaFileNames[i] = tryPath;
+					if (!ignore) {
+						
+						if (inputDir != "") {
+							string path = m->hasPath(fastaFileNames[i]);
+							//if the user has not given a path then, add inputdir. else leave path alone.
+							if (path == "") {	fastaFileNames[i] = inputDir + fastaFileNames[i];		}
 						}
-					}
+						
+						int ableToOpen;
+						
+						ifstream in;
+						ableToOpen = m->openInputFile(fastaFileNames[i], in, "noerror");
 					
-					in.close();
-					
-					if (ableToOpen == 1) { 
-						m->mothurOut("Unable to open " + fastaFileNames[i] + ". It will be disregarded."); m->mothurOutEndLine(); 
-						//erase from file list
-						fastaFileNames.erase(fastaFileNames.begin()+i);
-						i--;
+						//if you can't open it, try default location
+						if (ableToOpen == 1) {
+							if (m->getDefaultPath() != "") { //default path is set
+								string tryPath = m->getDefaultPath() + m->getSimpleName(fastaFileNames[i]);
+								m->mothurOut("Unable to open " + fastaFileNames[i] + ". Trying default " + tryPath); m->mothurOutEndLine();
+								ifstream in2;
+								ableToOpen = m->openInputFile(tryPath, in2, "noerror");
+								in2.close();
+								fastaFileNames[i] = tryPath;
+							}
+						}
+						
+						if (ableToOpen == 1) {
+							if (m->getOutputDir() != "") { //default path is set
+								string tryPath = m->getOutputDir() + m->getSimpleName(fastaFileNames[i]);
+								m->mothurOut("Unable to open " + fastaFileNames[i] + ". Trying output directory " + tryPath); m->mothurOutEndLine();
+								ifstream in2;
+								ableToOpen = m->openInputFile(tryPath, in2, "noerror");
+								in2.close();
+								fastaFileNames[i] = tryPath;
+							}
+						}
+						
+						in.close();
+						
+						if (ableToOpen == 1) { 
+							m->mothurOut("Unable to open " + fastaFileNames[i] + ". It will be disregarded."); m->mothurOutEndLine(); 
+							//erase from file list
+							fastaFileNames.erase(fastaFileNames.begin()+i);
+							i--;
+						}else {
+							m->setFastaFile(fastaFileNames[i]);
+						}
 					}
 					
 				}
@@ -231,16 +239,6 @@ ClassifySeqsCommand::ClassifySeqsCommand(string option)  {
 				if (fastaFileNames.size() == 0) { m->mothurOut("no valid files."); m->mothurOutEndLine(); abort = true; }
 			}
 
-			
-			taxonomyFileName = validParameter.validFile(parameters, "taxonomy", true);
-			if (taxonomyFileName == "not found") { 
-				m->mothurOut("taxonomy is a required parameter for the classify.seqs command."); 
-				m->mothurOutEndLine();
-				abort = true; 
-			}
-			else if (taxonomyFileName == "not open") { abort = true; }	
-			
-			
 			namefile = validParameter.validFile(parameters, "name", false);
 			if (namefile == "not found") { namefile = "";  }
 
@@ -249,47 +247,63 @@ ClassifySeqsCommand::ClassifySeqsCommand(string option)  {
 				
 				//go through files and make sure they are good, if not, then disregard them
 				for (int i = 0; i < namefileNames.size(); i++) {
-					if (inputDir != "") {
-						string path = m->hasPath(namefileNames[i]);
-						//if the user has not given a path then, add inputdir. else leave path alone.
-						if (path == "") {	namefileNames[i] = inputDir + namefileNames[i];		}
-					}
-					int ableToOpen;
-					
-					ifstream in;
-					ableToOpen = m->openInputFile(namefileNames[i], in, "noerror");
-				
-					//if you can't open it, try default location
-					if (ableToOpen == 1) {
-						if (m->getDefaultPath() != "") { //default path is set
-							string tryPath = m->getDefaultPath() + m->getSimpleName(namefileNames[i]);
-							m->mothurOut("Unable to open " + namefileNames[i] + ". Trying default " + tryPath); m->mothurOutEndLine();
-							ifstream in2;
-							ableToOpen = m->openInputFile(tryPath, in2, "noerror");
-							in2.close();
-							namefileNames[i] = tryPath;
+					bool ignore = false;
+					if (namefileNames[i] == "current") { 
+						namefileNames[i] = m->getNameFile(); 
+						if (namefileNames[i] != "") {  m->mothurOut("Using " + namefileNames[i] + " as input file for the name parameter where you had given current."); m->mothurOutEndLine(); }
+						else { 	
+							m->mothurOut("You have no current namefile, ignoring current."); m->mothurOutEndLine(); ignore=true; 
+							//erase from file list
+							namefileNames.erase(namefileNames.begin()+i);
+							i--;
 						}
 					}
 					
-					if (ableToOpen == 1) {
-						if (m->getOutputDir() != "") { //default path is set
-							string tryPath = m->getOutputDir() + m->getSimpleName(namefileNames[i]);
-							m->mothurOut("Unable to open " + namefileNames[i] + ". Trying output directory " + tryPath); m->mothurOutEndLine();
-							ifstream in2;
-							ableToOpen = m->openInputFile(tryPath, in2, "noerror");
-							in2.close();
-							namefileNames[i] = tryPath;
+					if (!ignore) {
+						
+						if (inputDir != "") {
+							string path = m->hasPath(namefileNames[i]);
+							//if the user has not given a path then, add inputdir. else leave path alone.
+							if (path == "") {	namefileNames[i] = inputDir + namefileNames[i];		}
+						}
+						int ableToOpen;
+						
+						ifstream in;
+						ableToOpen = m->openInputFile(namefileNames[i], in, "noerror");
+					
+						//if you can't open it, try default location
+						if (ableToOpen == 1) {
+							if (m->getDefaultPath() != "") { //default path is set
+								string tryPath = m->getDefaultPath() + m->getSimpleName(namefileNames[i]);
+								m->mothurOut("Unable to open " + namefileNames[i] + ". Trying default " + tryPath); m->mothurOutEndLine();
+								ifstream in2;
+								ableToOpen = m->openInputFile(tryPath, in2, "noerror");
+								in2.close();
+								namefileNames[i] = tryPath;
+							}
+						}
+						
+						if (ableToOpen == 1) {
+							if (m->getOutputDir() != "") { //default path is set
+								string tryPath = m->getOutputDir() + m->getSimpleName(namefileNames[i]);
+								m->mothurOut("Unable to open " + namefileNames[i] + ". Trying output directory " + tryPath); m->mothurOutEndLine();
+								ifstream in2;
+								ableToOpen = m->openInputFile(tryPath, in2, "noerror");
+								in2.close();
+								namefileNames[i] = tryPath;
+							}
+						}
+						in.close();
+						
+						if (ableToOpen == 1) { 
+							m->mothurOut("Unable to open " + namefileNames[i] + ". It will be disregarded."); m->mothurOutEndLine();  abort = true;
+							//erase from file list
+							namefileNames.erase(namefileNames.begin()+i);
+							i--;
+						}else {
+							m->setNameFile(namefileNames[i]);
 						}
 					}
-					in.close();
-					
-					if (ableToOpen == 1) { 
-						m->mothurOut("Unable to open " + namefileNames[i] + ". It will be disregarded."); m->mothurOutEndLine();  abort = true;
-						//erase from file list
-						namefileNames.erase(namefileNames.begin()+i);
-						i--;
-					}
-
 				}
 			}
 
@@ -344,6 +358,8 @@ ClassifySeqsCommand::ClassifySeqsCommand(string option)  {
 						//erase from file list
 						groupfileNames.erase(groupfileNames.begin()+i);
 						i--;
+					}else {
+						m->setGroupFile(groupfileNames[i]);
 					}
 				}
 			}
@@ -364,6 +380,46 @@ ClassifySeqsCommand::ClassifySeqsCommand(string option)  {
 			m->setProcessors(temp);
 			convert(temp, processors); 
 			
+			temp = validParameter.validFile(parameters, "save", false);			if (temp == "not found"){	temp = "f";				}
+			save = m->isTrue(temp); 
+			//this is so the threads can quickly load the reference data
+			#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+			#else
+			if ((processors != 1) && (rdb->referenceSeqs.size() == 0)) { save = true; }
+			#endif
+			rdb->save = save; 
+			if (save) { //clear out old references
+				rdb->clearMemory();	
+			}
+			
+			//this has to go after save so that if the user sets save=t and provides no reference we abort
+			templateFileName = validParameter.validFile(parameters, "reference", true);
+			if (templateFileName == "not found") { 
+				//check for saved reference sequences
+				if (rdb->referenceSeqs.size() != 0) {
+					templateFileName = "saved";
+				}else {
+					m->mothurOut("[ERROR]: You don't have any saved reference sequences and the reference parameter is a required for the classify.seqs command."); 
+					m->mothurOutEndLine();
+					abort = true; 
+				}
+			}else if (templateFileName == "not open") { abort = true; }	
+			else {	if (save) {	rdb->setSavedReference(templateFileName);	}	}
+			
+			//this has to go after save so that if the user sets save=t and provides no reference we abort
+			taxonomyFileName = validParameter.validFile(parameters, "taxonomy", true);
+			if (taxonomyFileName == "not found") { 
+				//check for saved reference sequences
+				if (rdb->wordGenusProb.size() != 0) {
+					taxonomyFileName = "saved";
+				}else {
+					m->mothurOut("[ERROR]: You don't have any saved taxonomy information and the taxonomy parameter is a required for the classify.seqs command."); 
+					m->mothurOutEndLine();
+					abort = true; 
+				}
+			}else if (taxonomyFileName == "not open") { abort = true; }	
+			else {	if (save) {	rdb->setSavedTaxonomy(taxonomyFileName);	}	}
+			
 			search = validParameter.validFile(parameters, "search", false);		if (search == "not found"){	search = "kmer";		}
 			
 			method = validParameter.validFile(parameters, "method", false);		if (method == "not found"){	method = "bayesian";	}
@@ -419,22 +475,24 @@ int ClassifySeqsCommand::execute(){
 	try {
 		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
 		
-		if(method == "bayesian"){	classify = new Bayesian(taxonomyFileName, templateFileName, search, kmerSize, cutoff, iters);		}
-		else if(method == "knn"){	classify = new Knn(taxonomyFileName, templateFileName, search, kmerSize, gapOpen, gapExtend, match, misMatch, numWanted);				}
+		if(method == "bayesian"){	classify = new Bayesian(taxonomyFileName, templateFileName, search, kmerSize, cutoff, iters, rand());		}
+		else if(method == "knn"){	classify = new Knn(taxonomyFileName, templateFileName, search, kmerSize, gapOpen, gapExtend, match, misMatch, numWanted, rand());				}
 		else {
 			m->mothurOut(search + " is not a valid method option. I will run the command using bayesian.");
 			m->mothurOutEndLine();
-			classify = new Bayesian(taxonomyFileName, templateFileName, search, kmerSize, cutoff, iters);	
+			classify = new Bayesian(taxonomyFileName, templateFileName, search, kmerSize, cutoff, iters, rand());	
 		}
 		
 		if (m->control_pressed) { delete classify; return 0; }
-		
 				
 		for (int s = 0; s < fastaFileNames.size(); s++) {
 		
 			m->mothurOut("Classifying sequences from " + fastaFileNames[s] + " ..." ); m->mothurOutEndLine();
 			
-			string RippedTaxName = m->getRootName(m->getSimpleName(taxonomyFileName));
+			string baseTName = taxonomyFileName;
+			if (taxonomyFileName == "saved") {baseTName = rdb->getSavedTaxonomy();	}
+			
+			string RippedTaxName = m->getRootName(m->getSimpleName(baseTName));
 			RippedTaxName = m->getExtension(RippedTaxName.substr(0, RippedTaxName.length()-1));
 			if (RippedTaxName[0] == '.') { RippedTaxName = RippedTaxName.substr(1, RippedTaxName.length()); }
 			RippedTaxName +=  "."; 
@@ -459,7 +517,7 @@ int ClassifySeqsCommand::execute(){
 #ifdef USE_MPI	
 				int pid, numSeqsPerProcessor; 
 				int tag = 2001;
-				vector<unsigned long int> MPIPos;
+				vector<unsigned long long> MPIPos;
 				
 				MPI_Status status; 
 				MPI_Comm_rank(MPI_COMM_WORLD, &pid); //find out who we are
@@ -485,7 +543,7 @@ int ClassifySeqsCommand::execute(){
 				MPI_File_open(MPI_COMM_WORLD, outNewTax, outMode, MPI_INFO_NULL, &outMPINewTax);
 				MPI_File_open(MPI_COMM_WORLD, outTempTax, outMode, MPI_INFO_NULL, &outMPITempTax);
 				
-				if (m->control_pressed) { outputTypes.clear(); MPI_File_close(&inMPI);  MPI_File_close(&outMPINewTax);   MPI_File_close(&outMPITempTax);  delete classify; return 0;  }
+				if (m->control_pressed) { outputTypes.clear(); MPI_File_close(&inMPI);  MPI_File_close(&outMPINewTax);   MPI_File_close(&outMPITempTax);  delete classify;  return 0;  }
 				
 				if (pid == 0) { //you are the root process 
 					
@@ -506,7 +564,7 @@ int ClassifySeqsCommand::execute(){
 					//align your part
 					driverMPI(startIndex, numSeqsPerProcessor, inMPI, outMPINewTax, outMPITempTax, MPIPos);
 					
-					if (m->control_pressed) {  outputTypes.clear(); MPI_File_close(&inMPI);  MPI_File_close(&outMPINewTax);   MPI_File_close(&outMPITempTax);  for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str());	} delete classify; return 0;  }
+					if (m->control_pressed) {  outputTypes.clear(); MPI_File_close(&inMPI);  MPI_File_close(&outMPINewTax);   MPI_File_close(&outMPITempTax);  for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);	} delete classify; return 0;  }
 					
 					for (int i = 1; i < processors; i++) {
 						int done;
@@ -540,25 +598,30 @@ int ClassifySeqsCommand::execute(){
 				
 #else
 		
-			vector<unsigned long int> positions = m->divideFile(fastaFileNames[s], processors);
+			vector<unsigned long long> positions; 
+#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+			positions = m->divideFile(fastaFileNames[s], processors);
+			for (int i = 0; i < (positions.size()-1); i++) {	lines.push_back(new linePair(positions[i], positions[(i+1)]));	}
+#else
+			if (processors == 1) {
+				lines.push_back(new linePair(0, 1000));
+			}else {
+				positions = m->setFilePosFasta(fastaFileNames[s], numFastaSeqs); 
 				
-			for (int i = 0; i < (positions.size()-1); i++) {
-				lines.push_back(new linePair(positions[i], positions[(i+1)]));
-			}	
-			
-		#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
+				//figure out how many sequences you have to process
+				int numSeqsPerProcessor = numFastaSeqs / processors;
+				for (int i = 0; i < processors; i++) {
+					int startIndex =  i * numSeqsPerProcessor;
+					if(i == (processors - 1)){	numSeqsPerProcessor = numFastaSeqs - i * numSeqsPerProcessor; 	}
+					lines.push_back(new linePair(positions[startIndex], numSeqsPerProcessor));
+				}
+			}
+#endif
 			if(processors == 1){
 				numFastaSeqs = driver(lines[0], newTaxonomyFile, tempTaxonomyFile, fastaFileNames[s]);
-			}
-			else{
-				processIDS.resize(0);
-				
+			}else{
 				numFastaSeqs = createProcesses(newTaxonomyFile, tempTaxonomyFile, fastaFileNames[s]); 
-				
 			}
-	#else
-			numFastaSeqs = driver(lines[0], newTaxonomyFile, tempTaxonomyFile, fastaFileNames[s]);
-	#endif	
 #endif
 
 		m->mothurOutEndLine();
@@ -599,9 +662,9 @@ int ClassifySeqsCommand::execute(){
 			string group = "";
 			if (groupfile != "") {  group = groupfileNames[s]; }
 			
-			PhyloSummary taxaSum(taxonomyFileName, group);
+			PhyloSummary taxaSum(baseTName, group);
 			
-			if (m->control_pressed) { outputTypes.clear();  for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str());	} delete classify; return 0; }
+			if (m->control_pressed) { outputTypes.clear();  for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);	} delete classify; return 0; }
 		
 			if (namefile == "") {  taxaSum.summarize(tempTaxonomyFile);  }
 			else {
@@ -628,9 +691,9 @@ int ClassifySeqsCommand::execute(){
 				}
 				in.close();
 			}
-			remove(tempTaxonomyFile.c_str());
+			m->mothurRemove(tempTaxonomyFile);
 			
-			if (m->control_pressed) {  outputTypes.clear(); for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str());	} delete classify; return 0; }
+			if (m->control_pressed) {  outputTypes.clear(); for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);	} delete classify; return 0; }
 			
 			//print summary file
 			ofstream outTaxTree;
@@ -652,7 +715,7 @@ int ClassifySeqsCommand::execute(){
 			//read taxfile - this reading and rewriting is done to preserve the confidence scores.
 			string name, taxon;
 			while (!inTax.eof()) {
-				if (m->control_pressed) { outputTypes.clear();  for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str());	} remove(unclass.c_str()); delete classify; return 0; }
+				if (m->control_pressed) { outputTypes.clear();  for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);	} m->mothurRemove(unclass); delete classify; return 0; }
 
 				inTax >> name >> taxon; m->gobble(inTax);
 				
@@ -663,7 +726,7 @@ int ClassifySeqsCommand::execute(){
 			inTax.close();	
 			outTax.close();
 			
-			remove(newTaxonomyFile.c_str());
+			m->mothurRemove(newTaxonomyFile);
 			rename(unclass.c_str(), newTaxonomyFile.c_str());
 			
 			m->mothurOutEndLine();
@@ -687,6 +750,7 @@ int ClassifySeqsCommand::execute(){
 		}
 		
 		delete classify;
+		
 		return 0;
 	}
 	catch(exception& e) {
@@ -728,9 +792,12 @@ string ClassifySeqsCommand::addUnclassifieds(string tax, int maxlevel) {
 
 int ClassifySeqsCommand::createProcesses(string taxFileName, string tempTaxFile, string filename) {
 	try {
+		
+		int num = 0;
+		processIDS.clear();
+		
 #if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
 		int process = 1;
-		int num = 0;
 		
 		//loop through and create all the processes you want
 		while (process != processors) {
@@ -741,7 +808,7 @@ int ClassifySeqsCommand::createProcesses(string taxFileName, string tempTaxFile,
 				process++;
 			}else if (pid == 0){
 				num = driver(lines[process], taxFileName + toString(getpid()) + ".temp", tempTaxFile + toString(getpid()) + ".temp", filename);
-				
+
 				//pass numSeqs to parent
 				ofstream out;
 				string tempFile = filename + toString(getpid()) + ".num.temp";
@@ -771,18 +838,58 @@ int ClassifySeqsCommand::createProcesses(string taxFileName, string tempTaxFile,
 			string tempFile =  filename + toString(processIDS[i]) + ".num.temp";
 			m->openInputFile(tempFile, in);
 			if (!in.eof()) { int tempNum = 0; in >> tempNum; num += tempNum; }
-			in.close(); remove(tempFile.c_str());
+			in.close(); m->mothurRemove(m->getFullPathName(tempFile));
 		}
+#else
+		//////////////////////////////////////////////////////////////////////////////////////////////////////
+		//Windows version shared memory, so be careful when passing variables through the alignData struct. 
+		//Above fork() will clone, so memory is separate, but that's not the case with windows, 
+		//////////////////////////////////////////////////////////////////////////////////////////////////////
+		
+		vector<classifyData*> pDataArray; 
+		DWORD   dwThreadIdArray[processors-1];
+		HANDLE  hThreadArray[processors-1]; 
+		
+		//Create processor worker threads.
+		for( int i=0; i<processors-1; i++ ){
+			// Allocate memory for thread data.
+			string extension = "";
+			if (i != 0) { extension = toString(i) + ".temp"; processIDS.push_back(i); }
+			
+			classifyData* tempclass = new classifyData(probs, method, templateFileName, taxonomyFileName, (taxFileName + extension), (tempTaxFile + extension), filename, search, kmerSize, iters, numWanted, m, lines[i]->start, lines[i]->end, match, misMatch, gapOpen, gapExtend, cutoff, i);
+			pDataArray.push_back(tempclass);
+			
+			//MySeqSumThreadFunction is in header. It must be global or static to work with the threads.
+			//default security attributes, thread function name, argument to thread function, use default creation flags, returns the thread identifier
+			hThreadArray[i] = CreateThread(NULL, 0, MyClassThreadFunction, pDataArray[i], 0, &dwThreadIdArray[i]);  
+			
+		}
+		
+		//parent does its part
+		num = driver(lines[processors-1], taxFileName + toString(processors-1) + ".temp", tempTaxFile + toString(processors-1) + ".temp", filename);
+		processIDS.push_back((processors-1));
+		
+		//Wait until all threads have terminated.
+		WaitForMultipleObjects(processors-1, hThreadArray, TRUE, INFINITE);
+		
+		//Close all thread handles and free memory allocations.
+		for(int i=0; i < pDataArray.size(); i++){
+			num += pDataArray[i]->count;
+			CloseHandle(hThreadArray[i]);
+			delete pDataArray[i];
+		}
+		
+	#endif	
 		
 		for(int i=0;i<processIDS.size();i++){
 			appendTaxFiles((taxFileName + toString(processIDS[i]) + ".temp"), taxFileName);
 			appendTaxFiles((tempTaxFile + toString(processIDS[i]) + ".temp"), tempTaxFile);
-			remove((taxFileName + toString(processIDS[i]) + ".temp").c_str());
-			remove((tempTaxFile + toString(processIDS[i]) + ".temp").c_str());
+			m->mothurRemove((m->getFullPathName(taxFileName) + toString(processIDS[i]) + ".temp"));
+			m->mothurRemove((m->getFullPathName(tempTaxFile) + toString(processIDS[i]) + ".temp"));
 		}
 		
 		return num;
-#endif		
+		
 	}
 	catch(exception& e) {
 		m->errorOut(e, "ClassifySeqsCommand", "createProcesses");
@@ -859,7 +966,7 @@ int ClassifySeqsCommand::driver(linePair* filePos, string taxFName, string tempT
 			delete candidateSeq;
 			
 			#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
-				unsigned long int pos = inFASTA.tellg();
+				unsigned long long pos = inFASTA.tellg();
 				if ((pos == -1) || (pos >= filePos->end)) { break; }
 			#else
 				if (inFASTA.eof()) { break; }
@@ -885,7 +992,7 @@ int ClassifySeqsCommand::driver(linePair* filePos, string taxFName, string tempT
 }
 //**********************************************************************************************************************
 #ifdef USE_MPI
-int ClassifySeqsCommand::driverMPI(int start, int num, MPI_File& inMPI, MPI_File& newFile, MPI_File& tempFile, vector<unsigned long int>& MPIPos){
+int ClassifySeqsCommand::driverMPI(int start, int num, MPI_File& inMPI, MPI_File& newFile, MPI_File& tempFile, vector<unsigned long long>& MPIPos){
 	try {
 		MPI_Status statusNew; 
 		MPI_Status statusTemp; 
