@@ -124,7 +124,8 @@ CollectCommand::CollectCommand(string option)  {
 		allLines = 1;
 		
 		//allow user to run help
-		if(option == "help") { help(); abort = true; }
+		if(option == "help") { help(); calledHelp = true; abort = true; }
+		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
 		
 		else {
 			vector<string> myArray = setParameters();
@@ -210,22 +211,22 @@ CollectCommand::CollectCommand(string option)  {
 			listfile = validParameter.validFile(parameters, "list", true);
 			if (listfile == "not open") { listfile = ""; abort = true; }
 			else if (listfile == "not found") { listfile = ""; }
-			else {  format = "list"; inputfile = listfile; }
+			else {  format = "list"; inputfile = listfile; m->setListFile(listfile); }
 			
 			sabundfile = validParameter.validFile(parameters, "sabund", true);
 			if (sabundfile == "not open") { sabundfile = ""; abort = true; }	
 			else if (sabundfile == "not found") { sabundfile = ""; }
-			else {  format = "sabund"; inputfile = sabundfile; }
+			else {  format = "sabund"; inputfile = sabundfile; m->setSabundFile(sabundfile); }
 			
 			rabundfile = validParameter.validFile(parameters, "rabund", true);
 			if (rabundfile == "not open") { rabundfile = ""; abort = true; }	
 			else if (rabundfile == "not found") { rabundfile = ""; }
-			else {  format = "rabund"; inputfile = rabundfile; }
+			else {  format = "rabund"; inputfile = rabundfile; m->setRabundFile(rabundfile); }
 			
 			sharedfile = validParameter.validFile(parameters, "shared", true);
 			if (sharedfile == "not open") { sharedfile = ""; abort = true; }	
 			else if (sharedfile == "not found") { sharedfile = ""; }
-			else {  format = "sharedfile"; inputfile = sharedfile; }
+			else {  format = "sharedfile"; inputfile = sharedfile; m->setSharedFile(sharedfile); }
 			
 			
 			//if the user changes the output directory command factory will send this info to us in the output parameter 
@@ -271,6 +272,11 @@ CollectCommand::CollectCommand(string option)  {
 				 if (calc == "default")  {  calc = "sobs-chao-ace-jack-shannon-npshannon-simpson";  }
 			}
 			m->splitAtDash(calc, Estimators);
+			if (m->inUsersGroups("citation", Estimators)) { 
+				ValidCalculators validCalc; validCalc.printCitations(Estimators); 
+				//remove citation from list of calcs
+				for (int i = 0; i < Estimators.size(); i++) { if (Estimators[i] == "citation") {  Estimators.erase(Estimators.begin()+i); break; } }
+			}
 
 			string temp;
 			temp = validParameter.validFile(parameters, "freq", false);			if (temp == "not found") { temp = "100"; }
@@ -301,7 +307,7 @@ int CollectCommand::execute(){
 	
 		for (int p = 0; p < inputFileNames.size(); p++) {
 			
-			if (m->control_pressed) {  outputTypes.clear(); for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); 	}  m->Groups.clear();  return 0; }
+			if (m->control_pressed) {  outputTypes.clear(); for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); 	}  m->clearGroups();  return 0; }
 			
 			if (outputDir == "") { outputDir += m->hasPath(inputFileNames[p]); }
 			string fileNameRoot = outputDir + m->getRootName(m->getSimpleName(inputFileNames[p]));
@@ -407,10 +413,10 @@ int CollectCommand::execute(){
 			
 			if (m->control_pressed) {  
 				for(int i=0;i<cDisplays.size();i++){	delete cDisplays[i];	}
-				for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); 	} outputTypes.clear(); 
+				for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); 	} outputTypes.clear(); 
 				delete input;  
 				delete order; 
-				m->Groups.clear();
+				m->clearGroups();
 				return 0;
 			}
 
@@ -419,10 +425,10 @@ int CollectCommand::execute(){
 			
 				if (m->control_pressed) { 
 					for(int i=0;i<cDisplays.size();i++){	delete cDisplays[i];	}
-					for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); 	} outputTypes.clear(); 
+					for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); 	} outputTypes.clear(); 
 					delete input;  
 					delete order; 
-					m->Groups.clear();
+					m->clearGroups();
 					return 0;
 				}
 
@@ -468,9 +474,9 @@ int CollectCommand::execute(){
 			
 			if (m->control_pressed) { 
 					for(int i=0;i<cDisplays.size();i++){	delete cDisplays[i];	}
-					for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); 	} outputTypes.clear(); 
+					for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); 	} outputTypes.clear(); 
 					delete input;  
-					m->Groups.clear();
+					m->clearGroups();
 					return 0;
 			}
 				
@@ -500,10 +506,10 @@ int CollectCommand::execute(){
 				
 				if (m->control_pressed) { 
 					for(int i=0;i<cDisplays.size();i++){	delete cDisplays[i];	}
-					for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); 	} outputTypes.clear(); 
+					for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); 	} outputTypes.clear(); 
 					delete input;  
 					delete order;
-					m->Groups.clear();
+					m->clearGroups();
 					return 0;
 				}
 				delete order;
@@ -514,7 +520,7 @@ int CollectCommand::execute(){
 			delete input;  
 		}
 		
-		if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); 	} return 0; }
+		if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); 	} return 0; }
 				
 		m->mothurOutEndLine();
 		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
@@ -545,7 +551,7 @@ vector<string> CollectCommand::parseSharedFile(string filename) {
 		
 		//clears file before we start to write to it below
 		for (int i=0; i<lookup.size(); i++) {
-			remove((sharedFileRoot + lookup[i]->getGroup() + ".rabund").c_str());
+			m->mothurRemove((sharedFileRoot + lookup[i]->getGroup() + ".rabund"));
 			filenames.push_back((sharedFileRoot + lookup[i]->getGroup() + ".rabund"));
 		}
 		
