@@ -69,6 +69,7 @@
 #include "chimeraslayercommand.h"
 #include "chimerapintailcommand.h"
 #include "chimerabellerophoncommand.h"
+#include "chimerauchimecommand.h"
 #include "setlogfilecommand.h"
 #include "phylodiversitycommand.h"
 #include "makegroupcommand.h"
@@ -117,6 +118,11 @@
 #include "setcurrentcommand.h"
 #include "sharedcommand.h"
 #include "getcommandinfocommand.h"
+#include "deuniquetreecommand.h"
+#include "countseqscommand.h"
+#include "countgroupscommand.h"
+#include "clearmemorycommand.h"
+#include "summarytaxcommand.h"
 
 /*******************************************************/
 
@@ -184,7 +190,7 @@ CommandFactory::CommandFactory(){
 	commands["trim.flows"]			= "trim.flows";
 	commands["list.seqs"]			= "list.seqs";
 	commands["get.seqs"]			= "get.seqs";
-	commands["remove.seqs"]			= "get.seqs";
+	commands["remove.seqs"]			= "remove.seqs";
 	commands["system"]				= "system";
 	commands["align.check"]			= "align.check";
 	commands["get.sharedseqs"]		= "get.sharedseqs";
@@ -238,6 +244,10 @@ CommandFactory::CommandFactory(){
 	commands["get.current"]			= "get.current";
 	commands["set.current"]			= "set.current";
 	commands["get.commandinfo"]		= "get.commandinfo";
+	commands["deunique.tree"]		= "deunique.tree";
+	commands["count.seqs"]			= "count.seqs";
+	commands["count.groups"]		= "count.groups";
+	commands["clear.memory"]		= "clear.memory";
 	commands["pairwise.seqs"]		= "MPIEnabled";
 	commands["pipeline.pds"]		= "MPIEnabled";
 	commands["classify.seqs"]		= "MPIEnabled"; 
@@ -247,14 +257,16 @@ CommandFactory::CommandFactory(){
 	commands["chimera.ccode"]		= "MPIEnabled";
 	commands["chimera.check"]		= "MPIEnabled";
 	commands["chimera.slayer"]		= "MPIEnabled";
+	commands["chimera.uchime"]		= "chimera.uchime";
 	commands["chimera.pintail"]		= "MPIEnabled";
 	commands["chimera.bellerophon"]	= "MPIEnabled";
 	commands["screen.seqs"]			= "MPIEnabled";
 	commands["summary.seqs"]		= "MPIEnabled";
 	commands["cluster.split"]		= "MPIEnabled";
-	commands["shhh.seqs"]			= "MPIEnabled";
+	commands["shhh.flows"]			= "MPIEnabled";
 	commands["sens.spec"]			= "sens.spec";
 	commands["seq.error"]			= "seq.error";
+	commands["seq.error"]			= "summary.tax";
 	commands["quit"]				= "MPIEnabled"; 
 
 }
@@ -337,7 +349,7 @@ Command* CommandFactory::getCommand(string commandName, string optionString){
 		else if(commandName == "reverse.seqs")			{	command = new ReverseSeqsCommand(optionString);				}
 		else if(commandName == "trim.seqs")				{	command = new TrimSeqsCommand(optionString);				}
 		else if(commandName == "trim.flows")			{	command = new TrimFlowsCommand(optionString);				}
-		else if(commandName == "shhh.seqs")				{	command = new ShhherCommand(optionString);					}
+		else if(commandName == "shhh.flows")			{	command = new ShhherCommand(optionString);					}
 		else if(commandName == "list.seqs")				{	command = new ListSeqsCommand(optionString);				}
 		else if(commandName == "get.seqs")				{	command = new GetSeqsCommand(optionString);					}
 		else if(commandName == "remove.seqs")			{	command = new RemoveSeqsCommand(optionString);				}
@@ -351,6 +363,7 @@ Command* CommandFactory::getCommand(string commandName, string optionString){
 		else if(commandName == "chimera.ccode")			{	command = new ChimeraCcodeCommand(optionString);			}
 		else if(commandName == "chimera.check")			{	command = new ChimeraCheckCommand(optionString);			}
 		else if(commandName == "chimera.slayer")		{	command = new ChimeraSlayerCommand(optionString);			}
+		else if(commandName == "chimera.uchime")		{	command = new ChimeraUchimeCommand(optionString);			}
 		else if(commandName == "chimera.pintail")		{	command = new ChimeraPintailCommand(optionString);			}
 		else if(commandName == "chimera.bellerophon")	{	command = new ChimeraBellerophonCommand(optionString);		}
 		else if(commandName == "phylotype")				{	command = new PhylotypeCommand(optionString);				}
@@ -406,6 +419,11 @@ Command* CommandFactory::getCommand(string commandName, string optionString){
 		else if(commandName == "anosim")				{	command = new AnosimCommand(optionString);					}
 		else if(commandName == "make.shared")			{	command = new SharedCommand(optionString);					}
 		else if(commandName == "get.commandinfo")		{	command = new GetCommandInfoCommand(optionString);			}
+		else if(commandName == "deunique.tree")			{	command = new DeuniqueTreeCommand(optionString);			}
+		else if(commandName == "count.seqs")			{	command = new CountSeqsCommand(optionString);				}
+		else if(commandName == "count.groups")			{	command = new CountGroupsCommand(optionString);				}
+		else if(commandName == "clear.memory")			{	command = new ClearMemoryCommand(optionString);				}
+		else if(commandName == "summary.tax")			{	command = new SummaryTaxCommand(optionString);				}
 		else											{	command = new NoCommand(optionString);						}
 
 		return command;
@@ -473,7 +491,7 @@ Command* CommandFactory::getCommand(string commandName, string optionString, str
 		else if(commandName == "reverse.seqs")			{	pipecommand = new ReverseSeqsCommand(optionString);				}
 		else if(commandName == "trim.seqs")				{	pipecommand = new TrimSeqsCommand(optionString);				}
 		else if(commandName == "trim.flows")			{	pipecommand = new TrimFlowsCommand(optionString);				}
-		else if(commandName == "shhh.seqs")				{	pipecommand = new ShhherCommand(optionString);					}
+		else if(commandName == "shhh.flows")			{	pipecommand = new ShhherCommand(optionString);					}
 		else if(commandName == "list.seqs")				{	pipecommand = new ListSeqsCommand(optionString);				}
 		else if(commandName == "get.seqs")				{	pipecommand = new GetSeqsCommand(optionString);					}
 		else if(commandName == "remove.seqs")			{	pipecommand = new RemoveSeqsCommand(optionString);				}
@@ -486,6 +504,7 @@ Command* CommandFactory::getCommand(string commandName, string optionString, str
 		else if(commandName == "classify.seqs")			{	pipecommand = new ClassifySeqsCommand(optionString);			}
 		else if(commandName == "chimera.ccode")			{	pipecommand = new ChimeraCcodeCommand(optionString);			}
 		else if(commandName == "chimera.check")			{	pipecommand = new ChimeraCheckCommand(optionString);			}
+		else if(commandName == "chimera.uchime")		{	pipecommand = new ChimeraUchimeCommand(optionString);			}
 		else if(commandName == "chimera.slayer")		{	pipecommand = new ChimeraSlayerCommand(optionString);			}
 		else if(commandName == "chimera.pintail")		{	pipecommand = new ChimeraPintailCommand(optionString);			}
 		else if(commandName == "chimera.bellerophon")	{	pipecommand = new ChimeraBellerophonCommand(optionString);		}
@@ -541,6 +560,11 @@ Command* CommandFactory::getCommand(string commandName, string optionString, str
 		else if(commandName == "set.current")			{	pipecommand = new SetCurrentCommand(optionString);				}
 		else if(commandName == "make.shared")			{	pipecommand = new SharedCommand(optionString);					}
 		else if(commandName == "get.commandinfo")		{	pipecommand = new GetCommandInfoCommand(optionString);			}
+		else if(commandName == "deunique.tree")			{	pipecommand = new DeuniqueTreeCommand(optionString);			}
+		else if(commandName == "count.seqs")			{	pipecommand = new CountSeqsCommand(optionString);				}
+		else if(commandName == "count.groups")			{	pipecommand = new CountGroupsCommand(optionString);				}
+		else if(commandName == "clear.memory")			{	pipecommand = new ClearMemoryCommand(optionString);				}
+		else if(commandName == "summary.tax")			{	pipecommand = new SummaryTaxCommand(optionString);				}
 		else											{	pipecommand = new NoCommand(optionString);						}
 
 		return pipecommand;
@@ -596,7 +620,7 @@ Command* CommandFactory::getCommand(string commandName){
 		else if(commandName == "reverse.seqs")			{	shellcommand = new ReverseSeqsCommand();			}
 		else if(commandName == "trim.seqs")				{	shellcommand = new TrimSeqsCommand();				}
 		else if(commandName == "trim.flows")			{	shellcommand = new TrimFlowsCommand();				}
-		else if(commandName == "shhh.seqs")				{	shellcommand = new ShhherCommand();					}
+		else if(commandName == "shhh.flows")			{	shellcommand = new ShhherCommand();					}
 		else if(commandName == "list.seqs")				{	shellcommand = new ListSeqsCommand();				}
 		else if(commandName == "get.seqs")				{	shellcommand = new GetSeqsCommand();				}
 		else if(commandName == "remove.seqs")			{	shellcommand = new RemoveSeqsCommand();				}
@@ -610,6 +634,7 @@ Command* CommandFactory::getCommand(string commandName){
 		else if(commandName == "chimera.ccode")			{	shellcommand = new ChimeraCcodeCommand();			}
 		else if(commandName == "chimera.check")			{	shellcommand = new ChimeraCheckCommand();			}
 		else if(commandName == "chimera.slayer")		{	shellcommand = new ChimeraSlayerCommand();			}
+		else if(commandName == "chimera.uchime")		{	shellcommand = new ChimeraUchimeCommand();			}
 		else if(commandName == "chimera.pintail")		{	shellcommand = new ChimeraPintailCommand();			}
 		else if(commandName == "chimera.bellerophon")	{	shellcommand = new ChimeraBellerophonCommand();		}
 		else if(commandName == "phylotype")				{	shellcommand = new PhylotypeCommand();				}
@@ -664,6 +689,11 @@ Command* CommandFactory::getCommand(string commandName){
 		else if(commandName == "set.current")			{	shellcommand = new SetCurrentCommand();				}
 		else if(commandName == "make.shared")			{	shellcommand = new SharedCommand();					}
 		else if(commandName == "get.commandinfo")		{	shellcommand = new GetCommandInfoCommand();			}
+		else if(commandName == "deunique.tree")			{	shellcommand = new DeuniqueTreeCommand();			}
+		else if(commandName == "count.seqs")			{	shellcommand = new CountSeqsCommand();				}
+		else if(commandName == "count.groups")			{	shellcommand = new CountGroupsCommand();			}
+		else if(commandName == "clear.memory")			{	shellcommand = new ClearMemoryCommand();			}
+		else if(commandName == "summary.tax")			{	shellcommand = new SummaryTaxCommand();				}
 		else											{	shellcommand = new NoCommand();						}
 
 		return shellcommand;
