@@ -18,6 +18,7 @@ vector<string> ConsensusSeqsCommand::setParameters(){
 		CommandParameter pname("name", "InputTypes", "", "", "none", "none", "none",false,false); parameters.push_back(pname);
 		CommandParameter plist("list", "InputTypes", "", "", "none", "none", "none",false,false); parameters.push_back(plist);
 		CommandParameter plabel("label", "String", "", "", "", "", "",false,false); parameters.push_back(plabel);
+		CommandParameter pcutoff("cutoff", "Number", "", "100", "", "", "",false,false); parameters.push_back(pcutoff);
 		CommandParameter pinputdir("inputdir", "String", "", "", "", "", "",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "",false,false); parameters.push_back(poutputdir);
 		
@@ -35,11 +36,12 @@ string ConsensusSeqsCommand::getHelpString(){
 	try {
 		string helpString = "";
 		helpString += "The consensus.seqs command can be used in 2 ways: create a consensus sequence from a fastafile, or with a listfile create a consensus sequence for each otu. Sequences must be aligned.\n";
-		helpString += "The consensus.seqs command parameters are fasta, list, name and label.\n";
+		helpString += "The consensus.seqs command parameters are fasta, list, name, cutoff and label.\n";
 		helpString += "The fasta parameter allows you to enter the fasta file containing your sequences, and is required, unless you have a valid current fasta file. \n";
 		helpString += "The list parameter allows you to enter a your list file. \n";
 		helpString += "The name parameter allows you to enter a names file associated with the fasta file. \n";
 		helpString += "The label parameter allows you to select what distance levels you would like output files for, and are separated by dashes.\n";
+		helpString += "The cutoff parameter allows you set a percentage of sequences that support the base. For example: cutoff=97 would only return a sequence that only showed ambiguities for bases that were not supported by at least 97% of sequences.\n";
 		helpString += "The consensus.seqs command should be in the following format: \n";
 		helpString += "consensus.seqs(fasta=yourFastaFile, list=yourListFile) \n";	
 		helpString += "Example: consensus.seqs(fasta=abrecovery.align, list=abrecovery.fn.list) \n";
@@ -75,6 +77,7 @@ ConsensusSeqsCommand::ConsensusSeqsCommand(string option)  {
 		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
+		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
 		
 		else {
 			
@@ -136,15 +139,17 @@ ConsensusSeqsCommand::ConsensusSeqsCommand(string option)  {
 				fastafile = m->getFastaFile(); 
 				if (fastafile != "") { m->mothurOut("Using " + fastafile + " as input file for the fasta parameter."); m->mothurOutEndLine(); }
 				else { 	m->mothurOut("You have no current fastafile and the fasta parameter is required."); m->mothurOutEndLine(); abort = true; }
-			}	
+			}else { m->setFastaFile(fastafile); }	
 			
 			namefile = validParameter.validFile(parameters, "name", true);
 			if (namefile == "not open") { abort = true; }
-			else if (namefile == "not found") { namefile = ""; }	
+			else if (namefile == "not found") { namefile = ""; }
+			else { m->setNameFile(namefile); }
 			
 			listfile = validParameter.validFile(parameters, "list", true);
 			if (listfile == "not open") { abort = true; }
 			else if (listfile == "not found") { listfile = "";  }	
+			else { m->setListFile(listfile); }
 			
 			label = validParameter.validFile(parameters, "label", false);			
 			if (label == "not found") { label = ""; }
@@ -153,6 +158,9 @@ ConsensusSeqsCommand::ConsensusSeqsCommand(string option)  {
 				else { allLines = 1;  }
 			}
 			
+			string temp = validParameter.validFile(parameters, "cutoff", false);  if (temp == "not found") { temp = "100"; }
+			convert(temp, cutoff); 
+			
 			//if the user changes the output directory command factory will send this info to us in the output parameter 
 			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	outputDir = m->hasPath(fastafile);	}
 
@@ -198,7 +206,7 @@ int ConsensusSeqsCommand::execute(){
 			int seqLength = 0;
 			for (map<string, string>::iterator it = nameMap.begin(); it != nameMap.end(); it++) {
 				
-				if (m->control_pressed) { outSummary.close(); outFasta.close(); for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); } return 0; }
+				if (m->control_pressed) { outSummary.close(); outFasta.close(); for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0; }
 				
 				string seq = fastaMap[it->second];
 				seqs.push_back(seq);
@@ -215,7 +223,7 @@ int ConsensusSeqsCommand::execute(){
 			//get counts
 			for (int j = 0; j < seqLength; j++) {
 				
-				if (m->control_pressed) { outSummary.close(); outFasta.close(); for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); } return 0; }
+				if (m->control_pressed) { outSummary.close(); outFasta.close(); for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0; }
 				
 				vector<int> counts; counts.resize(5, 0); //A,T,G,C,Gap
 				int numDots = 0;
@@ -233,7 +241,7 @@ int ConsensusSeqsCommand::execute(){
 				}
 				
 				char conBase = '.';
-				if (numDots != seqs.size()) { conBase = getBase(counts); }
+				if (numDots != seqs.size()) { conBase = getBase(counts, seqs.size()); }
 				
 				consSeq += conBase;
 				
@@ -268,7 +276,7 @@ int ConsensusSeqsCommand::execute(){
 			//as long as you are not at the end of the file or done wih the lines you want
 			while((list != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
 				
-				if (m->control_pressed) {  for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); } delete list; delete input;  return 0;  }
+				if (m->control_pressed) {  for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } delete list; delete input;  return 0;  }
 				
 				if(allLines == 1 || labels.count(list->getLabel()) == 1){			
 					
@@ -306,7 +314,7 @@ int ConsensusSeqsCommand::execute(){
 			}
 			
 			
-			if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); } if (list != NULL) { delete list; } delete input; return 0;  }
+			if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } if (list != NULL) { delete list; } delete input; return 0;  }
 			
 			//output error messages about any remaining user labels
 			set<string>::iterator it;
@@ -476,7 +484,7 @@ string ConsensusSeqsCommand::getConsSeq(string bin, ofstream& outSummary, string
 			}
 			
 			char conBase = '.';
-			if (numDots != seqs.size()) { conBase = getBase(counts); }
+			if (numDots != seqs.size()) { conBase = getBase(counts, seqs.size()); }
 			
 			consSeq += conBase;
 			
@@ -502,7 +510,7 @@ string ConsensusSeqsCommand::getConsSeq(string bin, ofstream& outSummary, string
 }
 //***************************************************************************************************************
 
-char ConsensusSeqsCommand::getBase(vector<int> counts){  //A,T,G,C,Gap
+char ConsensusSeqsCommand::getBase(vector<int> counts, int size){  //A,T,G,C,Gap
 	try{
 		/* A = adenine
 		* C = cytosine
@@ -522,6 +530,14 @@ char ConsensusSeqsCommand::getBase(vector<int> counts){  //A,T,G,C,Gap
 		
 		char conBase = 'N';
 		
+		//zero out counts that don't make the cutoff
+		float percentage = (100.0 - cutoff) / 100.0;
+		int zeroCutoff = percentage * size;
+		
+		for (int i = 0; i < counts.size(); i++) {
+			if (counts[i] < zeroCutoff) { counts[i] = 0; }
+		}
+		
 		//any
 		if ((counts[0] != 0) && (counts[1] != 0) && (counts[2] != 0) && (counts[3] != 0) && (counts[4] != 0)) {  conBase = 'n'; }
 		//any no gap
@@ -584,6 +600,8 @@ char ConsensusSeqsCommand::getBase(vector<int> counts){  //A,T,G,C,Gap
 		else if ((counts[0] == 0) && (counts[1] == 0) && (counts[2] == 0) && (counts[3] != 0) && (counts[4] == 0)) {  conBase = 'C'; }	
 		//only gap
 		else if ((counts[0] == 0) && (counts[1] == 0) && (counts[2] == 0) && (counts[3] == 0) && (counts[4] != 0)) {  conBase = '-'; }
+		//cutoff removed all counts
+		else if ((counts[0] == 0) && (counts[1] == 0) && (counts[2] == 0) && (counts[3] == 0) && (counts[4] == 0)) {  conBase = 'N'; }
 		else{ m->mothurOut("[ERROR]: cannot find consensus base."); m->mothurOutEndLine(); }
 		
 		return conBase;
