@@ -74,6 +74,7 @@ CorrAxesCommand::CorrAxesCommand(string option)  {
 		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
+		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
 		
 		else {
 			vector<string> myArray = setParameters();
@@ -139,12 +140,12 @@ CorrAxesCommand::CorrAxesCommand(string option)  {
 			sharedfile = validParameter.validFile(parameters, "shared", true);
 			if (sharedfile == "not open") { abort = true; }
 			else if (sharedfile == "not found") { sharedfile = ""; }
-			else { inputFileName = sharedfile; }
+			else { inputFileName = sharedfile; m->setSharedFile(sharedfile); }
 			
 			relabundfile = validParameter.validFile(parameters, "relabund", true);
 			if (relabundfile == "not open") { abort = true; }
 			else if (relabundfile == "not found") { relabundfile = ""; }
-			else { inputFileName = relabundfile; }
+			else { inputFileName = relabundfile; m->setRelAbundFile(relabundfile); }
 			
 			metadatafile = validParameter.validFile(parameters, "metadata", true);
 			if (metadatafile == "not open") { abort = true; }
@@ -157,7 +158,7 @@ CorrAxesCommand::CorrAxesCommand(string option)  {
 				pickedGroups = true;
 				m->splitAtDash(groups, Groups);	
 			}			
-			m->Groups = Groups;
+			m->setGroups(Groups);
 			
 			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	outputDir = m->hasPath(inputFileName);	}
 			
@@ -758,6 +759,8 @@ int CorrAxesCommand::eliminateZeroOTUS(vector<SharedRAbundFloatVector*>& thisloo
 		}
 		
 		//for each bin
+		vector<string> newBinLabels;
+		string snumBins = toString(thislookup[0]->getNumBins());
 		for (int i = 0; i < thislookup[0]->getNumBins(); i++) {
 			if (m->control_pressed) { for (int j = 0; j < newLookup.size(); j++) {  delete newLookup[j];  } return 0; }
 			
@@ -772,12 +775,25 @@ int CorrAxesCommand::eliminateZeroOTUS(vector<SharedRAbundFloatVector*>& thisloo
 				for (int j = 0; j < thislookup.size(); j++) {
 					newLookup[j]->push_back(thislookup[j]->getAbundance(i), thislookup[j]->getGroup());
 				}
+				
+				//if there is a bin label use it otherwise make one
+				string binLabel = "Otu";
+				string sbinNumber = toString(i+1);
+				if (sbinNumber.length() < snumBins.length()) { 
+					int diff = snumBins.length() - sbinNumber.length();
+					for (int h = 0; h < diff; h++) { binLabel += "0"; }
+				}
+				binLabel += sbinNumber; 
+				if (i < m->currentBinLabels.size()) {  binLabel = m->currentBinLabels[i]; }
+				
+				newBinLabels.push_back(binLabel);
 			}
 		}
 		
 		for (int j = 0; j < thislookup.size(); j++) {  delete thislookup[j];  }
 		
 		thislookup = newLookup;
+		m->currentBinLabels = newBinLabels;
 		
 		return 0;
 		
@@ -862,14 +878,14 @@ int CorrAxesCommand::getMetadata(){
 		//read the first label, because it refers to the groups
 		string columnLabel;
 		iss >> columnLabel; m->gobble(iss); 
-
+		
 		//save names of columns you are reading
 		while (!iss.eof()) {
 			iss >> columnLabel; m->gobble(iss);
 			metadataLabels.push_back(columnLabel);
 		}
 		int count = metadataLabels.size();
-		
+			
 		//read rest of file
 		while (!in.eof()) {
 			
@@ -878,7 +894,7 @@ int CorrAxesCommand::getMetadata(){
 			string group = "";
 			in >> group; m->gobble(in);
 			groupNames.push_back(group);
-			
+				
 			SharedRAbundFloatVector* tempLookup = new SharedRAbundFloatVector();
 			tempLookup->setGroup(group);
 			tempLookup->setLabel("1");
@@ -886,7 +902,6 @@ int CorrAxesCommand::getMetadata(){
 			for (int i = 0; i < count; i++) {
 				float temp = 0.0;
 				in >> temp; 
-				
 				tempLookup->push_back(temp, group);
 			}
 			
@@ -899,12 +914,13 @@ int CorrAxesCommand::getMetadata(){
 		//remove any groups the user does not want, and set globaldata->groups with only valid groups
 		SharedUtil* util;
 		util = new SharedUtil();
-		
-		util->setGroups(m->Groups, groupNames);
+		Groups = m->getGroups();
+		util->setGroups(Groups, groupNames);
+		m->setGroups(Groups);
 		
 		for (int i = 0; i < lookupFloat.size(); i++) {
 			//if this sharedrabund is not from a group the user wants then delete it.
-			if (util->isValidGroup(lookupFloat[i]->getGroup(), m->Groups) == false) { 
+			if (util->isValidGroup(lookupFloat[i]->getGroup(), m->getGroups()) == false) { 
 				delete lookupFloat[i]; lookupFloat[i] = NULL;
 				lookupFloat.erase(lookupFloat.begin()+i); 
 				i--; 
