@@ -17,6 +17,10 @@
 class eachGapDist : public Dist {
 	
 public:
+	
+	eachGapDist() {}
+	eachGapDist(const eachGapDist& ddb) {}
+	
 	void calcDist(Sequence A, Sequence B){		
 		int diff = 0;
 		int length = 0;
