@@ -23,6 +23,9 @@ class GetCurrentCommand : public Command {
 		string getCommandName()			{ return "get.current";	}
 		string getCommandCategory()		{ return "General";		}
 		string getHelpString();	
+		string getCitation() { return "http://www.mothur.org/wiki/Get.current"; }
+		string getDescription()		{ return "get current files saved by mothur"; }
+
 	
 		int execute(); 
 		void help() { m->mothurOut(getHelpString()); }	
