@@ -26,6 +26,9 @@ public:
 	string getCommandName()			{ return "get.groups";				}
 	string getCommandCategory()		{ return "OTU-Based Approaches";	}
 	string getHelpString();	
+	string getCitation() { return "http://www.mothur.org/wiki/Get.groups"; }
+	string getDescription()		{ return "gets sequences from a list, fasta, name, group or taxonomy file from a given group or set of groups"; }
+
 	
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
@@ -33,7 +36,7 @@ public:
 	
 private:
 	set<string> names;
-	string accnosfile, fastafile, namefile, groupfile, listfile, taxfile, outputDir, groups;
+	string accnosfile, fastafile, namefile, groupfile, listfile, taxfile, outputDir, groups, sharedfile;
 	bool abort;
 	vector<string> outputNames, Groups;
 	GroupMap* groupMap;
@@ -45,6 +48,7 @@ private:
 	int readList();
 	int readTax();
 	int fillNames();
+	int readShared();
 	
 };
 
