@@ -24,6 +24,9 @@ class GetLineageCommand : public Command {
 		string getCommandName()			{ return "get.lineage";				}
 		string getCommandCategory()		{ return "Phylotype Analysis";		}
 		string getHelpString();	
+		string getCitation() { return "http://www.mothur.org/wiki/Get.lineage"; }
+		string getDescription()		{ return "gets sequences from a list, fasta, name, group, alignreport or taxonomy file from a given taxonomy or set of taxonomies"; }
+
 	
 		int execute(); 
 		void help() { m->mothurOut(getHelpString()); }	
@@ -31,7 +34,7 @@ class GetLineageCommand : public Command {
 	
 	private:
 		set<string> names;
-		vector<string> outputNames;
+		vector<string> outputNames, listOfTaxons;
 		string fastafile, namefile, groupfile, alignfile, listfile, taxfile, outputDir, taxons;
 		bool abort, dups;
 		
