@@ -259,7 +259,7 @@ void HCluster::updateArrayandLinkTable() {
 	}
 }
 /***********************************************************************/
-bool HCluster::update(int row, int col, float distance){
+double HCluster::update(int row, int col, float distance){
 	try {
 		bool cluster = false;
 		smallRow = row;
@@ -296,7 +296,7 @@ bool HCluster::update(int row, int col, float distance){
 			}
 		}
 		
-		return cluster;
+		return cutoff;
 		//printInfo();
 	}
 	catch(exception& e) {
@@ -430,7 +430,6 @@ vector<seqDist> HCluster::getSeqsFNNN(){
 	}
 }
 //**********************************************************************************************************************
-//don't need cutoff since processFile removes all distance above cutoff and changes names to indexes
 vector<seqDist> HCluster::getSeqsAN(){
 	try {
 		int firstName, secondName;
@@ -552,7 +551,7 @@ int HCluster::combineFile() {
 			   
 			   in >> first >> second >> dist; m->gobble(in);
 			   
-			   if (m->control_pressed) { in.close(); out.close(); remove(tempDistFile.c_str()); return 0; }
+			   if (m->control_pressed) { in.close(); out.close(); m->mothurRemove(tempDistFile); return 0; }
 			   
 			   //while there are still values in mergedMin that are smaller than the distance read from file
 			   while (count < mergedMin.size())  {
@@ -572,7 +571,9 @@ int HCluster::combineFile() {
 							smallRowColValues[0][mergedMin[count].seq1] = mergedMin[count].dist;
 						}else { //if no, write to temp file
 							//outputString += toString(mergedMin[count].seq1) + '\t' + toString(mergedMin[count].seq2) + '\t' + toString(mergedMin[count].dist) + '\n';
-							out << mergedMin[count].seq1 << '\t' << mergedMin[count].seq2 << '\t' << mergedMin[count].dist << endl;
+							//if (mergedMin[count].dist < cutoff) { 
+								out << mergedMin[count].seq1 << '\t' << mergedMin[count].seq2 << '\t' << mergedMin[count].dist << endl;
+							//}
 						}
 						count++;
 					}else{   break;	}
@@ -592,7 +593,9 @@ int HCluster::combineFile() {
 			   
 			   }else { //if no, write to temp file
 					//outputString += toString(first) + '\t' + toString(second) + '\t' + toString(dist) + '\n';
-					out << first << '\t' << second << '\t' << dist << endl;
+				   //if (dist < cutoff) {
+					   out << first << '\t' << second << '\t' << dist << endl;
+				   //}
 			   }
 			}
 			
@@ -617,7 +620,9 @@ int HCluster::combineFile() {
 				smallRowColValues[0][mergedMin[count].seq1] = mergedMin[count].dist;
 				
 			}else { //if no, write to temp file
-				out << mergedMin[count].seq1 << '\t' << mergedMin[count].seq2 << '\t' << mergedMin[count].dist << endl;
+				//if (mergedMin[count].dist < cutoff) {
+					out << mergedMin[count].seq1 << '\t' << mergedMin[count].seq2 << '\t' << mergedMin[count].dist << endl;
+				//}
 			}
 			count++;
 		}
@@ -625,7 +630,7 @@ int HCluster::combineFile() {
 		mergedMin.clear();
 			
 		//rename tempfile to distfile
-		remove(distfile.c_str());
+		m->mothurRemove(distfile);
 		rename(tempDistFile.c_str(), distfile.c_str());
 //cout << "remove = "<< renameOK << " rename = " << ok << endl;	
 
@@ -650,9 +655,17 @@ int HCluster::combineFile() {
 				
 				seqDist temp(clusterArray[smallRow].parent, itMerge->first, average);
 				mergedMin.push_back(temp);
+			}else {  
+				//can't find value so update cutoff
+				if (cutoff > itMerge->second) { cutoff = itMerge->second; }
 			}
 		}
-
+		
+		//update cutoff
+		for(itMerge = smallRowColValues[1].begin(); itMerge != smallRowColValues[1].end(); itMerge++) {	
+			if (cutoff > itMerge->second) { cutoff = itMerge->second; }
+		}
+		
 		//sort merged values
 		sort(mergedMin.begin(), mergedMin.end(), compareSequenceDistance);	
 		
@@ -754,7 +767,7 @@ int HCluster::processFile() {
 	
 		//get entry
 		while (!in.eof()) {
-			if (m->control_pressed) { in.close(); out.close(); remove(outTemp.c_str()); return 0; }
+			if (m->control_pressed) { in.close(); out.close(); m->mothurRemove(outTemp); return 0; }
 			
 			in >> firstName >> secondName >> distance;    m->gobble(in);		
 			
@@ -774,7 +787,7 @@ int HCluster::processFile() {
 		in.close();
 		out.close();
 		
-		remove(distfile.c_str());
+		m->mothurRemove(distfile);
 		rename(outTemp.c_str(), distfile.c_str());
 		
 		return 0;
