@@ -83,6 +83,7 @@ HeatMapCommand::HeatMapCommand(string option) {
 		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
+		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
 		
 		else {
 			vector<string> myArray = setParameters();
@@ -152,27 +153,27 @@ HeatMapCommand::HeatMapCommand(string option) {
 			listfile = validParameter.validFile(parameters, "list", true);
 			if (listfile == "not open") { listfile = ""; abort = true; }
 			else if (listfile == "not found") { listfile = ""; }
-			else {  format = "list"; inputfile = listfile; }
+			else {  format = "list"; inputfile = listfile; m->setListFile(listfile); }
 			
 			sabundfile = validParameter.validFile(parameters, "sabund", true);
 			if (sabundfile == "not open") { sabundfile = ""; abort = true; }	
 			else if (sabundfile == "not found") { sabundfile = ""; }
-			else {  format = "sabund"; inputfile = sabundfile; }
+			else {  format = "sabund"; inputfile = sabundfile; m->setSabundFile(sabundfile); }
 			
 			rabundfile = validParameter.validFile(parameters, "rabund", true);
 			if (rabundfile == "not open") { rabundfile = ""; abort = true; }	
 			else if (rabundfile == "not found") { rabundfile = ""; }
-			else {  format = "rabund"; inputfile = rabundfile; }
+			else {  format = "rabund"; inputfile = rabundfile; m->setRabundFile(rabundfile); }
 			
 			sharedfile = validParameter.validFile(parameters, "shared", true);
 			if (sharedfile == "not open") { sharedfile = ""; abort = true; }	
 			else if (sharedfile == "not found") { sharedfile = ""; }
-			else {  format = "sharedfile"; inputfile = sharedfile; }
+			else {  format = "sharedfile"; inputfile = sharedfile; m->setSharedFile(sharedfile); }
 			
 			relabundfile = validParameter.validFile(parameters, "relabund", true);
 			if (relabundfile == "not open") { relabundfile = ""; abort = true; }	
 			else if (relabundfile == "not found") { relabundfile = ""; }
-			else {  format = "relabund"; inputfile = relabundfile; }
+			else {  format = "relabund"; inputfile = relabundfile; m->setRelAbundFile(relabundfile); }
 			
 			
 			if ((sharedfile == "") && (listfile == "") && (rabundfile == "") && (sabundfile == "") && (relabundfile == "")) { 
@@ -221,7 +222,7 @@ HeatMapCommand::HeatMapCommand(string option) {
 			if (groups == "not found") { groups = ""; }
 			else { 
 				m->splitAtDash(groups, Groups);
-				m->Groups = Groups;
+				m->setGroups(Groups);
 			}
 			
 			string temp = validParameter.validFile(parameters, "numotu", false);		if (temp == "not found") { temp = "0"; }
@@ -285,8 +286,8 @@ int HeatMapCommand::execute(){
 			while((lookup[0] != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
 				if (m->control_pressed) {
 					for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }
-					for (int i = 0; i < outputNames.size(); i++) {	if (outputNames[i] != "control") {  remove(outputNames[i].c_str());  } } outputTypes.clear();
-					m->Groups.clear(); 
+					for (int i = 0; i < outputNames.size(); i++) {	if (outputNames[i] != "control") {  m->mothurRemove(outputNames[i]);  } } outputTypes.clear();
+					m->clearGroups(); 
 					delete input; delete heatmap; return 0;
 				}
 		
@@ -328,8 +329,8 @@ int HeatMapCommand::execute(){
 			
 			
 			if (m->control_pressed) {
-				for (int i = 0; i < outputNames.size(); i++) {	if (outputNames[i] != "control") {  remove(outputNames[i].c_str());  } } outputTypes.clear();
-				m->Groups.clear(); 
+				for (int i = 0; i < outputNames.size(); i++) {	if (outputNames[i] != "control") {  m->mothurRemove(outputNames[i]);  } } outputTypes.clear();
+				m->clearGroups(); 
 				delete input; delete heatmap; return 0;
 			}
 
@@ -358,13 +359,13 @@ int HeatMapCommand::execute(){
 			}
 		
 			//reset groups parameter
-			m->Groups.clear();  
+			m->clearGroups();  
 			
 		}else if ((format == "list") || (format == "rabund") || (format == "sabund")) {
 	
 			while((rabund != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
 				if (m->control_pressed) {   
-					for (int i = 0; i < outputNames.size(); i++) {	if (outputNames[i] != "control") {  remove(outputNames[i].c_str());  } } outputTypes.clear();
+					for (int i = 0; i < outputNames.size(); i++) {	if (outputNames[i] != "control") {  m->mothurRemove(outputNames[i]);  } } outputTypes.clear();
 					delete rabund;  delete input; delete heatmap; return 0;	
 				}
 
@@ -403,7 +404,7 @@ int HeatMapCommand::execute(){
 			}
 			
 			if (m->control_pressed) {
-				for (int i = 0; i < outputNames.size(); i++) {	if (outputNames[i] != "control") {  remove(outputNames[i].c_str());  } } outputTypes.clear();
+				for (int i = 0; i < outputNames.size(); i++) {	if (outputNames[i] != "control") {  m->mothurRemove(outputNames[i]);  } } outputTypes.clear();
 				delete input; delete heatmap; return 0;
 			}
 
@@ -438,8 +439,8 @@ int HeatMapCommand::execute(){
 			while((lookupFloat[0] != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
 				if (m->control_pressed) {
 					for (int i = 0; i < lookupFloat.size(); i++) {  delete lookupFloat[i];  }
-					for (int i = 0; i < outputNames.size(); i++) {	if (outputNames[i] != "control") {  remove(outputNames[i].c_str());  } } outputTypes.clear();
-					m->Groups.clear(); 
+					for (int i = 0; i < outputNames.size(); i++) {	if (outputNames[i] != "control") {  m->mothurRemove(outputNames[i]);  } } outputTypes.clear();
+					m->clearGroups(); 
 					delete input; delete heatmap; return 0;
 				}
 		
@@ -480,8 +481,8 @@ int HeatMapCommand::execute(){
 			
 			
 			if (m->control_pressed) {
-				for (int i = 0; i < outputNames.size(); i++) {	if (outputNames[i] != "control") {  remove(outputNames[i].c_str());  } } outputTypes.clear();
-				m->Groups.clear(); 
+				for (int i = 0; i < outputNames.size(); i++) {	if (outputNames[i] != "control") {  m->mothurRemove(outputNames[i]);  } } outputTypes.clear();
+				m->clearGroups(); 
 				delete input; delete heatmap; return 0;
 			}
 
@@ -510,7 +511,7 @@ int HeatMapCommand::execute(){
 			}
 		
 			//reset groups parameter
-			m->Groups.clear();  
+			m->clearGroups();  
 
 		}
 		
@@ -518,7 +519,7 @@ int HeatMapCommand::execute(){
 		delete heatmap;
 		
 		if (m->control_pressed) {
-			for (int i = 0; i < outputNames.size(); i++) {	if (outputNames[i] != "control") {  remove(outputNames[i].c_str());  } } outputTypes.clear(); return 0;
+			for (int i = 0; i < outputNames.size(); i++) {	if (outputNames[i] != "control") {  m->mothurRemove(outputNames[i]);  } } outputTypes.clear(); return 0;
 		}
 		
 		m->mothurOutEndLine();
