@@ -92,6 +92,7 @@ HeatMapSimCommand::HeatMapSimCommand(string option)  {
 			
 		//allow user to run help
 		if(option == "help") {  help(); abort = true; calledHelp = true; }
+		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
 		
 		else {
 			vector<string> myArray = setParameters();
@@ -157,21 +158,22 @@ HeatMapSimCommand::HeatMapSimCommand(string option)  {
 			phylipfile = validParameter.validFile(parameters, "phylip", true);
 			if (phylipfile == "not open") { abort = true; }
 			else if (phylipfile == "not found") { phylipfile = ""; }	
-			else {  format = "phylip"; 	inputfile = phylipfile; if (outputDir == "") { outputDir += m->hasPath(phylipfile); }  }
+			else {  format = "phylip"; 	inputfile = phylipfile; m-> setPhylipFile(phylipfile); if (outputDir == "") { outputDir += m->hasPath(phylipfile); }  }
 			
 			columnfile = validParameter.validFile(parameters, "column", true);
 			if (columnfile == "not open") { abort = true; }	
 			else if (columnfile == "not found") { columnfile = ""; }
-			else {  format = "column";	inputfile = columnfile; if (outputDir == "") { outputDir += m->hasPath(columnfile); } }
+			else {  format = "column";	inputfile = columnfile; m->setColumnFile(columnfile); if (outputDir == "") { outputDir += m->hasPath(columnfile); } }
 			
 			sharedfile = validParameter.validFile(parameters, "shared", true);
 			if (sharedfile == "not open") { abort = true; }	
 			else if (sharedfile == "not found") { sharedfile = ""; }
-			else {  format = "shared";	inputfile = sharedfile;  if (outputDir == "") { outputDir += m->hasPath(sharedfile); } }
+			else {  format = "shared";	inputfile = sharedfile; m->setSharedFile(sharedfile); if (outputDir == "") { outputDir += m->hasPath(sharedfile); } }
 			
 			namefile = validParameter.validFile(parameters, "name", true);
 			if (namefile == "not open") { abort = true; }	
 			else if (namefile == "not found") { namefile = ""; }
+			else { m->setNameFile(namefile); }
 			
 			
 			//error checking on files			
@@ -222,12 +224,17 @@ HeatMapSimCommand::HeatMapSimCommand(string option)  {
 				if (calc == "default")  {  calc = "jest-thetayc";  }
 			}
 			m->splitAtDash(calc, Estimators);
+			if (m->inUsersGroups("citation", Estimators)) { 
+				ValidCalculators validCalc; validCalc.printCitations(Estimators); 
+				//remove citation from list of calcs
+				for (int i = 0; i < Estimators.size(); i++) { if (Estimators[i] == "citation") {  Estimators.erase(Estimators.begin()+i); break; } }
+			}
 				
 			groups = validParameter.validFile(parameters, "groups", false);			
 			if (groups == "not found") { groups = ""; }
 			else { 
 				m->splitAtDash(groups, Groups);
-				m->Groups = Groups;
+				m->setGroups(Groups);
 			}
 			
 			
@@ -287,7 +294,7 @@ int HeatMapSimCommand::execute(){
 		
 		delete heatmap;
 		
-		if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str());  } outputTypes.clear(); return 0; }
+		if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  } outputTypes.clear(); return 0; }
 		
 		m->mothurOutEndLine();
 		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
@@ -318,12 +325,12 @@ int HeatMapSimCommand::runCommandShared() {
 		set<string> processedLabels;
 		set<string> userLabels = labels;
 		
-		if (m->control_pressed) {  delete input;  for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }  m->Groups.clear(); return 0; }
+		if (m->control_pressed) {  delete input;  for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  }  m->clearGroups(); return 0; }
 		
 		//as long as you are not at the end of the file or done wih the lines you want
 		while((lookup[0] != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
 			
-			if (m->control_pressed) { delete input;  for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } m->Groups.clear(); return 0; }
+			if (m->control_pressed) { delete input;  for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } m->clearGroups(); return 0; }
 
 			if(allLines == 1 || labels.count(lookup[0]->getLabel()) == 1){			
 	
@@ -363,7 +370,7 @@ int HeatMapSimCommand::runCommandShared() {
 		}
 		
 			
-		if (m->control_pressed) {  delete input;  m->Groups.clear();  return 0; }
+		if (m->control_pressed) {  delete input;  m->clearGroups();  return 0; }
 
 		//output error messages about any remaining user labels
 		set<string>::iterator it;
@@ -378,7 +385,7 @@ int HeatMapSimCommand::runCommandShared() {
 			}
 		}
 		
-		if (m->control_pressed) {  delete input;  m->Groups.clear(); return 0; }
+		if (m->control_pressed) {  delete input;  m->clearGroups(); return 0; }
 		
 		//run last label if you need to
 		if (needToRun == true)  {
@@ -392,10 +399,10 @@ int HeatMapSimCommand::runCommandShared() {
 			for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } 
 		}
 		
-		if (m->control_pressed) {  delete input;  m->Groups.clear(); return 0; }
+		if (m->control_pressed) {  delete input;  m->clearGroups(); return 0; }
 			
 		//reset groups parameter
-		m->Groups.clear();  
+		m->clearGroups();  
 			
 		delete input;  
 	
