@@ -27,7 +27,9 @@ public:
 	string getCommandName()			{ return "heatmap.sim";				}
 	string getCommandCategory()		{ return "OTU-Based Approaches";	}
 	string getHelpString();	
-	
+	string getCitation() { return "http://www.mothur.org/wiki/Heatmap.sim"; }
+	string getDescription()		{ return "generate a heatmap indicating the pairwise distance between multiple samples using a variety of calculators"; }
+
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
 	
