@@ -20,6 +20,9 @@ class ignoreGaps : public Dist {
 	
 public:
 	
+	ignoreGaps() {}
+	ignoreGaps(const ignoreGaps& ddb) {}
+	
 	void calcDist(Sequence A, Sequence B){		
 		int diff = 0;
 		int length = 0;
