@@ -18,7 +18,7 @@
 class Knn : public Classify {
 	
 public:
-	Knn(string, string, string, int, float, float, float, float, int);
+	Knn(string, string, string, int, float, float, float, float, int, int);
 	~Knn();
 	
 	void setDistName(string s);
