@@ -10,6 +10,7 @@
 #include "metastatscommand.h"
 #include "metastats.h"
 #include "sharedutilities.h"
+#include "mothurmetastats.h"
 
 //**********************************************************************************************************************
 vector<string> MetaStatsCommand::setParameters(){	
@@ -83,6 +84,7 @@ MetaStatsCommand::MetaStatsCommand(string option) {
 		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
+		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
 		
 		else {
 			vector<string> myArray = setParameters();
@@ -133,7 +135,7 @@ MetaStatsCommand::MetaStatsCommand(string option) {
 				sharedfile = m->getSharedFile(); 
 				if (sharedfile != "") { m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
 				else { 	m->mothurOut("You have no current sharedfile and the shared parameter is required."); m->mothurOutEndLine(); abort = true; }
-			}
+			}else { m->setSharedFile(sharedfile); }
 			
 			//check for required parameters
 			designfile = validParameter.validFile(parameters, "design", true);
@@ -143,7 +145,7 @@ MetaStatsCommand::MetaStatsCommand(string option) {
 				designfile = m->getDesignFile(); 
 				if (designfile != "") { m->mothurOut("Using " + designfile + " as input file for the design parameter."); m->mothurOutEndLine(); }
 				else { 	m->mothurOut("You have no current designfile and the design parameter is required."); m->mothurOutEndLine(); abort = true; }
-			}
+			}else { m->setDesignFile(designfile); }
 			
 			//if the user changes the output directory command factory will send this info to us in the output parameter 
 			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	
@@ -165,7 +167,7 @@ MetaStatsCommand::MetaStatsCommand(string option) {
 			else { 
 				pickedGroups = true;
 				m->splitAtDash(groups, Groups);
-				m->Groups = Groups;
+				m->setGroups(Groups);
 			}
 			
 			sets = validParameter.validFile(parameters, "sets", false);			
@@ -213,8 +215,9 @@ int MetaStatsCommand::execute(){
 		//setup the pairwise comparions of sets for metastats
 		//calculate number of comparisons i.e. with groups A,B,C = AB, AC, BC = 3;
 		//make sure sets are all in designMap
-		SharedUtil* util = new SharedUtil();  
-		util->setGroups(Sets, designMap->namesOfGroups);  
+		SharedUtil* util = new SharedUtil(); 
+		vector<string> dGroups = designMap->getNamesOfGroups();
+		util->setGroups(Sets, dGroups);  
 		delete util;
 		
 		int numGroups = Sets.size();
@@ -248,7 +251,7 @@ int MetaStatsCommand::execute(){
 		//as long as you are not at the end of the file or done wih the lines you want
 		while((lookup[0] != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
 			
-			if (m->control_pressed) {  outputTypes.clear(); for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } m->Groups.clear(); delete input; delete designMap;  for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); } return 0; }
+			if (m->control_pressed) {  outputTypes.clear(); for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } m->clearGroups(); delete input; delete designMap;  for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0; }
 	
 			if(allLines == 1 || labels.count(lookup[0]->getLabel()) == 1){			
 
@@ -279,13 +282,13 @@ int MetaStatsCommand::execute(){
 			//prevent memory leak
 			for (int i = 0; i < lookup.size(); i++) {  delete lookup[i]; lookup[i] = NULL; }
 			
-			if (m->control_pressed) {  outputTypes.clear(); m->Groups.clear(); delete input;  delete designMap;  for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); } return 0; }
+			if (m->control_pressed) {  outputTypes.clear(); m->clearGroups(); delete input;  delete designMap;  for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0; }
 
 			//get next line to process
 			lookup = input->getSharedRAbundVectors();				
 		}
 		
-		if (m->control_pressed) { outputTypes.clear(); m->Groups.clear(); delete input; delete designMap;  for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); }  return 0; }
+		if (m->control_pressed) { outputTypes.clear(); m->clearGroups(); delete input; delete designMap;  for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); }  return 0; }
 
 		//output error messages about any remaining user labels
 		set<string>::iterator it;
@@ -313,11 +316,11 @@ int MetaStatsCommand::execute(){
 		}
 	
 		//reset groups parameter
-		m->Groups.clear();  
+		m->clearGroups();  
 		delete input; 
 		delete designMap;
 		
-		if (m->control_pressed) { outputTypes.clear(); for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); } return 0;}
+		if (m->control_pressed) { outputTypes.clear(); for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0;}
 		
 		m->mothurOutEndLine();
 		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
@@ -391,17 +394,19 @@ int MetaStatsCommand::driver(int start, int num, vector<SharedRAbundVector*>& th
 			//get set names
 			string setA = namesOfGroupCombos[c][0]; 
 			string setB = namesOfGroupCombos[c][1];
-			
+		
 			//get filename
 			string outputFileName = outputDir +  m->getRootName(m->getSimpleName(sharedfile)) + thisLookUp[0]->getLabel() + "." + setA + "-" + setB + ".metastats";
 			outputNames.push_back(outputFileName); outputTypes["metastats"].push_back(outputFileName);
-			int nameLength = outputFileName.length();
-			char * output = new char[nameLength];
-			strcpy(output, outputFileName.c_str());
+			//int nameLength = outputFileName.length();
+			//char * output = new char[nameLength];
+			//strcpy(output, outputFileName.c_str());
 	
 			//build matrix from shared rabunds
-			double** data;
-			data = new double*[thisLookUp[0]->getNumBins()];
+			//double** data;
+			//data = new double*[thisLookUp[0]->getNumBins()];
+			
+			vector< vector<double> > data2; data2.resize(thisLookUp[0]->getNumBins());
 			
 			vector<SharedRAbundVector*> subset;
 			int setACount = 0;
@@ -419,29 +424,38 @@ int MetaStatsCommand::driver(int start, int num, vector<SharedRAbundVector*>& th
 					setACount++;
 				}
 			}
-						
+			
+			//for (int i = 0; i < subset.size(); i++) { cout << subset[i]->getGroup() << endl; }
+			
 			if ((setACount == 0) || (setBCount == 0))  { 
 				m->mothurOut("Missing shared info for " + setA + " or " + setB + ". Skipping comparison."); m->mothurOutEndLine(); 
 				outputNames.pop_back();
 			}else {
 				//fill data
 				for (int j = 0; j < thisLookUp[0]->getNumBins(); j++) {
-					data[j] = new double[subset.size()];
+					//data[j] = new double[subset.size()];
+					data2[j].resize(subset.size(), 0.0);
 					for (int i = 0; i < subset.size(); i++) {
-						data[j][i] = (subset[i]->getAbundance(j));
+						//data[j][i] = (subset[i]->getAbundance(j));
+						data2[j][i] = (subset[i]->getAbundance(j));
 					}
 				}
 				
 				m->mothurOut("Comparing " + setA + " and " + setB + "..."); m->mothurOutEndLine(); 
-				metastat_main(output, thisLookUp[0]->getNumBins(), subset.size(), threshold, iters, data, setACount);
+				//metastat_main(output, thisLookUp[0]->getNumBins(), subset.size(), threshold, iters, data, setACount);
+				
+				m->mothurOutEndLine();
+				MothurMetastats mothurMeta(threshold, iters);
+				mothurMeta.runMetastats(outputFileName , data2, setACount);
+				m->mothurOutEndLine();
 				
 				m->mothurOutEndLine(); 
 			}
 			
 			//free memory
-			delete output;
-			for(int i = 0; i < thisLookUp[0]->getNumBins(); i++)  {  delete[] data[i];  }
-			delete[] data; 
+			//delete output;
+			//for(int i = 0; i < thisLookUp[0]->getNumBins(); i++)  {  delete[] data[i];  }
+			//delete[] data; 
 		}
 		
 		return 0;
