@@ -82,6 +82,7 @@ MGClusterCommand::MGClusterCommand(string option) {
 		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
+		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
 		
 		else {
 			vector<string> myArray = setParameters();
@@ -140,6 +141,7 @@ MGClusterCommand::MGClusterCommand(string option) {
 			namefile = validParameter.validFile(parameters, "name", true);
 			if (namefile == "not open") { abort = true; }	
 			else if (namefile == "not found") { namefile = ""; }
+			else { m->setNameFile(namefile); }
 			
 			if ((blastfile == "")) { m->mothurOut("When executing a mgcluster command you must provide a blastfile."); m->mothurOutEndLine(); abort = true; }
 			
@@ -228,11 +230,13 @@ int MGClusterCommand::execute(){
 		
 		if (m->control_pressed) { 
 			delete nameMap; delete read; delete list; delete rabund; 
-			listFile.close(); rabundFile.close(); sabundFile.close(); remove((fileroot+ tag + ".list").c_str()); remove((fileroot+ tag + ".rabund").c_str()); remove((fileroot+ tag + ".sabund").c_str());
+			listFile.close(); rabundFile.close(); sabundFile.close(); m->mothurRemove((fileroot+ tag + ".list")); m->mothurRemove((fileroot+ tag + ".rabund")); m->mothurRemove((fileroot+ tag + ".sabund"));
 			outputTypes.clear();
 			return 0; 
 		}
 		
+		double saveCutoff = cutoff;
+		
 		if (!hclusterWanted) {
 			//get distmatrix and overlap
 			SparseMatrix* distMatrix = read->getDistMatrix();
@@ -249,7 +253,7 @@ int MGClusterCommand::execute(){
 			
 			if (m->control_pressed) { 
 				delete nameMap; delete distMatrix; delete list; delete rabund; delete cluster;
-				listFile.close(); rabundFile.close(); sabundFile.close(); remove((fileroot+ tag + ".list").c_str()); remove((fileroot+ tag + ".rabund").c_str()); remove((fileroot+ tag + ".sabund").c_str());
+				listFile.close(); rabundFile.close(); sabundFile.close(); m->mothurRemove((fileroot+ tag + ".list")); m->mothurRemove((fileroot+ tag + ".rabund")); m->mothurRemove((fileroot+ tag + ".sabund"));
 				outputTypes.clear();
 				return 0; 
 			}
@@ -261,7 +265,7 @@ int MGClusterCommand::execute(){
 				
 				if (m->control_pressed) { 
 					delete nameMap; delete distMatrix; delete list; delete rabund; delete cluster;
-					listFile.close(); rabundFile.close(); sabundFile.close(); remove((fileroot+ tag + ".list").c_str()); remove((fileroot+ tag + ".rabund").c_str()); remove((fileroot+ tag + ".sabund").c_str());
+					listFile.close(); rabundFile.close(); sabundFile.close(); m->mothurRemove((fileroot+ tag + ".list")); m->mothurRemove((fileroot+ tag + ".rabund")); m->mothurRemove((fileroot+ tag + ".sabund"));
 					outputTypes.clear();
 					return 0; 
 				}
@@ -284,7 +288,7 @@ int MGClusterCommand::execute(){
 						
 						if (m->control_pressed) { 
 							delete nameMap; delete distMatrix; delete list; delete rabund; delete cluster; delete temp;
-							listFile.close(); rabundFile.close(); sabundFile.close(); remove((fileroot+ tag + ".list").c_str()); remove((fileroot+ tag + ".rabund").c_str()); remove((fileroot+ tag + ".sabund").c_str());
+							listFile.close(); rabundFile.close(); sabundFile.close(); m->mothurRemove((fileroot+ tag + ".list")); m->mothurRemove((fileroot+ tag + ".rabund")); m->mothurRemove((fileroot+ tag + ".sabund"));
 							outputTypes.clear();
 							return 0; 
 						}
@@ -315,7 +319,7 @@ int MGClusterCommand::execute(){
 					
 					if (m->control_pressed) { 
 							delete nameMap; delete distMatrix; delete list; delete rabund; delete cluster; delete temp;
-							listFile.close(); rabundFile.close(); sabundFile.close(); remove((fileroot+ tag + ".list").c_str()); remove((fileroot+ tag + ".rabund").c_str()); remove((fileroot+ tag + ".sabund").c_str());
+							listFile.close(); rabundFile.close(); sabundFile.close(); m->mothurRemove((fileroot+ tag + ".list")); m->mothurRemove((fileroot+ tag + ".rabund")); m->mothurRemove((fileroot+ tag + ".sabund"));
 							outputTypes.clear();
 							return 0; 
 					}
@@ -345,7 +349,7 @@ int MGClusterCommand::execute(){
 			
 			if (m->control_pressed) { 
 				delete nameMap;  delete list; delete rabund; 
-				listFile.close(); rabundFile.close(); sabundFile.close(); remove((fileroot+ tag + ".list").c_str()); remove((fileroot+ tag + ".rabund").c_str()); remove((fileroot+ tag + ".sabund").c_str());
+				listFile.close(); rabundFile.close(); sabundFile.close(); m->mothurRemove((fileroot+ tag + ".list")); m->mothurRemove((fileroot+ tag + ".rabund")); m->mothurRemove((fileroot+ tag + ".sabund"));
 				outputTypes.clear();
 				return 0; 
 			}
@@ -362,7 +366,7 @@ int MGClusterCommand::execute(){
 			
 			if (m->control_pressed) { 
 				delete nameMap;  delete list; delete rabund; delete hcluster;
-				listFile.close(); rabundFile.close(); sabundFile.close(); remove((fileroot+ tag + ".list").c_str()); remove((fileroot+ tag + ".rabund").c_str()); remove((fileroot+ tag + ".sabund").c_str());
+				listFile.close(); rabundFile.close(); sabundFile.close(); m->mothurRemove((fileroot+ tag + ".list")); m->mothurRemove((fileroot+ tag + ".rabund")); m->mothurRemove((fileroot+ tag + ".sabund"));
 				outputTypes.clear();
 				return 0; 
 			}
@@ -371,11 +375,16 @@ int MGClusterCommand::execute(){
 		
 				seqs = hcluster->getSeqs();
 				
+				//to account for cutoff change in average neighbor
+				if (seqs.size() != 0) {
+					if (seqs[0].dist > cutoff) { break; }
+				}
+				
 				if (m->control_pressed) { 
 					delete nameMap;  delete list; delete rabund; delete hcluster;
-					listFile.close(); rabundFile.close(); sabundFile.close(); remove((fileroot+ tag + ".list").c_str()); remove((fileroot+ tag + ".rabund").c_str()); remove((fileroot+ tag + ".sabund").c_str());
-					remove(distFile.c_str());
-					remove(overlapFile.c_str());
+					listFile.close(); rabundFile.close(); sabundFile.close(); m->mothurRemove((fileroot+ tag + ".list")); m->mothurRemove((fileroot+ tag + ".rabund")); m->mothurRemove((fileroot+ tag + ".sabund"));
+					m->mothurRemove(distFile);
+					m->mothurRemove(overlapFile);
 					outputTypes.clear();
 					return 0; 
 				}
@@ -384,13 +393,13 @@ int MGClusterCommand::execute(){
 					
 					if (seqs[i].seq1 != seqs[i].seq2) {
 		
-						hcluster->update(seqs[i].seq1, seqs[i].seq2, seqs[i].dist);
+						cutoff = hcluster->update(seqs[i].seq1, seqs[i].seq2, seqs[i].dist);
 						
 						if (m->control_pressed) { 
 							delete nameMap;  delete list; delete rabund; delete hcluster;
-							listFile.close(); rabundFile.close(); sabundFile.close(); remove((fileroot+ tag + ".list").c_str()); remove((fileroot+ tag + ".rabund").c_str()); remove((fileroot+ tag + ".sabund").c_str());
-							remove(distFile.c_str());
-							remove(overlapFile.c_str());
+							listFile.close(); rabundFile.close(); sabundFile.close(); m->mothurRemove((fileroot+ tag + ".list")); m->mothurRemove((fileroot+ tag + ".rabund")); m->mothurRemove((fileroot+ tag + ".sabund"));
+							m->mothurRemove(distFile);
+							m->mothurRemove(overlapFile);
 							outputTypes.clear();
 							return 0; 
 						}
@@ -412,9 +421,9 @@ int MGClusterCommand::execute(){
 								
 								if (m->control_pressed) { 
 									delete nameMap;  delete list; delete rabund; delete hcluster; delete temp;
-									listFile.close(); rabundFile.close(); sabundFile.close(); remove((fileroot+ tag + ".list").c_str()); remove((fileroot+ tag + ".rabund").c_str()); remove((fileroot+ tag + ".sabund").c_str());
-									remove(distFile.c_str());
-									remove(overlapFile.c_str());
+									listFile.close(); rabundFile.close(); sabundFile.close(); m->mothurRemove((fileroot+ tag + ".list")); m->mothurRemove((fileroot+ tag + ".rabund")); m->mothurRemove((fileroot+ tag + ".sabund"));
+									m->mothurRemove(distFile);
+									m->mothurRemove(overlapFile);
 									outputTypes.clear();
 									return 0; 
 								}
@@ -448,9 +457,9 @@ int MGClusterCommand::execute(){
 					
 					if (m->control_pressed) { 
 							delete nameMap; delete list; delete rabund; delete hcluster; delete temp;
-							listFile.close(); rabundFile.close(); sabundFile.close(); remove((fileroot+ tag + ".list").c_str()); remove((fileroot+ tag + ".rabund").c_str()); remove((fileroot+ tag + ".sabund").c_str());
-							remove(distFile.c_str());
-							remove(overlapFile.c_str());
+							listFile.close(); rabundFile.close(); sabundFile.close(); m->mothurRemove((fileroot+ tag + ".list")); m->mothurRemove((fileroot+ tag + ".rabund")); m->mothurRemove((fileroot+ tag + ".sabund"));
+							m->mothurRemove(distFile);
+							m->mothurRemove(overlapFile);
 							outputTypes.clear();
 							return 0; 
 					}
@@ -465,8 +474,8 @@ int MGClusterCommand::execute(){
 			}
 			
 			delete hcluster;
-			remove(distFile.c_str());
-			remove(overlapFile.c_str());
+			m->mothurRemove(distFile);
+			m->mothurRemove(overlapFile);
 		}
 		
 		delete list; 
@@ -477,7 +486,7 @@ int MGClusterCommand::execute(){
 	
 		if (m->control_pressed) { 
 			delete nameMap; 
-			listFile.close(); rabundFile.close(); sabundFile.close(); remove((fileroot+ tag + ".list").c_str()); remove((fileroot+ tag + ".rabund").c_str()); remove((fileroot+ tag + ".sabund").c_str());
+			listFile.close(); rabundFile.close(); sabundFile.close(); m->mothurRemove((fileroot+ tag + ".list")); m->mothurRemove((fileroot+ tag + ".rabund")); m->mothurRemove((fileroot+ tag + ".sabund"));
 			outputTypes.clear();
 			return 0; 
 		}
@@ -489,6 +498,13 @@ int MGClusterCommand::execute(){
 		m->mothurOut(fileroot+ tag + ".sabund"); m->mothurOutEndLine();	outputNames.push_back(fileroot+ tag + ".sabund"); outputTypes["sabund"].push_back(fileroot+ tag + ".sabund");
 		m->mothurOutEndLine();
 		
+		if (saveCutoff != cutoff) { 
+			if (hard)	{  saveCutoff = m->ceilDist(saveCutoff, precision);	}
+			else		{	saveCutoff = m->roundDist(saveCutoff, precision);  }
+			
+			m->mothurOut("changed cutoff to " + toString(cutoff)); m->mothurOutEndLine(); 
+		}
+		
 		//set list file as new current listfile
 		string current = "";
 		itTypes = outputTypes.find("list");
@@ -642,12 +658,12 @@ void MGClusterCommand::sortHclusterFiles(string unsortedDist, string unsortedOve
 	try {
 		//sort distFile
 		string sortedDistFile = m->sortFile(unsortedDist, outputDir);
-		remove(unsortedDist.c_str());  //delete unsorted file
+		m->mothurRemove(unsortedDist);  //delete unsorted file
 		distFile = sortedDistFile;
 		
 		//sort overlap file
 		string sortedOverlapFile = m->sortFile(unsortedOverlap, outputDir);
-		remove(unsortedOverlap.c_str());  //delete unsorted file
+		m->mothurRemove(unsortedOverlap);  //delete unsorted file
 		overlapFile = sortedOverlapFile;
 	}
 	catch(exception& e) {
