@@ -39,6 +39,8 @@ void MothurOut::printCurrentFiles()  {
 		if (sharedfile != "")		{  mothurOut("shared=" + sharedfile); mothurOutEndLine();			}
 		if (taxonomyfile != "")		{  mothurOut("taxonomy=" + taxonomyfile); mothurOutEndLine();		}
 		if (treefile != "")			{  mothurOut("tree=" + treefile); mothurOutEndLine();				}
+		if (flowfile != "")			{  mothurOut("flow=" + flowfile); mothurOutEndLine();				}
+		if (processors != "1")		{  mothurOut("processors=" + processors); mothurOutEndLine();		}
 		
 	}
 	catch(exception& e) {
@@ -70,6 +72,8 @@ bool MothurOut::hasCurrentFiles()  {
 		if (sharedfile != "")		{  return true;			}
 		if (taxonomyfile != "")		{  return true;			}
 		if (treefile != "")			{  return true;			}
+		if (flowfile != "")			{  return true;			}
+		if (processors != "1")		{  return true;			}
 		
 		return hasCurrent;
 		
@@ -101,7 +105,9 @@ void MothurOut::clearCurrentFiles()  {
 		sfffile = "";
 		oligosfile = "";
 		accnosfile = "";
-		taxonomyfile = "";		
+		taxonomyfile = "";	
+		flowfile = "";
+		processors = "1";
 	}
 	catch(exception& e) {
 		errorOut(e, "MothurOut", "clearCurrentFiles");
@@ -241,6 +247,53 @@ void MothurOut::mothurOutEndLine() {
 	}
 }
 /*********************************************************************************************/
+void MothurOut::mothurOut(string output, ofstream& outputFile) {
+	try {
+		
+#ifdef USE_MPI
+		int pid;
+		MPI_Comm_rank(MPI_COMM_WORLD, &pid); 
+		
+		if (pid == 0) { //only one process should output to screen
+#endif
+			
+			cout << output;
+			out << output;
+			outputFile << output;
+			
+#ifdef USE_MPI
+		}
+#endif
+	}
+	catch(exception& e) {
+		errorOut(e, "MothurOut", "MothurOut");
+		exit(1);
+	}
+}
+/*********************************************************************************************/
+void MothurOut::mothurOutEndLine(ofstream& outputFile) {
+	try {
+#ifdef USE_MPI
+		int pid;
+		MPI_Comm_rank(MPI_COMM_WORLD, &pid); 
+		
+		if (pid == 0) { //only one process should output to screen
+#endif
+			
+			cout << endl;
+			out << endl;
+			outputFile << endl;
+			
+#ifdef USE_MPI
+		}
+#endif
+	}
+	catch(exception& e) {
+		errorOut(e, "MothurOut", "MothurOutEndLine");
+		exit(1);
+	}
+}
+/*********************************************************************************************/
 void MothurOut::mothurOutJustToLog(string output) {
 	try {
 		#ifdef USE_MPI
@@ -381,7 +434,7 @@ void MothurOut::gobble(istream& f){
 		
 		char d;
 		while(isspace(d=f.get()))		{ ;}
-		f.putback(d);
+		if(!f.eof()) { f.putback(d); }
 	}
 	catch(exception& e) {
 		errorOut(e, "MothurOut", "gobble");
@@ -393,7 +446,7 @@ void MothurOut::gobble(istringstream& f){
 	try {
 		char d;
 		while(isspace(d=f.get()))		{;}
-		f.putback(d);
+		if(!f.eof()) { f.putback(d); }
 	}
 	catch(exception& e) {
 		errorOut(e, "MothurOut", "gobble");
@@ -432,12 +485,12 @@ string MothurOut::getline(ifstream& fileHandle) {
 	
 		string line = "";
 		
-		while (!fileHandle.eof())	{
+		while (fileHandle)	{
 			//get next character
 			char c = fileHandle.get(); 
 			
 			//are you at the end of the line
-			if ((c == '\n') || (c == '\r') || (c == '\f')){  break;	}	
+			if ((c == '\n') || (c == '\r') || (c == '\f') || (c == EOF)){  break;	}	
 			else {		line += c;		}
 		}
 		
@@ -509,6 +562,21 @@ string MothurOut::getSimpleName(string longName){
 
 /***********************************************************************/
 
+int MothurOut::getRandomIndex(int highest){
+	try {
+		
+		int random = (int) ((float)(highest+1) * (float)(rand()) / ((float)RAND_MAX+1.0));
+		
+		return random;
+	}
+	catch(exception& e) {
+		errorOut(e, "MothurOut", "getRandomIndex");
+		exit(1);
+	}	
+	
+}
+/**********************************************************************/
+
 string MothurOut::getPathName(string longName){
 	try {
 		string rootPathName = longName;
@@ -743,7 +811,7 @@ int MothurOut::openInputFile(string fileName, ifstream& fileHandle, string m){
           cerr << "Decompressing " << completeFileName << " via temporary named pipe " << tempName << "\n";
           system(command.c_str());
           cerr << "Done decompressing " << completeFileName << "\n";
-          remove(tempName.c_str());
+          mothurRemove(tempName);
           exit(EXIT_SUCCESS);
         } else {
           cerr << "waiting on child process " << fork_result << "\n";
@@ -789,7 +857,7 @@ int MothurOut::openInputFile(string fileName, ifstream& fileHandle){
       cerr << "Decompressing " << completeFileName << " via temporary named pipe " << tempName << "\n";
       system(command.c_str());
       cerr << "Done decompressing " << completeFileName << "\n";
-      remove(tempName.c_str());
+      mothurRemove(tempName);
       exit(EXIT_SUCCESS);
     } else {
       cerr << "waiting on child process " << fork_result << "\n";
@@ -823,10 +891,10 @@ int MothurOut::renameFile(string oldName, string newName){
 	try {
 		ifstream inTest;
 		int exist = openInputFile(newName, inTest, "");
+		inTest.close();
 		
 	#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)		
 		if (exist == 0) { //you could open it so you want to delete it
-			inTest.close();
 			string command = "rm " + newName;
 			system(command.c_str());
 		}
@@ -834,7 +902,7 @@ int MothurOut::renameFile(string oldName, string newName){
 		string command = "mv " + oldName + " " + newName;
 		system(command.c_str());
 	#else
-		remove(newName.c_str());
+		mothurRemove(newName);
 		int renameOk = rename(oldName.c_str(), newName.c_str());
 	#endif
 		return 0;
@@ -890,7 +958,7 @@ int MothurOut::openOutputFile(string fileName, ofstream& fileHandle){
 }
 
 /**************************************************************************************************/
-void MothurOut::appendFiles(string temp, string filename) {
+int MothurOut::appendFiles(string temp, string filename) {
 	try{
 		ofstream output;
 		ifstream input;
@@ -900,15 +968,18 @@ void MothurOut::appendFiles(string temp, string filename) {
 		int ableToOpen = openInputFile(temp, input, "no error");
 		//int ableToOpen = openInputFile(temp, input);
 		
+		int numLines = 0;
 		if (ableToOpen == 0) { //you opened it
 			while(char c = input.get()){
 				if(input.eof())		{	break;			}
-				else				{	output << c;	}
+				else				{	output << c;	if (c == '\n') {numLines++;} }
 			}
 			input.close();
 		}
 		
 		output.close();
+		
+		return numLines;
 	}
 	catch(exception& e) {
 		errorOut(e, "MothurOut", "appendFiles");
@@ -970,8 +1041,8 @@ string MothurOut::sortFile(string distFile, string outputDir){
 			output.close();
 		
 			//remove temp files
-			remove(tempDistFile.c_str());
-			remove(tempOutfile.c_str());
+			mothurRemove(tempDistFile);
+			mothurRemove(tempOutfile);
 		#endif
 		
 		return outfile;
@@ -982,19 +1053,27 @@ string MothurOut::sortFile(string distFile, string outputDir){
 	}	
 }
 /**************************************************************************************************/
-vector<unsigned long int> MothurOut::setFilePosFasta(string filename, int& num) {
+vector<unsigned long long> MothurOut::setFilePosFasta(string filename, int& num) {
 	try {
-			vector<unsigned long int> positions;
+			vector<unsigned long long> positions;
 			ifstream inFASTA;
-			openInputFile(filename, inFASTA);
+			//openInputFile(filename, inFASTA);
+			inFASTA.open(filename.c_str(), ios::binary);
 						
 			string input;
+			unsigned long long count = 0;
 			while(!inFASTA.eof()){
-				input = getline(inFASTA); 
-				if (input.length() != 0) {
-					if(input[0] == '>'){	unsigned long int pos = inFASTA.tellg(); positions.push_back(pos - input.length() - 1);	}
+				//input = getline(inFASTA); 
+				//cout << input << '\t' << inFASTA.tellg() << endl;
+				//if (input.length() != 0) {
+				//	if(input[0] == '>'){	unsigned long int pos = inFASTA.tellg(); positions.push_back(pos - input.length() - 1);	 cout << (pos - input.length() - 1) << endl; }
+				//}
+				//gobble(inFASTA); //has to be here since windows line endings are 2 characters and mess up the positions
+				char c = inFASTA.get(); count++;
+				if (c == '>') {
+					positions.push_back(count-1);
+					//cout << count << endl;
 				}
-				gobble(inFASTA); //has to be here since windows line endings are 2 characters and mess up the positions
 			}
 			inFASTA.close();
 		
@@ -1012,7 +1091,7 @@ vector<unsigned long int> MothurOut::setFilePosFasta(string filename, int& num)
 				fclose (pFile);
 			}*/
 			
-			unsigned long int size = positions[(positions.size()-1)];
+			unsigned long long size = positions[(positions.size()-1)];
 			ifstream in;
 			openInputFile(filename, in);
 			
@@ -1025,6 +1104,7 @@ vector<unsigned long int> MothurOut::setFilePosFasta(string filename, int& num)
 			in.close();
 		
 			positions.push_back(size);
+			positions[0] = 0;
 		
 			return positions;
 	}
@@ -1034,31 +1114,51 @@ vector<unsigned long int> MothurOut::setFilePosFasta(string filename, int& num)
 	}
 }
 /**************************************************************************************************/
-vector<unsigned long int> MothurOut::setFilePosEachLine(string filename, int& num) {
+vector<unsigned long long> MothurOut::setFilePosEachLine(string filename, int& num) {
 	try {
 			filename = getFullPathName(filename);
 			
-			vector<unsigned long int> positions;
+			vector<unsigned long long> positions;
 			ifstream in;
-			openInputFile(filename, in);
-				
+			//openInputFile(filename, in);
+			in.open(filename.c_str(), ios::binary);
+		
 			string input;
+			unsigned long long count = 0;
+			positions.push_back(0);
+		
 			while(!in.eof()){
-				unsigned long int lastpos = in.tellg();
-				input = getline(in); 
-				if (input.length() != 0) {
-					unsigned long int pos = in.tellg(); 
-					if (pos != -1) { positions.push_back(pos - input.length() - 1);	}
-					else {  positions.push_back(lastpos);  }
+				//unsigned long long lastpos = in.tellg();
+				//input = getline(in); 
+				//if (input.length() != 0) {
+					//unsigned long long pos = in.tellg(); 
+					//if (pos != -1) { positions.push_back(pos - input.length() - 1);	}
+					//else {  positions.push_back(lastpos);  }
+				//}
+				//gobble(in); //has to be here since windows line endings are 2 characters and mess up the positions
+				
+				
+				//getline counting reads
+				char d = in.get(); count++;
+				while ((d != '\n') && (d != '\r') && (d != '\f') && (d != in.eof()))	{
+					//get next character
+					d = in.get(); 
+					count++;
 				}
-				gobble(in); //has to be here since windows line endings are 2 characters and mess up the positions
+				
+				if (!in.eof()) {
+					d=in.get(); count++;
+					while(isspace(d) && (d != in.eof()))		{ d=in.get(); count++;}
+				}
+				positions.push_back(count-1);
+				cout << count-1 << endl;
 			}
 			in.close();
 		
-			num = positions.size();
+			num = positions.size()-1;
 		
 			FILE * pFile;
-			unsigned long int size;
+			unsigned long long size;
 			
 			//get num bytes in file
 			pFile = fopen (filename.c_str(),"rb");
@@ -1069,7 +1169,7 @@ vector<unsigned long int> MothurOut::setFilePosEachLine(string filename, int& nu
 				fclose (pFile);
 			}
 		
-			positions.push_back(size);
+			positions[(positions.size()-1)] = size;
 		
 			return positions;
 	}
@@ -1080,14 +1180,14 @@ vector<unsigned long int> MothurOut::setFilePosEachLine(string filename, int& nu
 }
 /**************************************************************************************************/
 
-vector<unsigned long int> MothurOut::divideFile(string filename, int& proc) {
+vector<unsigned long long> MothurOut::divideFile(string filename, int& proc) {
 	try{
 	
-		vector<unsigned long int> filePos;
+		vector<unsigned long long> filePos;
 		filePos.push_back(0);
 		
 		FILE * pFile;
-		unsigned long int size;
+		unsigned long long size;
 		
 		filename = getFullPathName(filename);
 		
@@ -1101,7 +1201,7 @@ vector<unsigned long int> MothurOut::divideFile(string filename, int& proc) {
 		}
 	
 		//estimate file breaks
-		unsigned long int chunkSize = 0;
+		unsigned long long chunkSize = 0;
 		chunkSize = size / proc;
 
 		//file to small to divide by processors
@@ -1109,21 +1209,21 @@ vector<unsigned long int> MothurOut::divideFile(string filename, int& proc) {
 	
 		//for each process seekg to closest file break and search for next '>' char. make that the filebreak
 		for (int i = 0; i < proc; i++) {
-			unsigned long int spot = (i+1) * chunkSize;
+			unsigned long long spot = (i+1) * chunkSize;
 			
 			ifstream in;
 			openInputFile(filename, in);
 			in.seekg(spot);
 			
 			//look for next '>'
-			unsigned long int newSpot = spot;
+			unsigned long long newSpot = spot;
 			while (!in.eof()) {
 			   char c = in.get();
 			   if (c == '>') {   in.putback(c); newSpot = in.tellg(); break;  }
 			}
 		
 			//there was not another sequence before the end of the file
-			unsigned long int sanityPos = in.tellg();
+			unsigned long long sanityPos = in.tellg();
 
 			if (sanityPos == -1) {	break;  }
 			else {  filePos.push_back(newSpot);  }
@@ -1148,7 +1248,43 @@ vector<unsigned long int> MothurOut::divideFile(string filename, int& proc) {
 		exit(1);
 	}
 }
-
+/**************************************************************************************************/
+int MothurOut::divideFile(string filename, int& proc, vector<string>& files) {
+	try{
+		
+		vector<unsigned long long> filePos = divideFile(filename, proc);
+		
+		for (int i = 0; i < (filePos.size()-1); i++) {
+			
+			//read file chunk
+			ifstream in;
+			openInputFile(filename, in);
+			in.seekg(filePos[i]);
+			unsigned long long size = filePos[(i+1)] - filePos[i];
+			char* chunk = new char[size];
+			in.read(chunk, size);
+			in.close();
+			
+			//open new file
+			string fileChunkName = filename + "." + toString(i) + ".tmp";
+			ofstream out; 
+			openOutputFile(fileChunkName, out);
+			
+			out << chunk << endl;
+			out.close();
+			delete[] chunk;
+			
+			//save name
+			files.push_back(fileChunkName);
+		}
+				
+		return 0;
+	}
+	catch(exception& e) {
+		errorOut(e, "MothurOut", "divideFile");
+		exit(1);
+	}
+}
 /***********************************************************************/
 
 bool MothurOut::isTrue(string f){
@@ -1188,6 +1324,61 @@ float MothurOut::ceilDist(float dist, int precision){
 	}
 }
 /**********************************************************************************************************************/
+int MothurOut::readNames(string namefile, map<string, string>& nameMap) { 
+	try {
+		
+		//open input file
+		ifstream in;
+		openInputFile(namefile, in);
+		
+		while (!in.eof()) {
+			if (control_pressed) { break; }
+			
+			string firstCol, secondCol;
+			in >> firstCol >> secondCol; gobble(in);
+			
+			nameMap[firstCol] = secondCol;
+		}
+		in.close();
+		
+		return 0;
+		
+	}
+	catch(exception& e) {
+		errorOut(e, "MothurOut", "readNames");
+		exit(1);
+	}
+}
+/**********************************************************************************************************************/
+int MothurOut::readNames(string namefile, map<string, vector<string> >& nameMap) { 
+	try {
+		
+		//open input file
+		ifstream in;
+		openInputFile(namefile, in);
+		
+		while (!in.eof()) {
+			if (control_pressed) { break; }
+			
+			string firstCol, secondCol;
+			in >> firstCol >> secondCol; gobble(in);
+			
+			vector<string> temp;
+			splitAtComma(secondCol, temp);
+			
+			nameMap[firstCol] = temp;
+		}
+		in.close();
+		
+		return 0;
+		
+	}
+	catch(exception& e) {
+		errorOut(e, "MothurOut", "readNames");
+		exit(1);
+	}
+}
+/**********************************************************************************************************************/
 map<string, int> MothurOut::readNames(string namefile) { 
 	try {
 		
@@ -1217,6 +1408,42 @@ map<string, int> MothurOut::readNames(string namefile) {
 		exit(1);
 	}
 }
+/**********************************************************************************************************************/
+int MothurOut::readNames(string namefile, vector<seqPriorityNode>& nameVector, map<string, string>& fastamap) { 
+	try {
+		int error = 0;
+		
+		//open input file
+		ifstream in;
+		openInputFile(namefile, in);
+		
+		while (!in.eof()) {
+			if (control_pressed) { break; }
+			
+			string firstCol, secondCol;
+			in >> firstCol >> secondCol; gobble(in);
+			
+			int num = getNumNames(secondCol);
+			
+			map<string, string>::iterator it = fastamap.find(firstCol);
+			if (it == fastamap.end()) {
+				error = 1;
+				mothurOut("[ERROR]: " + firstCol + " is not in your fastafile, but is in your namesfile, please correct."); mothurOutEndLine();
+			}else {
+				seqPriorityNode temp(num, it->second, firstCol);
+				nameVector.push_back(temp);
+			}
+		}
+		in.close();
+		
+		return error;
+		
+	}
+	catch(exception& e) {
+		errorOut(e, "MothurOut", "readNames");
+		exit(1);
+	}
+}
 
 /***********************************************************************/
 
@@ -1240,7 +1467,18 @@ int MothurOut::getNumNames(string names){
 		exit(1);
 	}
 }
+/***********************************************************************/
 
+void MothurOut::mothurRemove(string filename){
+	try {
+		filename = getFullPathName(filename);
+		remove(filename.c_str());
+	}
+	catch(exception& e) {
+		errorOut(e, "MothurOut", "mothurRemove");
+		exit(1);
+	}
+}
 /**************************************************************************************************/
 
 vector<vector<double> > MothurOut::binomial(int maxOrder){
