@@ -99,6 +99,7 @@ PairwiseSeqsCommand::PairwiseSeqsCommand(string option)  {
 	
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
+		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
 		
 		else {
 			vector<string> myArray = setParameters();
@@ -141,48 +142,65 @@ PairwiseSeqsCommand::PairwiseSeqsCommand(string option)  {
 				//go through files and make sure they are good, if not, then disregard them
 				for (int i = 0; i < fastaFileNames.size(); i++) {
 					
-					if (inputDir != "") {
-						string path = m->hasPath(fastaFileNames[i]);
-						//if the user has not given a path then, add inputdir. else leave path alone.
-						if (path == "") {	fastaFileNames[i] = inputDir + fastaFileNames[i];		}
-					}
-	
-					int ableToOpen;
-					ifstream in;
-
-					ableToOpen = m->openInputFile(fastaFileNames[i], in, "noerror");
-				
-					//if you can't open it, try default location
-					if (ableToOpen == 1) {
-						if (m->getDefaultPath() != "") { //default path is set
-							string tryPath = m->getDefaultPath() + m->getSimpleName(fastaFileNames[i]);
-							m->mothurOut("Unable to open " + fastaFileNames[i] + ". Trying default " + tryPath); m->mothurOutEndLine();
-							ifstream in2;
-							ableToOpen = m->openInputFile(tryPath, in2, "noerror");
-							in2.close();
-							fastaFileNames[i] = tryPath;
+					bool ignore = false;
+					if (fastaFileNames[i] == "current") { 
+						fastaFileNames[i] = m->getFastaFile(); 
+						if (fastaFileNames[i] != "") {  m->mothurOut("Using " + fastaFileNames[i] + " as input file for the fasta parameter where you had given current."); m->mothurOutEndLine(); }
+						else { 	
+							m->mothurOut("You have no current fastafile, ignoring current."); m->mothurOutEndLine(); ignore=true; 
+							//erase from file list
+							fastaFileNames.erase(fastaFileNames.begin()+i);
+							i--;
 						}
 					}
 					
-					//if you can't open it, try output location
-					if (ableToOpen == 1) {
-						if (m->getOutputDir() != "") { //default path is set
-							string tryPath = m->getOutputDir() + m->getSimpleName(fastaFileNames[i]);
-							m->mothurOut("Unable to open " + fastaFileNames[i] + ". Trying output directory " + tryPath); m->mothurOutEndLine();
-							ifstream in2;
-							ableToOpen = m->openInputFile(tryPath, in2, "noerror");
-							in2.close();
-							fastaFileNames[i] = tryPath;
-						}
-					}
+					if (!ignore) {
 					
-					in.close();					
+						if (inputDir != "") {
+							string path = m->hasPath(fastaFileNames[i]);
+							//if the user has not given a path then, add inputdir. else leave path alone.
+							if (path == "") {	fastaFileNames[i] = inputDir + fastaFileNames[i];		}
+						}
+		
+						int ableToOpen;
+						ifstream in;
 
-					if (ableToOpen == 1) { 
-						m->mothurOut("Unable to open " + fastaFileNames[i] + ". It will be disregarded."); m->mothurOutEndLine(); 
-						//erase from file list
-						fastaFileNames.erase(fastaFileNames.begin()+i);
-						i--;
+						ableToOpen = m->openInputFile(fastaFileNames[i], in, "noerror");
+					
+						//if you can't open it, try default location
+						if (ableToOpen == 1) {
+							if (m->getDefaultPath() != "") { //default path is set
+								string tryPath = m->getDefaultPath() + m->getSimpleName(fastaFileNames[i]);
+								m->mothurOut("Unable to open " + fastaFileNames[i] + ". Trying default " + tryPath); m->mothurOutEndLine();
+								ifstream in2;
+								ableToOpen = m->openInputFile(tryPath, in2, "noerror");
+								in2.close();
+								fastaFileNames[i] = tryPath;
+							}
+						}
+						
+						//if you can't open it, try output location
+						if (ableToOpen == 1) {
+							if (m->getOutputDir() != "") { //default path is set
+								string tryPath = m->getOutputDir() + m->getSimpleName(fastaFileNames[i]);
+								m->mothurOut("Unable to open " + fastaFileNames[i] + ". Trying output directory " + tryPath); m->mothurOutEndLine();
+								ifstream in2;
+								ableToOpen = m->openInputFile(tryPath, in2, "noerror");
+								in2.close();
+								fastaFileNames[i] = tryPath;
+							}
+						}
+						
+						in.close();					
+
+						if (ableToOpen == 1) { 
+							m->mothurOut("Unable to open " + fastaFileNames[i] + ". It will be disregarded."); m->mothurOutEndLine(); 
+							//erase from file list
+							fastaFileNames.erase(fastaFileNames.begin()+i);
+							i--;
+						}else {
+							m->setFastaFile(fastaFileNames[i]);
+						}
 					}
 				}
 				
@@ -294,14 +312,14 @@ int PairwiseSeqsCommand::execute(){
 				
 			if (output == "lt") { //does the user want lower triangle phylip formatted file 
 				outputFile = outputDir + m->getRootName(m->getSimpleName(fastaFileNames[s])) + "phylip.dist";
-				remove(outputFile.c_str()); outputTypes["phylip"].push_back(outputFile);
+				m->mothurRemove(outputFile); outputTypes["phylip"].push_back(outputFile);
 			}else if (output == "column") { //user wants column format
 				outputFile = outputDir + m->getRootName(m->getSimpleName(fastaFileNames[s])) + "dist";
 				outputTypes["column"].push_back(outputFile);
-				remove(outputFile.c_str());
+				m->mothurRemove(outputFile);
 			}else { //assume square
 				outputFile = outputDir + m->getRootName(m->getSimpleName(fastaFileNames[s])) + "square.dist";
-				remove(outputFile.c_str());
+				m->mothurRemove(outputFile);
 				outputTypes["phylip"].push_back(outputFile);
 			}
 			
@@ -339,11 +357,11 @@ int PairwiseSeqsCommand::execute(){
 					
 					driverMPI(start, end, outMPI, cutoff); 
 					
-					if (m->control_pressed) { outputTypes.clear(); MPI_File_close(&outMPI);  remove(outputFile.c_str()); delete distCalculator;  return 0; }
+					if (m->control_pressed) { outputTypes.clear(); MPI_File_close(&outMPI);  m->mothurRemove(outputFile); delete distCalculator;  return 0; }
 				
 					//wait on chidren
 					for(int i = 1; i < processors; i++) { 
-						if (m->control_pressed) { outputTypes.clear();  MPI_File_close(&outMPI);   remove(outputFile.c_str()); delete distCalculator;  return 0; }
+						if (m->control_pressed) { outputTypes.clear();  MPI_File_close(&outMPI);   m->mothurRemove(outputFile); delete distCalculator;  return 0; }
 						
 						char buf[5];
 						MPI_Recv(buf, 5, MPI_CHAR, i, tag, MPI_COMM_WORLD, &status); 
@@ -352,7 +370,7 @@ int PairwiseSeqsCommand::execute(){
 					//do your part
 					driverMPI(start, end, outMPI, cutoff); 
 					
-					if (m->control_pressed) { outputTypes.clear();  MPI_File_close(&outMPI);  remove(outputFile.c_str()); delete distCalculator;  return 0; }
+					if (m->control_pressed) { outputTypes.clear();  MPI_File_close(&outMPI);  m->mothurRemove(outputFile); delete distCalculator;  return 0; }
 				
 					char buf[5];
 					strcpy(buf, "done"); 
@@ -367,12 +385,12 @@ int PairwiseSeqsCommand::execute(){
 				
 					//do your part
 					string outputMyPart;
-					unsigned long int mySize;
+					unsigned long long mySize;
 					
 					if (output != "square"){ driverMPI(start, end, outputFile, mySize); }
 					else { driverMPI(start, end, outputFile, mySize, output); }
 		
-					if (m->control_pressed) {  outputTypes.clear();   remove(outputFile.c_str()); delete distCalculator;  return 0; }
+					if (m->control_pressed) {  outputTypes.clear();   m->mothurRemove(outputFile); delete distCalculator;  return 0; }
 					
 					int amode=MPI_MODE_APPEND|MPI_MODE_WRONLY|MPI_MODE_CREATE; //
 					MPI_File outMPI;
@@ -385,9 +403,9 @@ int PairwiseSeqsCommand::execute(){
 
 					//wait on chidren
 					for(int b = 1; b < processors; b++) { 
-						unsigned long int fileSize;
+						unsigned long long fileSize;
 						
-						if (m->control_pressed) { outputTypes.clear();  MPI_File_close(&outMPI);  remove(outputFile.c_str());  delete distCalculator;  return 0; }
+						if (m->control_pressed) { outputTypes.clear();  MPI_File_close(&outMPI);  m->mothurRemove(outputFile);  delete distCalculator;  return 0; }
 						
 						MPI_Recv(&fileSize, 1, MPI_LONG, b, tag, MPI_COMM_WORLD, &status); 
 						
@@ -413,7 +431,7 @@ int PairwiseSeqsCommand::execute(){
 					MPI_File_close(&outMPI);
 				}else { //you are a child process
 					//do your part
-					unsigned long int size;
+					unsigned long long size;
 					if (output != "square"){ driverMPI(start, end, (outputFile + toString(pid) + ".temp"), size); }
 					else { driverMPI(start, end, (outputFile + toString(pid) + ".temp"), size, output); }
 					
@@ -454,7 +472,7 @@ int PairwiseSeqsCommand::execute(){
 		#endif
 		
 	#endif
-			if (m->control_pressed) { outputTypes.clear();  delete distCalculator; remove(outputFile.c_str()); return 0; }
+			if (m->control_pressed) { outputTypes.clear();  delete distCalculator; m->mothurRemove(outputFile); return 0; }
 			
 			#ifdef USE_MPI
 				MPI_Comm_rank(MPI_COMM_WORLD, &pid); 
@@ -482,7 +500,7 @@ int PairwiseSeqsCommand::execute(){
 			
 			m->mothurOut("It took " + toString(time(NULL) - startTime) + " to calculate the distances for " + toString(numSeqs) + " sequences."); m->mothurOutEndLine();
 			
-			if (m->control_pressed) { outputTypes.clear();  delete distCalculator; remove(outputFile.c_str()); return 0; }
+			if (m->control_pressed) { outputTypes.clear();  delete distCalculator; m->mothurRemove(outputFile); return 0; }
 		}
 			
 		delete distCalculator;
@@ -553,7 +571,7 @@ void PairwiseSeqsCommand::createProcesses(string filename) {
 		//append and remove temp files
 		for (int i=0;i<processIDS.size();i++) { 
 			m->appendFiles((filename + toString(processIDS[i]) + ".temp"), filename);
-			remove((filename + toString(processIDS[i]) + ".temp").c_str());
+			m->mothurRemove((filename + toString(processIDS[i]) + ".temp"));
 		}
 #endif
 	}
@@ -764,7 +782,7 @@ int PairwiseSeqsCommand::driverMPI(int startLine, int endLine, MPI_File& outMPI,
 }
 /**************************************************************************************************/
 /////// need to fix to work with calcs and sequencedb
-int PairwiseSeqsCommand::driverMPI(int startLine, int endLine, string file, unsigned long int& size){
+int PairwiseSeqsCommand::driverMPI(int startLine, int endLine, string file, unsigned long long& size){
 	try {
 		MPI_Status status;
 		
@@ -840,7 +858,7 @@ int PairwiseSeqsCommand::driverMPI(int startLine, int endLine, string file, unsi
 }
 /**************************************************************************************************/
 /////// need to fix to work with calcs and sequencedb
-int PairwiseSeqsCommand::driverMPI(int startLine, int endLine, string file, unsigned long int& size, string square){
+int PairwiseSeqsCommand::driverMPI(int startLine, int endLine, string file, unsigned long long& size, string square){
 	try {
 		MPI_Status status;
 		
