@@ -26,7 +26,9 @@ public:
 	string getCommandName()			{ return "pca";					}
 	string getCommandCategory()		{ return "Hypothesis Testing";	}
 	string getHelpString();	
-	
+	string getCitation() { return "McCune B, Grace JB, Urban DL (2002). Analysis of ecological communities. MjM Software Design: Gleneden Beach, OR. \nLegendre P, Legendre L (1998). Numerical Ecology. Elsevier: New York. \nhttp://www.mothur.org/wiki/Pca"; }
+	string getDescription()		{ return "pca"; }
+
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
 	
