@@ -170,13 +170,13 @@ int Pintail::doPrep() {
 			string noOutliers, outliers;
 			
 			if ((!filter) && (seqMask == "")) {
-				noOutliers = templateFileName + "pintail.quan";
+				noOutliers = m->getRootName(m->getSimpleName(templateFileName)) + "pintail.quan";
 			}else if ((!filter) && (seqMask != "")) { 
-				noOutliers =templateFileName + "pintail.masked.quan";
+				noOutliers =m->getRootName(m->getSimpleName(templateFileName)) + "pintail.masked.quan";
 			}else if ((filter) && (seqMask != "")) { 
-				noOutliers = templateFileName + "pintail.filtered." + m->getSimpleName(m->getRootName(fastafile)) + "masked.quan";
+				noOutliers = m->getRootName(m->getSimpleName(templateFileName)) + "pintail.filtered." + m->getSimpleName(m->getRootName(fastafile)) + "masked.quan";
 			}else if ((filter) && (seqMask == "")) { 
-				noOutliers = templateFileName + "pintail.filtered." + m->getSimpleName(m->getRootName(fastafile)) + "quan";
+				noOutliers = m->getRootName(m->getSimpleName(templateFileName)) + "pintail.filtered." + m->getSimpleName(m->getRootName(fastafile)) + "quan";
 			}
 
 			decalc->removeObviousOutliers(quantilesMembers, templateSeqs.size());
@@ -249,7 +249,7 @@ int Pintail::doPrep() {
 	}
 }
 //***************************************************************************************************************
-Sequence* Pintail::print(ostream& out, ostream& outAcc) {
+Sequence Pintail::print(ostream& out, ostream& outAcc) {
 	try {
 		
 		int index = ceil(deviation);
@@ -280,7 +280,7 @@ Sequence* Pintail::print(ostream& out, ostream& outAcc) {
 		for (int m = 0; m < expectedDistance.size(); m++) {  out << expectedDistance[m] << '\t';  }
 		out << endl;
 		
-		return NULL;
+		return *querySeq;
 		
 	}
 	catch(exception& e) {
@@ -290,7 +290,7 @@ Sequence* Pintail::print(ostream& out, ostream& outAcc) {
 }
 #ifdef USE_MPI
 //***************************************************************************************************************
-Sequence* Pintail::print(MPI_File& out, MPI_File& outAcc) {
+Sequence Pintail::print(MPI_File& out, MPI_File& outAcc) {
 	try {
 		
 		string outputString = "";
@@ -320,7 +320,7 @@ Sequence* Pintail::print(MPI_File& out, MPI_File& outAcc) {
 			MPI_File_write_shared(outAcc, buf, length, MPI_CHAR, &statusAcc);
 			delete buf;
 
-			return NULL;
+			return *querySeq;
 		}
 		outputString += "Observed\t";
 		
@@ -340,7 +340,7 @@ Sequence* Pintail::print(MPI_File& out, MPI_File& outAcc) {
 		MPI_File_write_shared(out, buf2, length, MPI_CHAR, &status);
 		delete buf2;
 		
-		return NULL;
+		return *querySeq;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "Pintail", "print");
@@ -612,7 +612,7 @@ void Pintail::createProcessesQuan() {
 			}
 					
 			in.close();
-			remove(s.c_str());
+			m->mothurRemove(s);
 		}
 
 #else
