@@ -38,6 +38,7 @@ vector<string> RareFactCommand::setParameters(){
 		CommandParameter pcalc("calc", "Multiple", "sobs-chao-nseqs-coverage-ace-jack-shannon-shannoneven-npshannon-heip-smithwilson-simpson-simpsoneven-invsimpson-bootstrap", "sobs", "", "", "",true,false); parameters.push_back(pcalc);
 		CommandParameter pabund("abund", "Number", "", "10", "", "", "",false,false); parameters.push_back(pabund);
 		CommandParameter pprocessors("processors", "Number", "", "1", "", "", "",false,false); parameters.push_back(pprocessors);
+		CommandParameter pgroupmode("groupmode", "Boolean", "", "T", "", "", "",false,false); parameters.push_back(pgroupmode);
 		CommandParameter pinputdir("inputdir", "String", "", "", "", "", "",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "",false,false); parameters.push_back(poutputdir);
 		
@@ -63,6 +64,7 @@ string RareFactCommand::getHelpString(){
 		helpString += "Example rarefaction.single(label=unique-.01-.03, iters=10000, freq=10, calc=sobs-rchao-race-rjack-rbootstrap-rshannon-rnpshannon-rsimpson).\n";
 		helpString += "The default values for iters is 1000, freq is 100, and calc is rarefaction which calculates the rarefaction curve for the observed richness.\n";
 		validCalculator.printCalc("rarefaction");
+		helpString += "If you are running rarefaction.single with a shared file and would like your results collated in one file, set groupmode=t. (Default=true).\n";
 		helpString += "The label parameter is used to analyze specific labels in your input.\n";
 		helpString += "Note: No spaces between parameter labels (i.e. freq), '=' and parameters (i.e.yourFreq).\n";
 		return helpString;
@@ -107,7 +109,8 @@ RareFactCommand::RareFactCommand(string option)  {
 		allLines = 1;
 						
 		//allow user to run help
-		if(option == "help") { abort = true; calledHelp = true; }
+		if(option == "help") { help(); abort = true; calledHelp = true; }
+		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
 		
 		else {
 			vector<string> myArray = setParameters();
@@ -183,22 +186,22 @@ RareFactCommand::RareFactCommand(string option)  {
 			listfile = validParameter.validFile(parameters, "list", true);
 			if (listfile == "not open") { listfile = ""; abort = true; }
 			else if (listfile == "not found") { listfile = ""; }
-			else {  format = "list"; inputfile = listfile; }
+			else {  format = "list"; inputfile = listfile; m->setListFile(listfile); }
 			
 			sabundfile = validParameter.validFile(parameters, "sabund", true);
 			if (sabundfile == "not open") { sabundfile = ""; abort = true; }	
 			else if (sabundfile == "not found") { sabundfile = ""; }
-			else {  format = "sabund"; inputfile = sabundfile; }
+			else {  format = "sabund"; inputfile = sabundfile; m->setSabundFile(sabundfile); }
 			
 			rabundfile = validParameter.validFile(parameters, "rabund", true);
 			if (rabundfile == "not open") { rabundfile = ""; abort = true; }	
 			else if (rabundfile == "not found") { rabundfile = ""; }
-			else {  format = "rabund"; inputfile = rabundfile; }
+			else {  format = "rabund"; inputfile = rabundfile; m->setRabundFile(rabundfile); }
 			
 			sharedfile = validParameter.validFile(parameters, "shared", true);
 			if (sharedfile == "not open") { sharedfile = ""; abort = true; }	
 			else if (sharedfile == "not found") { sharedfile = ""; }
-			else {  format = "sharedfile"; inputfile = sharedfile; }
+			else {  format = "sharedfile"; inputfile = sharedfile; m->setSharedFile(sharedfile); }
 				
 			if ((sharedfile == "") && (listfile == "") && (rabundfile == "") && (sabundfile == "")) { 
 				//is there are current file available for any of these?
@@ -242,6 +245,11 @@ RareFactCommand::RareFactCommand(string option)  {
 				 if (calc == "default")  {  calc = "sobs";  }
 			}
 			m->splitAtDash(calc, Estimators);
+			if (m->inUsersGroups("citation", Estimators)) { 
+				ValidCalculators validCalc; validCalc.printCitations(Estimators); 
+				//remove citation from list of calcs
+				for (int i = 0; i < Estimators.size(); i++) { if (Estimators[i] == "citation") {  Estimators.erase(Estimators.begin()+i); break; } }
+			}
 
 			string temp;
 			temp = validParameter.validFile(parameters, "freq", false);			if (temp == "not found") { temp = "100"; }
@@ -256,6 +264,9 @@ RareFactCommand::RareFactCommand(string option)  {
 			temp = validParameter.validFile(parameters, "processors", false);	if (temp == "not found"){	temp = m->getProcessors();	}
 			m->setProcessors(temp);
 			convert(temp, processors);
+			
+			temp = validParameter.validFile(parameters, "groupmode", false);		if (temp == "not found") { temp = "T"; }
+			groupMode = m->isTrue(temp);
 		}
 		
 	}
@@ -280,7 +291,7 @@ int RareFactCommand::execute(){
 			
 			string fileNameRoot = outputDir + m->getRootName(m->getSimpleName(inputFileNames[p]));
 						
-			if (m->control_pressed) {  outputTypes.clear(); for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); 	}  m->Groups.clear();  return 0; }
+			if (m->control_pressed) {  outputTypes.clear(); for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); 	}  m->clearGroups();  return 0; }
 			
 			if (inputFileNames.size() > 1) {
 				m->mothurOutEndLine(); m->mothurOut("Processing group " + groups[p]); m->mothurOutEndLine(); m->mothurOutEndLine();
@@ -354,12 +365,12 @@ int RareFactCommand::execute(){
 			set<string> processedLabels;
 			set<string> userLabels = labels;
 			
-			if (m->control_pressed) { for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}  delete input;  delete order;  for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); } return 0; }
+			if (m->control_pressed) { for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}  delete input;  delete order;  for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0; }
 			
 			//as long as you are not at the end of the file or done wih the lines you want
 			while((order != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
 				
-				if (m->control_pressed) { for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}  delete input;  delete order;  for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); } return 0; }
+				if (m->control_pressed) { for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}  delete input;  delete order;  for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0; }
 
 				
 				if(allLines == 1 || labels.count(order->getLabel()) == 1){
@@ -397,7 +408,7 @@ int RareFactCommand::execute(){
 				order = (input->getOrderVector());
 			}
 			
-			if (m->control_pressed) { for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}  delete input;   for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); } return 0; }
+			if (m->control_pressed) { for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}  delete input;   for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0; }
 
 			//output error messages about any remaining user labels
 			set<string>::iterator it;
@@ -412,7 +423,7 @@ int RareFactCommand::execute(){
 				}
 			}
 			
-			if (m->control_pressed) { for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}  delete input;   for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); } return 0; }
+			if (m->control_pressed) { for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}  delete input;   for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0; }
 
 			//run last label if you need to
 			if (needToRun == true)  {
@@ -434,7 +445,12 @@ int RareFactCommand::execute(){
 		}
 		
 		
-		if (m->control_pressed) {  for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); } return 0; }
+		if (m->control_pressed) {  for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0; }
+
+		//create summary file containing all the groups data for each label - this function just combines the info from the files already created.
+		if ((sharedfile != "") && (groupMode)) {   outputNames = createGroupFile(outputNames);  }
+
+		if (m->control_pressed) {  for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0; }
 
 		m->mothurOutEndLine();
 		m->mothurOut("Output File Names: "); m->mothurOutEndLine();
@@ -449,6 +465,114 @@ int RareFactCommand::execute(){
 	}
 }
 //**********************************************************************************************************************
+vector<string> RareFactCommand::createGroupFile(vector<string>& outputNames) {
+	try {
+		
+		vector<string> newFileNames;
+		
+		//find different types of files
+		map<string, vector<string> > typesFiles;
+		for (int i = 0; i < outputNames.size(); i++) {
+			string extension = m->getExtension(outputNames[i]);
+			
+			ifstream in;
+			m->openInputFile(outputNames[i], in);
+			
+			string labels = m->getline(in);
+			string newLine = labels.substr(0, labels.find_first_of('\t'));
+			
+			newLine += "\tGroup" + labels.substr(labels.find_first_of('\t'));
+			
+			typesFiles[extension].push_back(outputNames[i]);
+			
+			string combineFileName = outputDir + m->getRootName(m->getSimpleName(sharedfile)) + "groups" + extension;
+			
+			//print headers
+			ofstream out;
+			m->openOutputFile(combineFileName, out);
+			out << newLine << endl;
+			out.close();
+			
+		}
+		
+		//for each type create a combo file
+		for (map<string, vector<string> >::iterator it = typesFiles.begin(); it != typesFiles.end(); it++) {
+			
+			ofstream out;
+			string combineFileName = outputDir + m->getRootName(m->getSimpleName(sharedfile)) + "groups" + it->first;
+			m->openOutputFileAppend(combineFileName, out);
+			newFileNames.push_back(combineFileName);
+			
+			vector<string> thisTypesFiles = it->second;
+		
+			//open each type summary file
+			map<string, vector<string> > files; //maps file name to lines in file
+			int maxLines = 0;
+			for (int i=0; i<thisTypesFiles.size(); i++) {
+								
+				ifstream temp;
+				m->openInputFile(thisTypesFiles[i], temp);
+				
+				//read through first line - labels
+				m->getline(temp);	m->gobble(temp);
+				
+				vector<string> thisFilesLines;
+				string group = m->getRootName(thisTypesFiles[i]);
+				group = group.substr(0, group.length()-1);
+				group = group.substr(group.find_last_of('.')+1);
+				
+				thisFilesLines.push_back(group);
+				while (!temp.eof()){
+				
+					string thisLine = m->getline(temp);
+										
+					thisFilesLines.push_back(thisLine);
+					
+					m->gobble(temp);
+				}
+				
+				files[thisTypesFiles[i]] = thisFilesLines;
+				
+				//save longest file for below
+				if (maxLines < thisFilesLines.size()) { maxLines = thisFilesLines.size(); }
+				
+				temp.close();
+				m->mothurRemove(thisTypesFiles[i]);
+			}
+			
+			
+			//for each label
+			for (int k = 1; k < maxLines; k++) {
+				
+				//grab data for each group
+				for (int i=0; i<thisTypesFiles.size(); i++) {
+					
+					string output = "NA\t";
+					if (k < files[thisTypesFiles[i]].size()) {
+						string line = files[thisTypesFiles[i]][k];
+						output = line.substr(0, line.find_first_of('\t'));
+						output += '\t' + files[thisTypesFiles[i]][0] + '\t' + line.substr(line.find_first_of('\t'));
+					}else{
+						output += '\t' + files[thisTypesFiles[i]][0] + '\t';
+					}
+					out << output << endl;
+				}
+			}	
+			
+			out.close();
+			
+		}
+		
+		//return combine file name
+		return newFileNames;
+		
+	}
+	catch(exception& e) {
+		m->errorOut(e, "RareFactCommand", "createGroupFile");
+		exit(1);
+	}
+}
+//**********************************************************************************************************************
 vector<string> RareFactCommand::parseSharedFile(string filename) {
 	try {
 		vector<string> filenames;
@@ -463,7 +587,7 @@ vector<string> RareFactCommand::parseSharedFile(string filename) {
 		
 		//clears file before we start to write to it below
 		for (int i=0; i<lookup.size(); i++) {
-			remove((sharedFileRoot + lookup[i]->getGroup() + ".rabund").c_str());
+			m->mothurRemove((sharedFileRoot + lookup[i]->getGroup() + ".rabund"));
 			filenames.push_back((sharedFileRoot + lookup[i]->getGroup() + ".rabund"));
 		}
 		
@@ -493,7 +617,7 @@ vector<string> RareFactCommand::parseSharedFile(string filename) {
 		}
 		
 		delete input;
-		m->Groups.clear();
+		m->clearGroups();
 
 		return filenames;
 	}
