@@ -27,7 +27,9 @@ public:
 	string getCommandName()			{ return "rarefaction.single";		}
 	string getCommandCategory()		{ return "OTU-Based Approaches";	}
 	string getHelpString();	
-	
+	string getCitation() { return "Magurran AE (2004). Measuring biological diversity. Blackwell Pub.: Malden, Ma. \nhttp://www.mothur.org/wiki/Rarefaction.single"; }
+	string getDescription()		{ return "generate intra-sample rarefaction curves using a re-sampling without replacement approach"; }
+
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
 	
@@ -40,7 +42,7 @@ private:
 	int nIters, abund, processors;
 	float freq;
 	
-	bool abort, allLines;
+	bool abort, allLines, groupMode;
 	set<string> labels; //holds labels to be used
 	string label, calc, sharedfile, listfile, rabundfile, sabundfile, format, inputfile;
 	vector<string>  Estimators;
@@ -49,6 +51,7 @@ private:
 	string outputDir;
 	
 	vector<string> parseSharedFile(string);
+	vector<string> createGroupFile(vector<string>&);
 };
 
 #endif
