@@ -26,6 +26,8 @@ public:
 	string getCommandName()			{ return "remove.groups";			}
 	string getCommandCategory()		{ return "OTU-Based Approaches";	}
 	string getHelpString();	
+	string getCitation() { return "http://www.mothur.org/wiki/Remove.groups"; }
+	string getDescription()		{ return "removes sequences from a list, fasta, name, group or taxonomy file from a given group or set of groups"; }
 	
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
@@ -33,12 +35,13 @@ public:
 	
 private:
 	set<string> names;
-	string accnosfile, fastafile, namefile, groupfile, listfile, taxfile, outputDir, groups;
+	string accnosfile, fastafile, namefile, groupfile, listfile, taxfile, outputDir, groups, sharedfile;
 	bool abort;
 	vector<string> outputNames, Groups;
 	GroupMap* groupMap;
 	
 	int readFasta();
+	int readShared();
 	int readName();
 	int readGroup();
 	void readAccnos();
