@@ -24,13 +24,15 @@ class RemoveLineageCommand : public Command {
 		string getCommandName()			{ return "remove.lineage";			}
 		string getCommandCategory()		{ return "Phylotype Analysis";		}
 		string getHelpString();	
-	
+		string getCitation() { return "http://www.mothur.org/wiki/Remove.lineage"; }
+		string getDescription()		{ return "removes sequences from a list, fasta, name, group, alignreport or taxonomy file from a given taxonomy or set of taxonomies"; }
+
 		int execute(); 
 		void help() { m->mothurOut(getHelpString()); }	
 	
 	private:
 		set<string> names;
-		vector<string> outputNames;
+		vector<string> outputNames, listOfTaxons;
 		string fastafile, namefile, groupfile, alignfile, listfile, taxfile, outputDir, taxons;
 		bool abort, dups;
 		
