@@ -26,7 +26,9 @@ public:
 	string getCommandName()			{ return "remove.otus";				}
 	string getCommandCategory()		{ return "OTU-Based Approaches";	}
 	string getHelpString();	
-	
+	string getCitation() { return "http://www.mothur.org/wiki/Remove.otus"; }
+	string getDescription()		{ return "outputs a new list file containing the otus NOT containing sequences from the groups specified"; }
+
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
 	
