@@ -81,6 +81,7 @@ RemoveSeqsCommand::RemoveSeqsCommand(string option)  {
 		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
+		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
 		
 		else {
 			vector<string> myArray = setParameters();
@@ -190,19 +191,22 @@ RemoveSeqsCommand::RemoveSeqsCommand(string option)  {
 					m->mothurOut("You have no valid accnos file and accnos is required."); m->mothurOutEndLine(); 
 					abort = true;
 				}  
-			}	
+			}else { m->setAccnosFile(accnosfile); }	
 			
 			fastafile = validParameter.validFile(parameters, "fasta", true);
 			if (fastafile == "not open") { abort = true; }
 			else if (fastafile == "not found") {  fastafile = "";  }	
-			
+			else { m->setFastaFile(fastafile); }
+								   
 			namefile = validParameter.validFile(parameters, "name", true);
 			if (namefile == "not open") { abort = true; }
 			else if (namefile == "not found") {  namefile = "";  }	
-			
+			else { m->setNameFile(namefile); } 
+								   
 			groupfile = validParameter.validFile(parameters, "group", true);
 			if (groupfile == "not open") { abort = true; }
-			else if (groupfile == "not found") {  groupfile = "";  }	
+			else if (groupfile == "not found") {  groupfile = "";  }
+			else { m->setGroupFile(groupfile); }
 			
 			alignfile = validParameter.validFile(parameters, "alignreport", true);
 			if (alignfile == "not open") { abort = true; }
@@ -211,15 +215,17 @@ RemoveSeqsCommand::RemoveSeqsCommand(string option)  {
 			listfile = validParameter.validFile(parameters, "list", true);
 			if (listfile == "not open") { abort = true; }
 			else if (listfile == "not found") {  listfile = "";  }
+			else { m->setListFile(listfile); }
 			
 			taxfile = validParameter.validFile(parameters, "taxonomy", true);
 			if (taxfile == "not open") { abort = true; }
 			else if (taxfile == "not found") {  taxfile = "";  }
+			else { m->setTaxonomyFile(taxfile); }
 			
 			qualfile = validParameter.validFile(parameters, "qfile", true);
 			if (qualfile == "not open") { abort = true; }
 			else if (qualfile == "not found") {  qualfile = "";  }			
-
+			else { m->setQualFile(qualfile); }
 			
 			string usedDups = "true";
 			string temp = validParameter.validFile(parameters, "dups", false);	
@@ -260,10 +266,8 @@ int RemoveSeqsCommand::execute(){
 		if (taxfile != "")			{		readTax();		}
 		if (qualfile != "")			{		readQual();		}
 		
-		if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); } return 0; }
-		
-		m->mothurOut("Removed " + toString(names.size()) + " sequences."); m->mothurOutEndLine();
-		
+		if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0; }
+	
 		if (outputNames.size() != 0) {
 			m->mothurOutEndLine();
 			m->mothurOut("Output File Names: "); m->mothurOutEndLine();
@@ -327,9 +331,10 @@ int RemoveSeqsCommand::readFasta(){
 		string name;
 		
 		bool wroteSomething = false;
+		int removedCount = 0;
 		
 		while(!in.eof()){
-			if (m->control_pressed) { in.close();  out.close();  remove(outputFileName.c_str());  return 0; }
+			if (m->control_pressed) { in.close();  out.close();  m->mothurRemove(outputFileName);  return 0; }
 			
 			Sequence currSeq(in);
 			name = currSeq.getName();
@@ -340,7 +345,7 @@ int RemoveSeqsCommand::readFasta(){
 					wroteSomething = true;
 					
 					currSeq.printSequence(out);
-				}
+				}else {  removedCount++;  }
 			}
 			m->gobble(in);
 		}
@@ -350,6 +355,8 @@ int RemoveSeqsCommand::readFasta(){
 		if (wroteSomething == false) {  m->mothurOut("Your file contains only sequences from the .accnos file."); m->mothurOutEndLine();  }
 		outputTypes["fasta"].push_back(outputFileName);  outputNames.push_back(outputFileName);
 		
+		m->mothurOut("Removed " + toString(removedCount) + " sequences from your fasta file."); m->mothurOutEndLine();
+		
 		return 0;
 		
 	}
@@ -373,6 +380,7 @@ int RemoveSeqsCommand::readQual(){
 		string name;
 		
 		bool wroteSomething = false;
+		int removedCount = 0;
 		
 		
 		while(!in.eof()){	
@@ -404,7 +412,7 @@ int RemoveSeqsCommand::readQual(){
 				wroteSomething = true;
 				
 				out << name << endl << scores;
-			}
+			}else {  removedCount++;  }
 			
 			m->gobble(in);
 		}
@@ -415,6 +423,8 @@ int RemoveSeqsCommand::readQual(){
 		if (wroteSomething == false) { m->mothurOut("Your file contains only sequences from the .accnos file."); m->mothurOutEndLine();  }
 		outputNames.push_back(outputFileName);  outputTypes["qfile"].push_back(outputFileName); 
 		
+		m->mothurOut("Removed " + toString(removedCount) + " sequences from your quality file."); m->mothurOutEndLine();
+		
 		return 0;
 		
 	}
@@ -437,8 +447,12 @@ int RemoveSeqsCommand::readList(){
 		m->openInputFile(listfile, in);
 		
 		bool wroteSomething = false;
+		int removedCount = 0;
 		
 		while(!in.eof()){
+			
+			removedCount = 0;
+			
 			//read in list vector
 			ListVector list(in);
 			
@@ -448,7 +462,7 @@ int RemoveSeqsCommand::readList(){
 			
 			//for each bin
 			for (int i = 0; i < list.getNumBins(); i++) {
-				if (m->control_pressed) { in.close();  out.close();  remove(outputFileName.c_str());  return 0; }
+				if (m->control_pressed) { in.close();  out.close();  m->mothurRemove(outputFileName);  return 0; }
 			
 				//parse out names that are in accnos file
 				string binnames = list.get(i);
@@ -460,10 +474,12 @@ int RemoveSeqsCommand::readList(){
 					
 					//if that name is in the .accnos file, add it
 					if (names.count(name) == 0) {  newNames += name + ",";  }
+					else {  removedCount++;  }
 				}
 			
 				//get last name
 				if (names.count(binnames) == 0) {  newNames += binnames + ",";  }
+				else {  removedCount++;  }
 
 				//if there are names in this bin add to new list
 				if (newNames != "") {  
@@ -485,7 +501,9 @@ int RemoveSeqsCommand::readList(){
 		
 		if (wroteSomething == false) {  m->mothurOut("Your file contains only sequences from the .accnos file."); m->mothurOutEndLine();  }
 		outputTypes["list"].push_back(outputFileName); outputNames.push_back(outputFileName);
-				
+		
+		m->mothurOut("Removed " + toString(removedCount) + " sequences from your list file."); m->mothurOutEndLine();
+		
 		return 0;
 
 	}
@@ -509,10 +527,10 @@ int RemoveSeqsCommand::readName(){
 		string name, firstCol, secondCol;
 		
 		bool wroteSomething = false;
-				
+		int removedCount = 0;
 		
 		while(!in.eof()){
-			if (m->control_pressed) { in.close();  out.close();  remove(outputFileName.c_str());  return 0; }
+			if (m->control_pressed) { in.close();  out.close();  m->mothurRemove(outputFileName);  return 0; }
 			
 			in >> firstCol;		m->gobble(in);		
 			in >> secondCol;			
@@ -529,7 +547,9 @@ int RemoveSeqsCommand::readName(){
 			
 			if ((dups) && (validSecond.size() != parsedNames.size())) {  //if dups is true and we want to get rid of anyone, get rid of everyone
 				for (int i = 0; i < parsedNames.size(); i++) {  names.insert(parsedNames[i]);  }
+				removedCount += parsedNames.size();
 			}else {
+				removedCount += parsedNames.size()-validSecond.size();
 				//if the name in the first column is in the set then print it and any other names in second column also in set
 				if (names.count(firstCol) == 0) {
 					
@@ -565,6 +585,8 @@ int RemoveSeqsCommand::readName(){
 		if (wroteSomething == false) {  m->mothurOut("Your file contains only sequences from the .accnos file."); m->mothurOutEndLine();  }
 		outputTypes["name"].push_back(outputFileName); outputNames.push_back(outputFileName);
 		
+		m->mothurOut("Removed " + toString(removedCount) + " sequences from your name file."); m->mothurOutEndLine();
+		
 		return 0;
 	}
 	catch(exception& e) {
@@ -588,9 +610,10 @@ int RemoveSeqsCommand::readGroup(){
 		string name, group;
 		
 		bool wroteSomething = false;
+		int removedCount = 0;
 		
 		while(!in.eof()){
-			if (m->control_pressed) { in.close();  out.close();  remove(outputFileName.c_str());  return 0; }
+			if (m->control_pressed) { in.close();  out.close();  m->mothurRemove(outputFileName);  return 0; }
 			
 			in >> name;				//read from first column
 			in >> group;			//read from second column
@@ -599,7 +622,7 @@ int RemoveSeqsCommand::readGroup(){
 			if (names.count(name) == 0) {
 				wroteSomething = true;
 				out << name << '\t' << group << endl;
-			}
+			}else {  removedCount++;  }
 					
 			m->gobble(in);
 		}
@@ -609,6 +632,9 @@ int RemoveSeqsCommand::readGroup(){
 		if (wroteSomething == false) {  m->mothurOut("Your file contains only sequences from the .accnos file."); m->mothurOutEndLine();  }
 		outputTypes["group"].push_back(outputFileName); outputNames.push_back(outputFileName);
 		
+		m->mothurOut("Removed " + toString(removedCount) + " sequences from your group file."); m->mothurOutEndLine();
+
+		
 		return 0;
 	}
 	catch(exception& e) {
@@ -630,9 +656,10 @@ int RemoveSeqsCommand::readTax(){
 		string name, tax;
 		
 		bool wroteSomething = false;
+		int removedCount = 0;
 		
 		while(!in.eof()){
-			if (m->control_pressed) { in.close();  out.close();  remove(outputFileName.c_str());  return 0; }
+			if (m->control_pressed) { in.close();  out.close();  m->mothurRemove(outputFileName);  return 0; }
 			
 			in >> name;				//read from first column
 			in >> tax;			//read from second column
@@ -641,7 +668,7 @@ int RemoveSeqsCommand::readTax(){
 			if (names.count(name) == 0) {
 				wroteSomething = true;
 				out << name << '\t' << tax << endl;
-			}
+			}else {  removedCount++;  }
 					
 			m->gobble(in);
 		}
@@ -651,6 +678,8 @@ int RemoveSeqsCommand::readTax(){
 		if (wroteSomething == false) {  m->mothurOut("Your file contains only sequences from the .accnos file."); m->mothurOutEndLine();  }
 		outputTypes["taxonomy"].push_back(outputFileName); outputNames.push_back(outputFileName);
 		
+		m->mothurOut("Removed " + toString(removedCount) + " sequences from your taxonomy file."); m->mothurOutEndLine();
+		
 		return 0;
 	}
 	catch(exception& e) {
@@ -674,6 +703,7 @@ int RemoveSeqsCommand::readAlign(){
 		string name, junk;
 		
 		bool wroteSomething = false;
+		int removedCount = 0;
 		
 		//read column headers
 		for (int i = 0; i < 16; i++) {  
@@ -683,7 +713,7 @@ int RemoveSeqsCommand::readAlign(){
 		out << endl;
 		
 		while(!in.eof()){
-			if (m->control_pressed) { in.close();  out.close();  remove(outputFileName.c_str());  return 0; }
+			if (m->control_pressed) { in.close();  out.close();  m->mothurRemove(outputFileName);  return 0; }
 			
 			in >> name;				//read from first column
 			
@@ -701,6 +731,7 @@ int RemoveSeqsCommand::readAlign(){
 				out << endl;
 				
 			}else {//still read just don't do anything with it
+				removedCount++;  
 				
 				//read rest
 				for (int i = 0; i < 15; i++) {  
@@ -717,6 +748,9 @@ int RemoveSeqsCommand::readAlign(){
 		if (wroteSomething == false) {  m->mothurOut("Your file contains only sequences from the .accnos file."); m->mothurOutEndLine();  }
 		outputTypes["alignreport"].push_back(outputFileName); outputNames.push_back(outputFileName);
 		
+		m->mothurOut("Removed " + toString(removedCount) + " sequences from your alignreport file."); m->mothurOutEndLine();
+
+		
 		return 0;
 		
 	}
