@@ -16,6 +16,7 @@ vector<string> ScreenSeqsCommand::setParameters(){
 		CommandParameter pfasta("fasta", "InputTypes", "", "", "none", "none", "none",false,true); parameters.push_back(pfasta);
 		CommandParameter pname("name", "InputTypes", "", "", "none", "none", "none",false,false); parameters.push_back(pname);
 		CommandParameter pgroup("group", "InputTypes", "", "", "none", "none", "none",false,false); parameters.push_back(pgroup);
+		CommandParameter pqfile("qfile", "InputTypes", "", "", "none", "none", "none",false,false); parameters.push_back(pqfile);
 		CommandParameter palignreport("alignreport", "InputTypes", "", "", "none", "none", "none",false,false); parameters.push_back(palignreport);
 		CommandParameter pstart("start", "Number", "", "-1", "", "", "",false,false); parameters.push_back(pstart);
 		CommandParameter pend("end", "Number", "", "-1", "", "", "",false,false); parameters.push_back(pend);
@@ -43,7 +44,7 @@ string ScreenSeqsCommand::getHelpString(){
 	try {
 		string helpString = "";
 		helpString += "The screen.seqs command reads a fastafile and creates .....\n";
-		helpString += "The screen.seqs command parameters are fasta, start, end, maxambig, maxhomop, minlength, maxlength, name, group, optimize, criteria and processors.\n";
+		helpString += "The screen.seqs command parameters are fasta, start, end, maxambig, maxhomop, minlength, maxlength, name, group, qfile, optimize, criteria and processors.\n";
 		helpString += "The fasta parameter is required.\n";
 		helpString += "The start parameter .... The default is -1.\n";
 		helpString += "The end parameter .... The default is -1.\n";
@@ -78,6 +79,7 @@ ScreenSeqsCommand::ScreenSeqsCommand(){
 		outputTypes["group"] = tempOutNames;
 		outputTypes["alignreport"] = tempOutNames;
 		outputTypes["accnos"] = tempOutNames;
+		outputTypes["qfile"] = tempOutNames;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "ScreenSeqsCommand", "ScreenSeqsCommand");
@@ -92,6 +94,7 @@ ScreenSeqsCommand::ScreenSeqsCommand(string option)  {
 		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
+		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
 		
 		else {
 			vector<string> myArray = setParameters();
@@ -114,6 +117,7 @@ ScreenSeqsCommand::ScreenSeqsCommand(string option)  {
 			outputTypes["group"] = tempOutNames;
 			outputTypes["alignreport"] = tempOutNames;
 			outputTypes["accnos"] = tempOutNames;
+			outputTypes["qfile"] = tempOutNames;
 			
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
 			string inputDir = validParameter.validFile(parameters, "inputdir", false);		
@@ -151,6 +155,15 @@ ScreenSeqsCommand::ScreenSeqsCommand(string option)  {
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["alignreport"] = inputDir + it->second;		}
 				}
+				
+				it = parameters.find("qfile");
+				//user has given a template file
+				if(it != parameters.end()){ 
+					path = m->hasPath(it->second);
+					//if the user has not given a path then, add inputdir. else leave path alone.
+					if (path == "") {	parameters["qfile"] = inputDir + it->second;		}
+				}
+				
 			}
 
 			//check for required parameters
@@ -160,16 +173,24 @@ ScreenSeqsCommand::ScreenSeqsCommand(string option)  {
 				if (fastafile != "") { m->mothurOut("Using " + fastafile + " as input file for the fasta parameter."); m->mothurOutEndLine(); }
 				else { 	m->mothurOut("You have no current fastafile and the fasta parameter is required."); m->mothurOutEndLine(); abort = true; }
 			}
-			else if (fastafile == "not open") { abort = true; }	
+			else if (fastafile == "not open") { abort = true; }
+			else { m->setFastaFile(fastafile); }
 	
 			groupfile = validParameter.validFile(parameters, "group", true);
 			if (groupfile == "not open") { abort = true; }	
 			else if (groupfile == "not found") { groupfile = ""; }
+			else { m->setGroupFile(groupfile); }
+			
+			qualfile = validParameter.validFile(parameters, "qfile", true);
+			if (qualfile == "not open") { abort = true; }	
+			else if (qualfile == "not found") { qualfile = ""; }
+			else { m->setQualFile(qualfile); }
 			
 			namefile = validParameter.validFile(parameters, "name", true);
 			if (namefile == "not open") { namefile = ""; abort = true; }
 			else if (namefile == "not found") { namefile = ""; }	
-
+			else { m->setNameFile(namefile); }
+			
 			alignreport = validParameter.validFile(parameters, "alignreport", true);
 			if (alignreport == "not open") { abort = true; }
 			else if (alignreport == "not found") { alignreport = ""; }	
@@ -240,7 +261,7 @@ int ScreenSeqsCommand::execute(){
 		if (abort == true) { if (calledHelp) { return 0; }  return 2;	}
 		
 		//if the user want to optimize we need to know the 90% mark
-		vector<unsigned long int> positions;
+		vector<unsigned long long> positions;
 		if (optimize.size() != 0) {  //get summary is paralellized so we need to divideFile, no need to do this step twice so I moved it here
 			//use the namefile to optimize correctly
 			if (namefile != "") { nameMap = m->readNames(namefile); }
@@ -263,7 +284,7 @@ int ScreenSeqsCommand::execute(){
 #ifdef USE_MPI	
 			int pid, numSeqsPerProcessor; 
 			int tag = 2001;
-			vector<unsigned long int> MPIPos;
+			vector<unsigned long long> MPIPos;
 			
 			MPI_Status status; 
 			MPI_Comm_rank(MPI_COMM_WORLD, &pid); //find out who we are
@@ -373,7 +394,7 @@ int ScreenSeqsCommand::execute(){
 			if(processors == 1){
 				numFastaSeqs = driver(lines[0], goodSeqFile, badAccnosFile, fastafile, badSeqNames);
 				
-				if (m->control_pressed) { remove(goodSeqFile.c_str()); return 0; }
+				if (m->control_pressed) { m->mothurRemove(goodSeqFile); return 0; }
 				
 			}else{
 				processIDS.resize(0);
@@ -386,13 +407,13 @@ int ScreenSeqsCommand::execute(){
 				//append alignment and report files
 				for(int i=1;i<processors;i++){
 					m->appendFiles((goodSeqFile + toString(processIDS[i]) + ".temp"), goodSeqFile);
-					remove((goodSeqFile + toString(processIDS[i]) + ".temp").c_str());
+					m->mothurRemove((goodSeqFile + toString(processIDS[i]) + ".temp"));
 			
 					m->appendFiles((badAccnosFile + toString(processIDS[i]) + ".temp"), badAccnosFile);
-					remove((badAccnosFile + toString(processIDS[i]) + ".temp").c_str());
+					m->mothurRemove((badAccnosFile + toString(processIDS[i]) + ".temp"));
 				}
 				
-				if (m->control_pressed) { remove(goodSeqFile.c_str()); return 0; }
+				if (m->control_pressed) { m->mothurRemove(goodSeqFile); return 0; }
 				
 				//read badSeqs in because root process doesnt know what other "bad" seqs the children found
 				ifstream inBad;
@@ -411,7 +432,7 @@ int ScreenSeqsCommand::execute(){
 	#else
 			numFastaSeqs = driver(lines[0], goodSeqFile, badAccnosFile, fastafile, badSeqNames);
 			
-			if (m->control_pressed) { remove(goodSeqFile.c_str()); return 0; }
+			if (m->control_pressed) { m->mothurRemove(goodSeqFile); return 0; }
 			
 	#endif
 
@@ -452,17 +473,18 @@ int ScreenSeqsCommand::execute(){
 																					
 		if(namefile != "" && groupfile != "")	{	
 			screenNameGroupFile(badSeqNames);	
-			if (m->control_pressed) {  remove(goodSeqFile.c_str()); return 0; }
+			if (m->control_pressed) {  m->mothurRemove(goodSeqFile); return 0; }
 		}else if(namefile != "")	{	
 			screenNameGroupFile(badSeqNames);
-			if (m->control_pressed) {  remove(goodSeqFile.c_str());  return 0; }	
+			if (m->control_pressed) {  m->mothurRemove(goodSeqFile);  return 0; }	
 		}else if(groupfile != "")				{	screenGroupFile(badSeqNames);		}	// this screens just the group
 		
-		if (m->control_pressed) { remove(goodSeqFile.c_str());  return 0; }
+		if (m->control_pressed) { m->mothurRemove(goodSeqFile);  return 0; }
 
 		if(alignreport != "")					{	screenAlignReport(badSeqNames);		}
+		if(qualfile != "")						{	screenQual(badSeqNames);			}
 		
-		if (m->control_pressed) { remove(goodSeqFile.c_str());  return 0; }
+		if (m->control_pressed) { m->mothurRemove(goodSeqFile);  return 0; }
 		
 		#ifdef USE_MPI
 			}
@@ -492,6 +514,11 @@ int ScreenSeqsCommand::execute(){
 		if (itTypes != outputTypes.end()) {
 			if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setGroupFile(current); }
 		}
+		
+		itTypes = outputTypes.find("qfile");
+		if (itTypes != outputTypes.end()) {
+			if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setQualFile(current); }
+		}
 
 		m->mothurOut("It took " + toString(time(NULL) - start) + " secs to screen " + toString(numFastaSeqs) + " sequences.");
 		m->mothurOutEndLine();
@@ -520,7 +547,7 @@ int ScreenSeqsCommand::screenNameGroupFile(set<string> badSeqNames){
 		ofstream goodNameOut;	m->openOutputFile(goodNameFile, goodNameOut);
 		
 		while(!inputNames.eof()){
-			if (m->control_pressed) { goodNameOut.close();  inputNames.close(); remove(goodNameFile.c_str());  return 0; }
+			if (m->control_pressed) { goodNameOut.close();  inputNames.close(); m->mothurRemove(goodNameFile);  return 0; }
 
 			inputNames >> seqName >> seqList;
 			it = badSeqNames.find(seqName);
@@ -566,7 +593,7 @@ int ScreenSeqsCommand::screenNameGroupFile(set<string> badSeqNames){
 			ofstream goodGroupOut;	m->openOutputFile(goodGroupFile, goodGroupOut);
 			
 			while(!inputGroups.eof()){
-				if (m->control_pressed) { goodGroupOut.close(); inputGroups.close(); remove(goodNameFile.c_str());  remove(goodGroupFile.c_str()); return 0; }
+				if (m->control_pressed) { goodGroupOut.close(); inputGroups.close(); m->mothurRemove(goodNameFile);  m->mothurRemove(goodGroupFile); return 0; }
 
 				inputGroups >> seqName >> group;
 				
@@ -602,7 +629,7 @@ int ScreenSeqsCommand::screenNameGroupFile(set<string> badSeqNames){
 	}
 }
 //***************************************************************************************************************
-int ScreenSeqsCommand::getSummary(vector<unsigned long int>& positions){
+int ScreenSeqsCommand::getSummary(vector<unsigned long long>& positions){
 	try {
 		
 		vector<int> startPosition;
@@ -611,7 +638,7 @@ int ScreenSeqsCommand::getSummary(vector<unsigned long int>& positions){
 		vector<int> ambigBases;
 		vector<int> longHomoPolymer;
 		
-		vector<unsigned long int> positions = m->divideFile(fastafile, processors);
+		vector<unsigned long long> positions = m->divideFile(fastafile, processors);
 				
 		for (int i = 0; i < (positions.size()-1); i++) {
 			lines.push_back(new linePair(positions[i], positions[(i+1)]));
@@ -697,7 +724,7 @@ int ScreenSeqsCommand::driverCreateSummary(vector<int>& startPosition, vector<in
 			}
 			
 			#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
-				unsigned long int pos = in.tellg();
+				unsigned long long pos = in.tellg();
 				if ((pos == -1) || (pos >= filePos->end)) { break; }
 			#else
 				if (in.eof()) { break; }
@@ -779,7 +806,7 @@ int ScreenSeqsCommand::createProcessesCreateSummary(vector<int>& startPosition,
 			for (int k = 0; k < tempNum; k++)			{		in >> temp; longHomoPolymer.push_back(temp);	}		m->gobble(in);
 				
 			in.close();
-			remove(tempFilename.c_str());
+			m->mothurRemove(tempFilename);
 		}
 		
 		return num;
@@ -805,7 +832,7 @@ int ScreenSeqsCommand::screenGroupFile(set<string> badSeqNames){
 		ofstream goodGroupOut;	m->openOutputFile(goodGroupFile, goodGroupOut);
 		
 		while(!inputGroups.eof()){
-			if (m->control_pressed) { goodGroupOut.close(); inputGroups.close(); remove(goodGroupFile.c_str()); return 0; }
+			if (m->control_pressed) { goodGroupOut.close(); inputGroups.close(); m->mothurRemove(goodGroupFile); return 0; }
 
 			inputGroups >> seqName >> group;
 			it = badSeqNames.find(seqName);
@@ -819,7 +846,7 @@ int ScreenSeqsCommand::screenGroupFile(set<string> badSeqNames){
 			m->gobble(inputGroups);
 		}
 		
-		if (m->control_pressed) { goodGroupOut.close();  inputGroups.close(); remove(goodGroupFile.c_str());  return 0; }
+		if (m->control_pressed) { goodGroupOut.close();  inputGroups.close(); m->mothurRemove(goodGroupFile);  return 0; }
 
 		//we were unable to remove some of the bad sequences
 		if (badSeqNames.size() != 0) {
@@ -832,7 +859,7 @@ int ScreenSeqsCommand::screenGroupFile(set<string> badSeqNames){
 		inputGroups.close();
 		goodGroupOut.close();
 		
-		if (m->control_pressed) { remove(goodGroupFile.c_str());   }
+		if (m->control_pressed) { m->mothurRemove(goodGroupFile);   }
 		
 		return 0;
 	
@@ -863,7 +890,7 @@ int ScreenSeqsCommand::screenAlignReport(set<string> badSeqNames){
 		}
 
 		while(!inputAlignReport.eof()){
-			if (m->control_pressed) { goodAlignReportOut.close(); inputAlignReport.close(); remove(goodAlignReportFile.c_str()); return 0; }
+			if (m->control_pressed) { goodAlignReportOut.close(); inputAlignReport.close(); m->mothurRemove(goodAlignReportFile); return 0; }
 
 			inputAlignReport >> seqName;
 			it = badSeqNames.find(seqName);
@@ -883,7 +910,7 @@ int ScreenSeqsCommand::screenAlignReport(set<string> badSeqNames){
 			m->gobble(inputAlignReport);
 		}
 		
-		if (m->control_pressed) { goodAlignReportOut.close();  inputAlignReport.close(); remove(goodAlignReportFile.c_str());  return 0; }
+		if (m->control_pressed) { goodAlignReportOut.close();  inputAlignReport.close(); m->mothurRemove(goodAlignReportFile);  return 0; }
 
 		//we were unable to remove some of the bad sequences
 		if (badSeqNames.size() != 0) {
@@ -896,7 +923,7 @@ int ScreenSeqsCommand::screenAlignReport(set<string> badSeqNames){
 		inputAlignReport.close();
 		goodAlignReportOut.close();
 				
-		if (m->control_pressed) {  remove(goodAlignReportFile.c_str());  return 0; }
+		if (m->control_pressed) {  m->mothurRemove(goodAlignReportFile);  return 0; }
 		
 		return 0;
 	
@@ -906,6 +933,79 @@ int ScreenSeqsCommand::screenAlignReport(set<string> badSeqNames){
 		exit(1);
 	}
 	
+}
+//***************************************************************************************************************
+
+int ScreenSeqsCommand::screenQual(set<string> badSeqNames){
+	try {
+		ifstream in;
+		m->openInputFile(qualfile, in);
+		set<string>::iterator it;
+		
+		string goodQualFile = outputDir + m->getRootName(m->getSimpleName(qualfile)) + "good" + m->getExtension(qualfile);
+		outputNames.push_back(goodQualFile);  outputTypes["qfile"].push_back(goodQualFile);
+		ofstream goodQual;	m->openOutputFile(goodQualFile, goodQual);
+		
+		while(!in.eof()){	
+			
+			if (m->control_pressed) { goodQual.close(); in.close(); m->mothurRemove(goodQualFile); return 0; }
+
+			string saveName = "";
+			string name = "";
+			string scores = "";
+			
+			in >> name; 
+			
+			if (name.length() != 0) { 
+				saveName = name.substr(1);
+				while (!in.eof())	{	
+					char c = in.get(); 
+					if (c == 10 || c == 13){	break;	}
+					else { name += c; }	
+				} 
+				m->gobble(in);
+			}
+			
+			while(in){
+				char letter= in.get();
+				if(letter == '>'){	in.putback(letter);	break;	}
+				else{ scores += letter; }
+			}
+			
+			m->gobble(in);
+			
+			it = badSeqNames.find(saveName);
+			
+			if(it != badSeqNames.end()){
+				badSeqNames.erase(it);
+			}else{				
+				goodQual << name << endl << scores;
+			}
+			
+			m->gobble(in);
+		}
+		
+		in.close();
+		goodQual.close();
+		
+		//we were unable to remove some of the bad sequences
+		if (badSeqNames.size() != 0) {
+			for (it = badSeqNames.begin(); it != badSeqNames.end(); it++) {  
+				m->mothurOut("Your qual file does not include the sequence " + *it + " please correct."); 
+				m->mothurOutEndLine();
+			}
+		}
+		
+		if (m->control_pressed) {  m->mothurRemove(goodQualFile);  return 0; }
+		
+		return 0;
+		
+	}
+	catch(exception& e) {
+		m->errorOut(e, "ScreenSeqsCommand", "screenQual");
+		exit(1);
+	}
+	
 }
 //**********************************************************************************************************************
 
@@ -950,7 +1050,7 @@ int ScreenSeqsCommand::driver(linePair* filePos, string goodFName, string badAcc
 			}
 			
 			#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux)
-				unsigned long int pos = inFASTA.tellg();
+				unsigned long long pos = inFASTA.tellg();
 				if ((pos == -1) || (pos >= filePos->end)) { break; }
 			#else
 				if (inFASTA.eof()) { break; }
@@ -976,7 +1076,7 @@ int ScreenSeqsCommand::driver(linePair* filePos, string goodFName, string badAcc
 }
 //**********************************************************************************************************************
 #ifdef USE_MPI
-int ScreenSeqsCommand::driverMPI(int start, int num, MPI_File& inMPI, MPI_File& goodFile, MPI_File& badAccnosFile, vector<unsigned long int>& MPIPos, set<string>& badSeqNames){
+int ScreenSeqsCommand::driverMPI(int start, int num, MPI_File& inMPI, MPI_File& goodFile, MPI_File& badAccnosFile, vector<unsigned long long>& MPIPos, set<string>& badSeqNames){
 	try {
 		string outputString = "";
 		MPI_Status statusGood; 
@@ -1096,7 +1196,7 @@ int ScreenSeqsCommand::createProcesses(string goodFileName, string badAccnos, st
 			string tempFile =  filename + toString(processIDS[i]) + ".num.temp";
 			m->openInputFile(tempFile, in);
 			if (!in.eof()) { int tempNum = 0; in >> tempNum; num += tempNum; }
-			in.close(); remove(tempFile.c_str());
+			in.close(); m->mothurRemove(tempFile);
 		}
 		
 		return num;
