@@ -82,7 +82,7 @@ SplitAbundCommand::SplitAbundCommand(string option)  {
 			
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
-		
+		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
 		else {
 			vector<string> myArray = setParameters();
 			
@@ -152,12 +152,12 @@ SplitAbundCommand::SplitAbundCommand(string option)  {
 			listfile = validParameter.validFile(parameters, "list", true);
 			if (listfile == "not open") { abort = true; }
 			else if (listfile == "not found") { listfile = ""; }
-			else{ inputFile = listfile; }	
+			else{ inputFile = listfile; m->setListFile(listfile); }	
 			
 			namefile = validParameter.validFile(parameters, "name", true);
 			if (namefile == "not open") { abort = true; }
 			else if (namefile == "not found") { namefile = ""; }	
-			else{ inputFile = namefile; }	
+			else{ inputFile = namefile; m->setNameFile(namefile); }	
 		
 			fastafile = validParameter.validFile(parameters, "fasta", true);
 			if (fastafile == "not open") { abort = true; }
@@ -165,7 +165,7 @@ SplitAbundCommand::SplitAbundCommand(string option)  {
 				fastafile = m->getFastaFile(); 
 				if (fastafile != "") { m->mothurOut("Using " + fastafile + " as input file for the fasta parameter."); m->mothurOutEndLine(); }
 				else { 	m->mothurOut("You have no current fastafile and the fasta parameter is required."); m->mothurOutEndLine(); abort = true; }
-			}	
+			}else { m->setFastaFile(fastafile); }	
 			
 			groupfile = validParameter.validFile(parameters, "group", true);
 			if (groupfile == "not open") {  groupfile = ""; abort = true; }	
@@ -175,13 +175,13 @@ SplitAbundCommand::SplitAbundCommand(string option)  {
 				
 				int error = groupMap->readMap();
 				if (error == 1) { abort = true; }
-	
+				m->setGroupFile(groupfile);
 			}
 			
 			groups = validParameter.validFile(parameters, "groups", false);		
 			if (groups == "not found") { groups = ""; }
 			else if (groups == "all") { 
-				if (groupfile != "") {  Groups = groupMap->namesOfGroups;  } 
+				if (groupfile != "") {  Groups = groupMap->getNamesOfGroups();  } 
 				else {  m->mothurOut("You cannot select groups without a valid groupfile, I will disregard your groups selection. "); m->mothurOutEndLine(); groups = "";   }
 			}else { 
 				m->splitAtDash(groups, Groups);
@@ -250,11 +250,11 @@ int SplitAbundCommand::execute(){
 			if (namefile != "") {  readNamesFile();		}
 			else				{ createNameMap(list);	}
 			
-			if (m->control_pressed) { delete input; delete list; for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); } return 0; }
+			if (m->control_pressed) { delete input; delete list; for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0; }
 			
 			while((list != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
 			
-				if (m->control_pressed) { delete input; delete list; for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); } return 0; }
+				if (m->control_pressed) { delete input; delete list; for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0; }
 				
 				if(allLines == 1 || labels.count(list->getLabel()) == 1){
 						
@@ -288,7 +288,7 @@ int SplitAbundCommand::execute(){
 				list = input->getListVector(); //get new list vector to process
 			}
 			
-			if (m->control_pressed) { delete input;  for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); } return 0; }
+			if (m->control_pressed) { delete input;  for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0; }
 			
 			//output error messages about any remaining user labels
 			set<string>::iterator it;
@@ -304,7 +304,7 @@ int SplitAbundCommand::execute(){
 
 			}
 			
-			if (m->control_pressed) { delete input;  for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); } return 0; }
+			if (m->control_pressed) { delete input;  for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } return 0; }
 			
 			//run last label if you need to
 			if (needToRun == true)  {
@@ -319,7 +319,7 @@ int SplitAbundCommand::execute(){
 			
 			delete input;
 			
-			if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); }	return 0;	}
+			if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); }	return 0;	}
 									
 		}else { //you are using the namefile to determine abundance
 			if (outputDir == "") { outputDir = m->hasPath(namefile); }
