@@ -25,7 +25,9 @@ class SystemCommand : public Command {
 		string getCommandName()			{ return "system";		}
 		string getCommandCategory()		{ return "General";		}
 		string getHelpString();	
-	
+		string getCitation() { return "http://www.mothur.org/wiki/System"; }
+		string getDescription()		{ return "execute system commands from within mothur"; }
+
 		int execute(); 
 		void help() { m->mothurOut(getHelpString()); }	
 	
