@@ -80,6 +80,7 @@ UnifracUnweightedCommand::UnifracUnweightedCommand(string option)  {
 			
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
+		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
 		
 		else {
 			vector<string> myArray = setParameters();
@@ -133,8 +134,8 @@ UnifracUnweightedCommand::UnifracUnweightedCommand(string option)  {
 			}
 			
 			m->runParse = true;
-			m->Groups.clear();
-			m->namesOfGroups.clear();
+			m->clearGroups();
+			m->clearAllGroups();
 			m->Treenames.clear();
 			m->names.clear();
 			
@@ -145,16 +146,18 @@ UnifracUnweightedCommand::UnifracUnweightedCommand(string option)  {
 				treefile = m->getTreeFile(); 
 				if (treefile != "") { m->mothurOut("Using " + treefile + " as input file for the tree parameter."); m->mothurOutEndLine(); }
 				else { 	m->mothurOut("You have no current tree file and the tree parameter is required."); m->mothurOutEndLine(); abort = true; }								
-			}	
+			}else { m->setTreeFile(treefile); }	
 			
 			//check for required parameters
 			groupfile = validParameter.validFile(parameters, "group", true);
 			if (groupfile == "not open") { abort = true; }
 			else if (groupfile == "not found") { groupfile = ""; }
+			else { m->setGroupFile(groupfile); }
 			
 			namefile = validParameter.validFile(parameters, "name", true);
 			if (namefile == "not open") { abort = true; }
 			else if (namefile == "not found") { namefile = ""; }
+			else { m->setNameFile(namefile); }
 			
 			outputDir = validParameter.validFile(parameters, "outputdir", false);		if (outputDir == "not found"){	outputDir = "";	}
 			
@@ -164,7 +167,7 @@ UnifracUnweightedCommand::UnifracUnweightedCommand(string option)  {
 			if (groups == "not found") { groups = ""; }
 			else { 
 				m->splitAtDash(groups, Groups);
-				m->Groups = Groups;
+				m->setGroups(Groups);
 			}
 				
 			itersString = validParameter.validFile(parameters, "iters", false);				if (itersString == "not found") { itersString = "1000"; }
@@ -193,7 +196,7 @@ UnifracUnweightedCommand::UnifracUnweightedCommand(string option)  {
 			if ((phylip) && (Groups.size() == 0)) {
 				groups = "all";
 				m->splitAtDash(groups, Groups);
-				m->Groups = Groups;
+				m->setGroups(Groups);
 			}
 		}
 		
@@ -255,8 +258,8 @@ int UnifracUnweightedCommand::execute() {
 				
 				if (m->control_pressed) { 
 					delete tmap; for (int i = 0; i < T.size(); i++) { delete T[i]; }
-					for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str()); } outputTypes.clear();
-					m->Groups.clear();
+					for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]); } outputTypes.clear();
+					m->clearGroups();
 					return 0;
 				}
 				
@@ -279,8 +282,11 @@ int UnifracUnweightedCommand::execute() {
 		m->openOutputFile(sumFile, outSum);
 		
 		util = new SharedUtil();
-		util->setGroups(m->Groups, tmap->namesOfGroups, allGroups, numGroups, "unweighted");	//sets the groups the user wants to analyze
-		util->getCombos(groupComb, m->Groups, numComp);
+		Groups = m->getGroups();
+		vector<string> namesGroups = tmap->getNamesOfGroups();
+		util->setGroups(Groups, namesGroups, allGroups, numGroups, "unweighted");	//sets the groups the user wants to analyze
+		util->getCombos(groupComb, Groups, numComp);
+		m->setGroups(Groups);
 		delete util;
 	
 		if (numGroups == 1) { numComp++; groupComb.push_back(allGroups); }
@@ -295,8 +301,10 @@ int UnifracUnweightedCommand::execute() {
 		
 		if (numComp < processors) { processors = numComp;  }
 		
-		outSum << "Tree#" << '\t' << "Groups" << '\t'  <<  "UWScore" <<'\t' << "UWSig" <<  endl;
-		m->mothurOut("Tree#\tGroups\tUWScore\tUWSig"); m->mothurOutEndLine();
+		outSum << "Tree#" << '\t' << "Groups" << '\t'  <<  "UWScore" <<'\t';
+		m->mothurOut("Tree#\tGroups\tUWScore\t");
+		if (random) { outSum << "UWSig"; m->mothurOut("UWSig"); }
+		outSum << endl; m->mothurOutEndLine();
 	 
 		//get pscores for users trees
 		for (int i = 0; i < T.size(); i++) {
@@ -304,7 +312,7 @@ int UnifracUnweightedCommand::execute() {
 				delete tmap; delete unweighted;
 				for (int i = 0; i < T.size(); i++) { delete T[i]; }
 				outSum.close();
-				for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str());  }
+				for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  }
 				return 0; 
 			}
 			
@@ -326,7 +334,7 @@ int UnifracUnweightedCommand::execute() {
 			userData = unweighted->getValues(T[i], processors, outputDir);  //userData[0] = unweightedscore
 		
 			if (m->control_pressed) { delete tmap; delete unweighted;
-				for (int i = 0; i < T.size(); i++) { delete T[i]; }if (random) { delete output;  } outSum.close();  for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str());  }return 0; }
+				for (int i = 0; i < T.size(); i++) { delete T[i]; }if (random) { delete output;  } outSum.close();  for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  }return 0; }
 			
 			//output scores for each combination
 			for(int k = 0; k < numComp; k++) {
@@ -344,7 +352,7 @@ int UnifracUnweightedCommand::execute() {
 				randomData = unweighted->getValues(T[i], "", "", processors, outputDir);
 				
 				if (m->control_pressed) { delete tmap; delete unweighted;
-					for (int i = 0; i < T.size(); i++) { delete T[i]; }if (random) { delete output;  } outSum.close(); for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str());  } return 0; }
+					for (int i = 0; i < T.size(); i++) { delete T[i]; }if (random) { delete output;  } outSum.close(); for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  } return 0; }
 			
 				for(int k = 0; k < numComp; k++) {	
 					//add trees unweighted score to map of scores
@@ -382,7 +390,7 @@ int UnifracUnweightedCommand::execute() {
 			}
 			
 			if (m->control_pressed) { delete tmap; delete unweighted;
-				for (int i = 0; i < T.size(); i++) { delete T[i]; }if (random) { delete output;  } outSum.close(); for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str());  } return 0;  }
+				for (int i = 0; i < T.size(); i++) { delete T[i]; }if (random) { delete output;  } outSum.close(); for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  } return 0;  }
 			
 			//print output files
 			printUWSummaryFile(i);
@@ -398,11 +406,11 @@ int UnifracUnweightedCommand::execute() {
 		
 
 		outSum.close();
-		m->Groups.clear();
+		m->clearGroups();
 		delete tmap; delete unweighted;
 		for (int i = 0; i < T.size(); i++) { delete T[i]; }
 		
-		if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str());  }	return 0; }
+		if (m->control_pressed) { for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  }	return 0; }
 		
 		m->mothurOut("It took " + toString(time(NULL) - start) + " secs to run unifrac.unweighted."); m->mothurOutEndLine();
 		
@@ -482,9 +490,9 @@ void UnifracUnweightedCommand::printUWSummaryFile(int i) {
 					m->mothurOutJustToLog(groupComb[a]  + "\t" + toString(utreeScores[a][0])  + "\t<" + toString((1/float(iters))) + "\n"); 
 				}
 			}else{
-				outSum << setprecision(6) << groupComb[a]  << '\t' << utreeScores[a][0] << '\t' << "0.00" << endl;
-				cout << setprecision(6)  << groupComb[a]  << '\t' << utreeScores[a][0] << '\t' << "0.00" << endl; 
-				m->mothurOutJustToLog(groupComb[a]  + "\t" + toString(utreeScores[a][0])  + "\t0.00\n");
+				outSum << setprecision(6) << groupComb[a]  << '\t' << utreeScores[a][0]  << endl;
+				cout << setprecision(6)  << groupComb[a]  << '\t' << utreeScores[a][0]  << endl; 
+				m->mothurOutJustToLog(groupComb[a]  + "\t" + toString(utreeScores[a][0]) + "\n");
 			}
 		}
 		
@@ -511,18 +519,18 @@ void UnifracUnweightedCommand::createPhylipFile(int i) {
 		
 		if ((outputForm == "lt") || (outputForm == "square")) {
 			//output numSeqs
-			out << m->Groups.size() << endl;
+			out << m->getNumGroups() << endl;
 		}
 		
 		//make matrix with scores in it
-		vector< vector<float> > dists;	dists.resize(m->Groups.size());
-		for (int i = 0; i < m->Groups.size(); i++) {
-			dists[i].resize(m->Groups.size(), 0.0);
+		vector< vector<float> > dists;	dists.resize(m->getNumGroups());
+		for (int i = 0; i < m->getNumGroups(); i++) {
+			dists[i].resize(m->getNumGroups(), 0.0);
 		}
 		
 		//flip it so you can print it
 		int count = 0;
-		for (int r=0; r<m->Groups.size(); r++) { 
+		for (int r=0; r<m->getNumGroups(); r++) { 
 			for (int l = 0; l < r; l++) {
 				dists[r][l] = utreeScores[count][0];
 				dists[l][r] = utreeScores[count][0];
@@ -531,9 +539,9 @@ void UnifracUnweightedCommand::createPhylipFile(int i) {
 		}
 		
 		//output to file
-		for (int r=0; r<m->Groups.size(); r++) { 
+		for (int r=0; r<m->getNumGroups(); r++) { 
 			//output name
-			string name = m->Groups[r];
+			string name = (m->getGroups())[r];
 			if (name.length() < 10) { //pad with spaces to make compatible
 				while (name.length() < 10) {  name += " ";  }
 			}
@@ -548,12 +556,12 @@ void UnifracUnweightedCommand::createPhylipFile(int i) {
 				out << name << '\t';
 				
 				//output distances
-				for (int l = 0; l < m->Groups.size(); l++) {	out << dists[r][l] << '\t';  }
+				for (int l = 0; l < m->getNumGroups(); l++) {	out << dists[r][l] << '\t';  }
 				out << endl;
 			}else{
 				//output distances
 				for (int l = 0; l < r; l++) {	
-					string otherName = m->Groups[l];
+					string otherName = (m->getGroups())[l];
 					if (otherName.length() < 10) { //pad with spaces to make compatible
 						while (otherName.length() < 10) {  otherName += " ";  }
 					}
