@@ -87,6 +87,7 @@ VennCommand::VennCommand(string option)  {
 			
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
+		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
 		
 		else {
 			vector<string> myArray = setParameters();
@@ -128,12 +129,12 @@ VennCommand::VennCommand(string option)  {
 			listfile = validParameter.validFile(parameters, "list", true);
 			if (listfile == "not open") { listfile = ""; abort = true; }
 			else if (listfile == "not found") { listfile = ""; }
-			else {  format = "list"; inputfile = listfile; }
+			else {  format = "list"; inputfile = listfile; m->setListFile(listfile); }
 			
 			sharedfile = validParameter.validFile(parameters, "shared", true);
 			if (sharedfile == "not open") { sharedfile = ""; abort = true; }	
 			else if (sharedfile == "not found") { sharedfile = ""; }
-			else {  format = "sharedfile"; inputfile = sharedfile; }
+			else {  format = "sharedfile"; inputfile = sharedfile; m->setSharedFile(sharedfile); }
 			
 			if ((sharedfile == "") && (listfile == "")) { 
 				//is there are current file available for any of these?
@@ -167,7 +168,7 @@ VennCommand::VennCommand(string option)  {
 			if (groups == "not found") { groups = ""; }
 			else { 
 				m->splitAtDash(groups, Groups);
-				m->Groups = Groups;
+				m->setGroups(Groups);
 			}
 			
 			calc = validParameter.validFile(parameters, "calc", false);			
@@ -182,6 +183,11 @@ VennCommand::VennCommand(string option)  {
 				}
 			}
 			m->splitAtDash(calc, Estimators);
+			if (m->inUsersGroups("citation", Estimators)) { 
+				ValidCalculators validCalc; validCalc.printCitations(Estimators); 
+				//remove citation from list of calcs
+				for (int i = 0; i < Estimators.size(); i++) { if (Estimators[i] == "citation") {  Estimators.erase(Estimators.begin()+i); break; } }
+			}
 			
 			string temp;
 			temp = validParameter.validFile(parameters, "abund", false);		if (temp == "not found") { temp = "10"; }
@@ -268,8 +274,8 @@ int VennCommand::execute(){
 				if (m->control_pressed) {
 					for (int i = 0; i < vennCalculators.size(); i++) {	delete vennCalculators[i];	}
 					for (int i = 0; i < lookup.size(); i++) {  delete lookup[i];  } 
-					m->Groups.clear(); delete venn; delete input;
-					for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str());  }
+					m->clearGroups(); delete venn; delete input;
+					for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  }
 					return 0;
 				}
 
@@ -351,8 +357,8 @@ int VennCommand::execute(){
 			
 			if (m->control_pressed) {
 					for (int i = 0; i < vennCalculators.size(); i++) {	delete vennCalculators[i];	}
-					m->Groups.clear(); delete venn; delete input; 
-					for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str());  }
+					m->clearGroups(); delete venn; delete input; 
+					for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  }
 					return 0;
 			}
 
@@ -408,12 +414,12 @@ int VennCommand::execute(){
 		
 
 			//reset groups parameter
-			m->Groups.clear();  
+			m->clearGroups();  
 			
 			if (m->control_pressed) {
-					m->Groups.clear(); delete venn; delete input;
+					m->clearGroups(); delete venn; delete input;
 					for (int i = 0; i < vennCalculators.size(); i++) {	delete vennCalculators[i];	}
-					for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str());  }
+					for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  }
 					return 0;
 			}
 
@@ -425,7 +431,7 @@ int VennCommand::execute(){
 				if (m->control_pressed) {
 					for (int i = 0; i < vennCalculators.size(); i++) {	delete vennCalculators[i];	}
 					delete sabund; delete venn; delete input;
-					for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str());  }
+					for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  }
 					return 0;
 				}
 		
@@ -466,7 +472,7 @@ int VennCommand::execute(){
 			
 			if (m->control_pressed) {
 					for (int i = 0; i < vennCalculators.size(); i++) {	delete vennCalculators[i];	}
-					for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str());  }
+					for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  }
 					delete venn; delete input;
 					return 0;
 			}
@@ -500,7 +506,7 @@ int VennCommand::execute(){
 			if (m->control_pressed) {
 					delete venn; delete input;
 					for (int i = 0; i < vennCalculators.size(); i++) {	delete vennCalculators[i];	}
-					for (int i = 0; i < outputNames.size(); i++) {	remove(outputNames[i].c_str());  }
+					for (int i = 0; i < outputNames.size(); i++) {	m->mothurRemove(outputNames[i]);  }
 					return 0;
 			}
 		}
